## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::De_ch_1901 0.102;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::De_ch_1901::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=head1 C<De_ch_1901> hyphenation pattern class

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 Copyright

The copyright of the patterns is not covered by the copyright of this package
since this pattern is generated from the source at
L<svn://tug.org/texhyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/tex/hyph-de-ch-1901.tex>

The copyright of the source can be found in the DATA section in the source of
this package file.

=cut

__DATA__
% dehyphts-x-2014-05-21.pat

\message{Swiss-German Hyphenation Patterns (Traditional Orthography) `dehyphts-x' 2014-05-21 (WL)}

% TeX-Trennmuster für die traditionelle deutsch-schweizerische
% Rechtschreibung
%
%
% Copyright (C) 2009, 2011, 2012, 2013, 2014 Werner Lemberg <wl@gnu.org>
%
% This program can be redistributed and/or modified under the terms
% of the LaTeX Project Public License Distributed from CTAN
% archives in directory macros/latex/base/lppl.txt; either
% version 1 of the License, or any later version.
%
%
% The word list is available from
%
%   http://repo.or.cz/w/wortliste.git?a=commit;h=3a97953c0ddd099a1785ea7927cbf24e639090b0
%
% The used patgen parameters are
%
%   1 1 | 2 5 | 1 1 1
%   2 2 | 2 5 | 1 2 1
%   3 3 | 2 6 | 1 1 1
%   4 4 | 2 6 | 1 4 1
%   5 5 | 2 7 | 1 1 1
%   6 6 | 2 7 | 1 6 1
%   7 7 | 2 13 | 1 4 1
%   8 8 | 2 13 | 1 8 1

\patterns{%
.ab1a
.ab3l
.abo2
.ab3ol
.ab1or
.ack2
.ag2a
.ag4r
.ag2u
.ai2s
.akt2a
.al2e
.al3k
.al5l4en
.al4tei
.alt3s
.ampe4
.amt4s1
.an3d2
.anden6k
.and4ri
.ang2
.an3gli
.ang4s2
.angst3
.an3s2
.an4si.
.an4tag
.an3th
.an3z2
.aos4
.ap5p6le.
.aps2
.ari1e
.ark2a
.ar4m3ac
.ar2sc
.ar4t3ei
.arter4
.ar6t5erh
.as2t
.ata1
.at4h
.au3d
.au4f3
.aufs2
.au2s1
.ausch3
.au6stes
.ax2
.äm3
.är6schl
.ät2s
.be3erb
.be3r2a
.be3r2e
.berg3a
.ber6gab
.ber6g5e6b
.ber4gl
.ber4g3r
.boge2
.bo4s3k
.bu4ser
.ch2
.chi3er
.dab4
.da2r1
.da4rin
.dar2m1
.da4te.
.da4tes
.de2al
.de1i
.de4in.
.de8ments
.de1o2
.de3r4en
.de3sk
.dien2
.do2mo
.do1pe
.dorf1
.dü1b
.ebe2r1
.ehe1i
.ei4ds
.ei3e2
.ei4na
.einen6g
.ei2sp
.ei4s1t
.ei2tr
.eke2
.el2a
.el2bi
.em3m2
.en1
.en4d3er
.en5der.
.en2d3r
.en2gl
.enn2
.en2t3
.epi1
.ep3p
.er8brecht
.er2bu
.er2da
.er4dan
.er4dar
.er4dei
.erden6k
.er4der
.er1e
.ere3c
.erf4
.er1i
.ers2
.er8stein
.erster6
.er8sterb
.er8stritt.
.er8stritten.
.er4zen4
.esel4s
.es3p
.es6serv
.es2st
.es2t
.est4e
.est2h
.et2s
.eu1
.eu3g4
.eu3t
.eve4r
.ext4
.fe4i
.fer4no
.fe4sta
.fid2
.fi4le.
.fi4len
.fi2s
.fs2
.fu2sc
.ga2t
.gd2
.geb2l
.gel2d1
.ge5nar
.ge3n2e
.ge3r2a
.ge3r2e
.ge3s2
.get4
.ge3u
.grif8fes
.gros2
.guss1
.haft3s
.hal2s
.hau2t1
.he2
.he3fe
.her3an
.he3ri
.he6r5inn
.hin3u
.ho4met
.ia2
.il3
.im2a
.ima4ge
.im5m2
.in1
.in3e
.in3gl
.ink4
.inn2e
.inu1
.ioni1
.ire3
.is2a
.ka2b5l
.ka2i
.kamp2
.ka4t3io
.ken6num
.ker3s
.ki4e
.kle4i
.kopf1
.ks2
.kus2
.le4ar
.le3se
.lich8t7er8s
.li2f
.li4ve.
.lo4g3in
.lo3ver
.lu4str
.ma3d
.ma3la
.mal4e
.ma4str
.md2
.mel2a
.me3no
.men8schl
.men8schw
.men3t4
.mi2t
.mi4ti
.mm2
.näs1c
.ni2e
.nob4
.no2c
.no2s
.no4th
.nul2
.nus2
.ob1a
.obe2
.ohr5s
.oper4
.or2a
.ort2
.orts3e
.ort4st
.os5t6alg
.oste2
.ost5end
.osten8de
.oste6re
.ost3r
.ozo4
.öl3l
.pa4r1e
.par3t4h
.pe2c
.pe4ste
.pf4
.ph2
.poka2
.po4str
.ps2
.rabe4
.ra3me
.reb3s2
.re3cha
.rein4t
.reli1
.reli3e
.ri2as
.rich5te
.ro4a
.ro3m4a
.rö2s1c
.runder6
.rü1b
.rücker6
.sali1
.sami3
.sch4
.sen3s
.ser2u
.se2t1
.sha2
.si2te
.ski1e
.spiege8lei
.st6
.sto4re
.sucher6
.tan4k3l
.ta2to
.te2e
.te2f
.te3no
.th4
.ti2a
.tid1
.ti2e
.ti4me.
.ti4mes
.ti2s
.to4nin
.to4pl
.to2w
.tri3e4s
.ts2
.tu3ri
.uf2e2
.ufer1
.um3
.umo2
.ums2
.un3a2
.un3d
.une4
.un3g
.uni2t
.ur1
.ural4
.ur2i
.urin4s
.ur3o2m
.uro2p
.ur3s2
.ut2a
.ut3r
.übe4
.ve5n2e
.vi2e
.vo4r
.wah4l
.wa2s
.welter8e
.welter8k
.wi4e
.wor2
.wort5en6
.xe3
.ya4l
.zeit3s
.zel4la4
.zelle4
.zel6lei
.zi2e
.zin4st
.zol2
a1ab
aa2be
aa1c
aa2gr
2a1a2n
2a2ar
aa2r1a
aar3f4
aar3k4
aar5sc
aas1t
aa2th
aa2t3r
aat4s1
2a3au
a1ä
a1b
2aba
abais4
ab1auf
ab1ä
ab2äu
1abd
ab1eb
abe1e
ab1eil
4abel
abe2la
a3beri
ab1er2k
ab1er2r
ab1er2z
ab3esse
abes2t
ab1eß
2abet
2abew
1abf
3abfi
1abg
1abh
2abi
ab1ins
ab1ir
ab1it
1abk
ab1l
1a2bla
1a2blä
2able
ab4le.
ab3li
ab4lo
3a2blö
a2blu
1abn
a2bo.
ab2of
1a2bon
2abor
ab3r
a3bra
a4brä
2abrü
1abs
2abs.
abs2a
2absar
ab5s2i
ab3s2p
abs4t2
2abst.
ab3sz
1abtei
2a3bu
ab1ur
2abü
1abw
2aby
1abz
2aca
2ac1c
a1cem
2ach.
ach1a
a1chal
ach3au
2achb
2a1che
a2ch1e2c
ach1ei
a4cherf
a4cherk
a4cherö
a4ch3erw
a1chi
ach3l
ach3m
ach3n
a1cho
a3cho.
ach1o2b
ach1or
ach3ö
ach3r
ach3s2i
ach3su
a4cht
acht7ersc
ach2t1o
ach8traum
ach8träume.
ach8träumen.
ach6trit
a1chu
ach1u2f
ach3ü
2achv
2ach1w
a1ci
ac1in
2ack.
ackmu4
ackmus3
ack2se
ack3sl
ack3sta4
a1cl
a3co
acon4n
2acu
a1ç
a1d
2ada.
a3d2ab
ad2ag
adai4
ada2m
ad3ama
a2d1an
3a4dap
a3d2ar3
4adav
1a2dä
ad1c
1add
2ade.
ade2al
adefi4
a2dein
2aden
ade1r2a
a2deri
4ades2
ade3sp
ades6s
2adf
2adh
4a3di
adi3en
5adj
2ado
ad2ob
2adp
2adq
2ad3rec
ad4res
2ads2
ad3sz
ad2t1
adta2
2adu
2a1e1
ae2b
a3e2d
a3e2i
a2ek
a3el.
a2ela
a2ele
a2eli
a3els
ae2o3
a3e2p
3a2er2o
ae4sc
a2et
a2ew
ae2x
af1a
a2fak
a2fan
a3far
af4at
a2fau
2afe
a2f1ec
a2fent
af1erl
a2fex
af2fei
af2f3l
af4flu
2afi
2af3l
a2fö
af3ra
af3rä
af3re
af3rö
af3s2a
af2sp
2aft
af2t1a
af2tei
af4t3erl
af2t1o
af2t3r
aft5re
af2tur
a2f3ur
a1g
2aga
ag1a2b
ag1a2d
ag1am
ag1ar
ag1au
ag2di
ag2du
2age.
age1i
age4na
age4neb
a2gent
a4gentu
ag2er
age4ral
2ages
age2sa
age4sel
age4si
age2s3p
ages5s
ag3esse
age6stem
ag3gl
3aggr
3a2git
2a2gl
ag4la
a4glö
ag2n
a2gna
ag4ne.
ag4nu
a2g3re
a2g3ri
ag4ro
agsa2
ag3sah
ag4sam
ag3sc
ag4set
ags3p
ag6spo
ag4sti
ag2s1tr
2agt
ag2th
a2gund
2ah.
2a1ha
ah4at
2a1he
ahe1in
a2h1erh
a1h2i
ahin3
ahl3a4
ah4l1ei
ah4l3erh
ah2lö
ahl3sz
ah4n1a
ahner4e
ahnt2
1ahor
ah1o2s
a2h3ö
ahr1a
ah3re
ahre4s3
ah3ri
ahrta4
ahr4tri
ah2ta
aht3h
ah2t5r
aht1s
a1hu
ah1w
a1hy
2ai
ai3a4
aian3
aid4s
aids1t
ai1e2
aif4
ai1fr
ai3g4
a3ik.
ai3ke
aik4r
ai2lo
aim2o
ain2a
a1ind
ain4e
a1ing
ain3sp
3airb
ai2sa
a3isch.
ai3s2e
aiss2
ais4se.
ais5st
ait4
a3iv.
a3ivl
a3ivs
a1j
ajekt4o
2ak.
1a2k4ad
2akal
2a3kam
2akar
ak4at
1a2kaz
2akb
2akc
2akd
2a1ke
a2kef
aken2n
a2keu
2a1ki
2ak3l
ak4li
4ako
2a1kr
ak3rau
3akro3
2aks
ak3sh
2akta
2aktb
ak3te
ak4tei
2aktik
ak2t3r
ak3t4ri
2aktsi
2aktst
2a1ku
a2kun
2a3kü
1akz
a1la
2ala.
al1ab
ala3ch2
al1af
ala2g
al1age
a3lal
al1am
alami5
al3amp
al1ana
a2l1ang
al1ans
al1anz
a2lar
a3lar.
a3lare
al2arm
al3arr
ala2s
al1asi
al1ass
2alat
al1au
al3aug
a1lä
al1äm
alb3ein
al4berh
al4b3er4w
al2b1l
alb3li
al2boh
al2br
alb3ru
alb3s
al2dä
al2dr
2ale
ale4a
3a2l1e2b
3a4l1ef
a4l1eh
a2l1ei
a4lein
a2l1el
alen1
al3ends
a2leng
a3lentf
ale2p
al1epo
al1erf
a2l1erh
al3erl
3alerm
a2l1ert
3alerz
a2l1esk
ale4t
al1eta
al1eth
a2l1eu
a4leur
3a2lex
alf4r
3algi
al2gli
1algo
2ali
ali4ene
al2imb
ali4nal
al1ins
a2linv
alk1ar
al2kne
1alkoh
alk3s2
al2l1ab
alla3d
al2lan
al2l3a4r
al6later
al2län
al3läu
al4lec
alle4gi
al4leh
al5lein
al3lend
all5erfa
al3les
alle3se
al2leu
1allgä
alli5er.
alli7ers.
al2lob
al2lo2c
al2lo2k
al4lo2s
al2lö2
all3öse
al2luf
allu4s
al2lü4s
al4m3ast
3almb
2alo
a2l1o2b
3a2loe
alo2ga
al1orc
a2l1ö
al3öf
al2ös
3alpe.
1alph
al3skl
als2to
al2sum
al3sun
al4tak
al3tar
alt3eig
al4t3er3f
alt1op
al2tö
al2tri
alt3ric
al2tro
alt2se
alt4stü
a1lu
al2uf
a2lum
al1umb
al1ur
4aly
alzer4z
al2zw
2am.
2am2a
amab4
amad2
ama3g
2amä
am2e
2ame.
a2meb
2amel
am4e2n1
amer2a
am3erf
a2meri
ame3ru
a4mesh
a3met
a2mew
2amir
ami3t2a
ami3ti
2aml
2amm.
am2ma2c
2ammal
amma4n
am2mar
am2mas
amma4sc
am2maß
am4ma4te
am2mä
ammen8ge.
am2min
am2mit
2amml
am4mod
2ammt
ammu2
am4mü
amni1
a2mö
amp2fa2
am3pr
2ams
am4schl
1amt.
am2t1a
am2t1ä
am2tel
am4t3ern
am2tö
am2t3r
am2tu
2amu
2ana.
2anab
ana3c
anadi3
a3nak
an1alg
ana4lin
2anam
2anan
2anas
an1ath
an4atm
an1äs
1anb
2anbu
an3ch
2and.
3an3d2ac
an4d3ei
ande4sc
an2dex
an4drau
an2d3rü
and4sas
and6spas
and6s5paß
and2su
2andu
and1ur
2ane
an3ec
a3nee
an2ei.
an3eif
an1e4k
3a4n1erb
an1eth
1anf
2anfi
anft3s
an3f2u
4ang.
an2g1ar
3angeb
an2g1ei
an4g3erf
an4g3erl
an4gerw
an4g3erz
2angf
2angh
2angie
ang1l
an2gla
2ango
ang1r
an4g3ra
4angs.
ang3sc
ang6s3po
1anh
2a3ni
an2i3d
ani3els
ani5ers.
3a4nim
a4nins
2anj
2ank.
an2k1an
3ankä
an2kei
an3kl
an4klö
an2klu
an2k3no
ank1r
ank3ra
ank3rä
ankt4
1anl
1anmu
2ann
3an3na
ann2ab
3annä
an3n2e
ann4sto
an1od
a3nol
a2n1or
a3nos
2a1nö
1anr
1an3s2ä
1ansc
ans2en
an2seu
2ansk
an3skr
an3s1pa
1anspr
an3s2z
2ant.
an2t3a4r
1antá
1antei
3antenn
an3t4he
1anthr
2anto
anton4
3antr
ant3rin
an2tro
1antw
2anu
anu1s
a1nü
1anw
2anwet
2anzb
1anzei
anze2n
2anzg
an2z1i4n
2anzs
1anzü
2anzw
an2zwa
an2zwi
2ao
ao1i4
a1op
a1or
a1os3
ao3t4
a3ot.
a1ö
a1p
2ap.
2a3pa
2ape
a2pef
a3pel
a2pé
a2pf
ap2fa
a3pfl
a3phä
a2ph3t
2ap3l
ap4la
ap2n
a2pot
ap2pf
3appl
2apr
3apri
ap2str
2a3pu
2aq
2ar.
a1ra
a3ra.
ar2ab
ar3abt
ara3d2
a2r3al
a3ra3li
2aran
a2r1ang
a2r1ans
a2r1anz
a2r3app
2a2rar
a2r1au
a1rä
1arb
2arb.
4arba
ar2bau
ar2bec
2arbek
2arben
4arbi
ar2bl
2arbr
ar2bre
2arbs2
2arbt
2arbu
ar2b3un
1ar1c
ar2dro
2are
a2rea
ar1eff
a4reg
ar1ehr
a2rein
4arem
a3ren
4aren.
are3r2a
ar2erf
a2r1erh
a2reri
are3u
ar2ew
2arf
ar2fä
arf1r
ar2f3ra
ar2gl
ar2gn
ar3g4r
2arh
2a3ri
ar2ia
ari3e4n
ari3erd
ari3erg
ari5ers.
ar1im
arin3it
a4r1int
a4rinw
ar2kal
ark3amt
ar2k1ar
ark3aue
ar2k3l
ar4klag
ar2kor
ar4k3ri
ark3sa
ark3she
ar2les
2arma
ar3m2ä
ar3m2or
ar2nan
arn2e
2a1ro
ar1ob
a2r1o2d
a2r1of
a2r1op
a2ror
2arp
2arr
ar2r3ad
ar2rek
arre4n
ar2rh
arr3he
2arsa
ar4schl
arse3
ar3s2h
2arsi
ar3t2e
artel6li6
ar2the
artin2
2arto
ar4t3ram
art3re
2arts
2artuc
2aru
ar1uh
ar1um
a2rü
2arv
arwa2
2ary
ar2zä
2arze
1arzt
ar2z1w
as2ad
as1ala
as3au
asau2s1
a2sca
a4schec
asch3la
a2schm
a3schu
4a3s2e
a4seb
as3e2m
a5s4es
a4sex
2asg
4ash
a3s2hi
asin2g
4a5sis
asi4st
a3skop
a1so1
as1o2f
a3sol
as1or
as1p
aspek6to
as2ph
as2pi
as2po
a1spu
as3s2a
as2sä
as3s2e
as4s3ei
ass2i
as3sin
as2si2t
as2s1p
as4st
ass1ti
ass1to
as5str
as5stu
as2sü
2asta
a4stec
a4s3tep
as2ter
a4stese
2astr
as4trau
a4strä
ast3räu
a2s2t3re
a4strol
a2stum
a3su
asu2s
aswa2s
3a2syl
aße2
aßen3
2a1t
at1ab
at2a1f
at4ag
a2t1akt
ata3l
a3tam
at1apf
at1au
a2taus
a2tä
at1än
at2c
a2teb
ate1c
ateien4
at1eig
a4teli
at2en
a2tep
ate2ru
atex3
at2h
at3ha
athe1
3athl
a4thr
4a3ti
3atm
4atmus
ato4man
4ator
a2t1ort
a2t1ö
4atr
atra4t
at3rä
at3re
at3rom
at3rü
at2sa
at4schn
at2se
at4set
at2si
ats1p
at3ta
3attac
at4tak
at2ta2l
att3ang
at4tau
at2tä
at4tec
at2tei
at3t4hä
at2t3rä
att3s
at3tu
atu2n
atz1er
at4zerk
at4zerw
at2zi
atz1in
at2zo
atz3t2
at2z1w
a2u
2au.
2au1a2
2aub
au2bab
aube4n
au2bli
au2blo
4auc
auch3ta
au2dr
2aue
aue2b
au3en.
au2ere
au5erein
auer3ö
au2fa
auf1an
3aufber
2aufe.
2aufeh
auf1er
au4ferk
auff4
3aufn
auft2
2auft.
2aug
4augeh
2auh
au3ha
au2hu
4au1i
au2is
2auj
aule2s
au3lü
2aum
au2mal
aum2ei
au2m1e4r1
aum3eri
au2m1o
aum3p2
aum3s2
4aun
au3n2a
aun2e
au4nei
au2nio
au3nu
a4unz
2aup2
aup4ter
2au3r2
au2s1ah
ausan8ne.
au2sau
4ausc
au4schm
1ausd
2ausen
aus3erp
au4s3erw
1ausf
1ausg
1ausl
au2so
au2spr
1ausr
1auss2
aus3sa
aus4se.
au2sta
2auste
au4stec
aus3tie
aust2o
aus3tri
1ausü
1ausz
au3ße
au2t1äu
au4ten4g
au4t3erh
1auto
au2trö
2auts
2auu
2auw
2aux
2auz
auz2w
2a1ü
2a1v
a3v4a
ava3t4
a3vi
a2vr
av2s
2a1w
awi3
awi1e
a1x
ax2am
ax2e
axi2s
2a1ya
a1yeu
aysi1
ay3t
2a1z
a3z2a3
az2i
az2o
az2u
ä1a
äand4
ä1b
ä2b3l
äb2s
ä1che
äche1e
ä1chi
äch3l
ä2chr
äch2sp
ä1chu
äck2e
ä1d
ä2da
ä2d1ia
ä2dr
äd2s
2ä1e
äf2e
äfe4n
äf2f3l
äf3l
äf3r
äf4ro
äf2s
äft2
äft4s
ä1g
äge1i
äge2ra
ä2g3l
äg2n
ä2g3r
äg4ra
äg2s
äg3sc
äg3str
1ä2gy
äh1a
2ä3he
ä1hi
ähl1a
äh3l2e
äh4l3e4be
2ähm
äh3na
äh3ne
1ähnl
2ähr
äh3ri
2äh2s
2äh3t
ä1hu
äh1w
2äi
ä1im
ä1is.
ä3isch.
ä1isk
ä1j
ä1k
ä2k3l
ä2k3r
ä1la
älbe2
äl2bl
äl2l1a
äl2p3
äl4schl
ä1lu
ämi3en
2äml
äm2ma2
ämoni3e
2ämp
äm2s
ämt2e
2än.
än5de
än2dr
2äne
äne2n1
än2f5
änft2
2änge
2än2g3l
än2gr
äng3se
2ä3ni
änk2e
än2k3l
än2kr
änn4e2
äno3
2äns
än2s1c
äns2e
änse3h
2änz
ä1on
ä1pa
äp2pl
äp2pr
äp2s1c
1äq
ä2r3a2
är4af
är1ä
är2b3le
är1c
4äre
ä2r1ei
äre2n
ä2r1ene
är2gr
är1int
är2k3l
är4ment
ärme3s
är1o
ä1rö
ärse2
är2seb
är2si
ärt4e
är2th
ärt4s1
ä2rü
är2zw
ä5s4e
äse3g2
äser4ei
äse4ren
äser2i
äse3t
äskop2
äskopf3
ä3s2kr
ä1so
äs1p
äs2s1c
äs3s2e
äs4s3erk
äs4s1t
äst2
äs2te
ä2str
ä1su
ä1ß
äß1erk
ä2t1a2
ä3te
äte1i
ätein2
äte2n
ä2t2h
ä1ti
ä1to
ät1ob
ät3r
ät2sa
ät2sä
ät4schl
ät4schr
ät2s1i
äts3l
äts1p
ät2s1t
ät4s3te
ät4sti
ät2tei
ät2tr
ä1tu
ät2zw
äu2b3l
äu2br
äu1c
äude3
äu3el
ä2uf
äuf2e
1äug
äug3l
2äul
2äum
äu2ma
äum2s1
2ä2un
äun2e
äu3nu
2äu3r
2ä3us.
äu4schä
äu4schm
äu3se
ä3usg
ä3usk
ä3usn
äu2s1p
äus2s1c
1äuß
äu2tr
4ä1v
1äx
ä1z
â1t
á1n
ba2bl
2babs
bach5t4e
backs2
b1a2dr
2b1af
bah2nu
bahr2e
bais2
ba2ka
ba2k1er
ba2k1i
bak1l
bak1r
ba2kra
3bal
bal2a
bal4lan
balle4b
bal6lerg
bal4li4g
bal4lok
bal3lö3
2b1am
ba2me
ban2a
3b2and
ban2dr
ba3n2e
b1ang
ban3gl
ban2k1a
ban4kl
ban2kr
2banl
2b1ans
ban3t
b1anz
bar3b
bar3de
ba2rei
bar2en
ba4r3ins
bar3n
bar3zw
3bas
ba3s2a
ba2sc
bas4sa
ba2str
ba4t3ent
bauer4l
bauer4s
bau3g
bau3s2k
bau3sp
ba1yo
3b2äc
bä1ch
b2är
b2äs
4b1b
bbe4p
b4be2se
bb3ler
bb2lö
b3bru
bbru2c
bb2s
bbu1
2b1c
bch2
2b3d4
1be.
3bea
be3an
be3ar
3beb
b2ebe
1bec
be1ch
be2del
bedi4
be1eh
be1erl
be1eta
3bef4
be3g2
2b1eier
bei1f4
bei4ge.
beik4
beil2
bei3la
2b1eime
be1imm
b2ein
be1ind
be1in2h
bei3sc
beis2e
bei3s2t
beit2s
3bek
3bel
be3las
bel3d
be3lec
be3lei
be2l1en
be2let
be3li
bel3la
bel3lä
bel3li
be2l3ö
bel3sz
bel3t4
1bem
1ben.
ben3ar
be4nas
be4nä
ben3dor
be3nei
3beng
be3n2i
ben3n
ben2se
ben4spa
ben4spr
benst4
ben2su
3bensv
2bentb
b2enti
bent4r
b1ents
2bentw
be2nu
ben3un
ben3z2
be1o
be1ra
be2rab
be2ran
berb2
berd4
ber4ei.
be4r3eiw
be4rerk
bere4s
ber6gan.
ber4hab
ber4in.
ber3iss
ber3na
b1ernt
be1rop
berö4
ber3st4a
be3rum
ber2zö
3bes
bes2a
be3sak
be2s1er
be3slo
bes2po
bess4e
b3esst.
bes3sz
beste2
be6stein
be4s3tol
be4stor
best4r
be3s2ze
3bet
be2tap
be3tha
bet2to
be1ur
3b2ew
2b1ex
1bez
4b5f4
bfal2
2b1g2
bgas1
bga4st
bge3
bges2
bgus2
2b1h2
bhut2
1bi
bi3ak
bib2
bibe2
3bietu
bik2a
bi2ke.
bi2kes
3bil
bil2a
bi2lau
4b1illu
bi2lu
2b1inb
bin2e
2b1inf
bin3gl
2b1inh
2b1int
bi2o1
bio3d
bi3on
biri1
bi3se
b1iso
bi2sol
bi2sp
bis2s1c
bi2stu
bi2stü
b2it.
b2ita
b2ite
bit4ta4
bi2tu
bi3tum
b2i3tus
biz2
4b1j
bjek4to
2b1k4
bl2
2bl.
bla3b4
b3lad
b5lag
b2lanc
3blat
b2latt
2b3law
b2läse
b2le
3blea
b3leb
3blec
2b3leg
2bleh
2b3leid
4b3lein
blei7s
3blem
3ble4n
b3lese
ble3sz
b4let
b3leu
2blich
3blick
b2lie
2blig
b4lis
b2lit
3blitz
b2lo
b4loc
b3los
2blun
3blut
3blü
2b1m
4b3n2
bni2
bnis1
bo4a
bo5as
b1ob3
bo2bl
bo2br
bo1ch2
bo3d2
boe1
bo2ei
2b1of
bo3fe
bo1is
bo2l1an
3bon.
bond1
bon2de
bo2ne
3bons
b1op
bo1r2a
bo4rä
bor2d3r
bo2rei
bo4rig
b1ort
bor2t3r
bo2sc
bo3se
bo4s3p
bote3n4e
bo3th
bot2st
bö2b3
2böf
b1öl
2b1p2
bpa2g
2b1q
b2r4
2br.
b4ra.
2b3rad
b4rah
b4ra3k
bra3st4
3brä
brä4u
2bre.
3brea
6b5rechte
2b3ref
2breg
b3reif
b3rek
3brem
2b3rep
b4rer
2b3riem
bri2er
b4rio
bro1
b3roh
2b3rol
b4ron
b4ruc
bru4s
brust1
bru2th
3brü
4b1s
b2sad
b3sand
bs3ar
bsat2z
b3sä
b4sär
b5sc
bs2ca
b6schan
b6schef
bs4cu
bs1e2b
b3sel.
bs1ele
bse2n1
b3sen.
bs1ent
bs1er
b2serf
bs3e4r3in
b2sers
b3ses
b3si2t
b4sl
b2s1of
bs1op
bso2r
b2sö
b3s2pi
bs2pl
b3s2pu
bss2
bs2t
bst1a2b
bst3ac
bs3tag
bst1ak
bs3tät
bst1er
b4stern
b2s3tip
b3sto
b4stob
b4stod
b3stö
b3stra
b2s3trä
bs3treu
b2st3ro
b3stü
b4stüb
b3sub
b2s1un
4b1t
b3ta
bta4st3r
b5te
b2th
bt4r
bts2
btü1
bu3ches
bu2chi
bu2e3
bu2f
bug3
2b3umk
bunde4s
b3ungn
b2urg
bu3r4i
4burn
burt4s
bu2sa
bu4s3cha
bu4schl
bu4sch3m
bu4schw
bus1er
bu2si
bu2s1p
bus2sä
bu6s5term
bu2s1tr
bu2s1u
bu3tan
bü1c
bügel3e
2b1v
2b1w
bwel3
by1
by3p
bys2
2b1z2
bzeit1
bzu1
1ca
2c1ab
ca2ch
ca2e3
ca3g4
ca1h
cal3t
c4an
ca2pe
3car
car3n
carri1
ca3s2a3
cas2t
ca3t4h
ca1y2
cä3
cäs2
2cc
c1ce
c1ch2
c2d2
c3do
2cec
ceco4
1ced
ce2dr
2cef
ce1i
2cek
1cen
ce3nu
1cer
cere3
ce1ro
ce3s2h
1cet
2ceta
ce1u
1cé
c1f
c4h
4ch.
2chab
ch3a2bi
2ch1ak
ch2anb
3chanc
ch1ang
ch3anst
2chanz
1chao
2char.
1chara
3charta
cha2sc
1chato
ch1ärm
ch1äs
1châ
2chb
2chc
2chd
ch3e4ben
1chef
3chef.
che4fer
3chefs
2chei
ch1eim
4chelem
che4ler
4chents
4chentw
cher3a
che3rei
6chergeb
cher6zie
ch3ess
2cheta
2ch3e4x
1ché
2chf
2chg
2chh
1ch1ia
chi3na
4chind
3chines
2chinf
2chinh
ch1ins
ch1int
2ch1inv
1chiru
2chj
2chk
2chl2
ch2le
ch2lu
4ch2m
2chn4
chner8ei.
ch2neu
2chob
cho2f
ch1off
ch1oh
chol2a
ch1orc
2chp
ch2r4
2chre
chre3s
ch3rh
1chron
4chs
ch4stal
chst3ri
2cht
2chuf
2chuh
2ch1unf
2chunt
2chü
2chv
2chw
1chy
2chz
ci1c
ci1es
cil3l
ci2s
c1j
4c4k
ck1a
ck3an
cka4r1
ck1ä
ck1ehe
ck1ei
cke2ra
ck2ere
ck1erh
ck2ern
ck1er2r
ck1ese
ck1id
ck1im
ck1in
ck3l
ck3n
ck1o2
ck3r
ck3so
ck4stro
ckt2e
ckt2i
ck1um3
ck1up
c4l2
cle4a
clet2
clo1
1clu
c2m2
1co
co1ch
co2d2
co3di
coff4
coi2
co1it
co2ke
co2le
col2o
com4te.
comtes4
con2ne
co2pe
co1ra
cor3d
co3re
cor3t
cos4
co2te
2cp
c1q
1c4r2
cre2
cre4mes
cry2
2c1s2
c2si
4c1t
cte3e
cti2
cti4o
ction5
ctur6
3cu
cu2p3
cussi4
1cy
c1z
3da.
da1a
2d1ab
d2abä
da2ben
3d2abl
da2bre
dab4rü
2d1ac
d2ac.
dach3a
da2cho
4d3achse
d1af
d1ag
dagi2o
dah3l
da1ho
3dai2
da1in
da1is
dal2a
2d1alar
dal3b2
da3lö
d1alt
d1amma
2d1ammä
damo3
d2amp
dampf8erf
2d1amt
d2an.
2d1ana
dan4ce.
2d1an3d2
d3anei
d1ang
2dange
3dank
dan4kl
dan5kla
dan2k1o
dan2kr
2d1ans
4dantw
2danw
d2anz.
4danzi
2d1ap
d2aph
4dapp
da2r3a
2darb2
dark4
3d2arl
dar2ma
dar2m1i
da2ro
d3arr
3d2ars
d1art
2dart.
da2ru
d2arw
d1arz
dasch4
da3s2h
3dat
dat2a
dat2e2
da3tei
date4n
4d3atl
4d1atm
3dau3e
4d1au2f
d3aug
4d1aus
2d1ax
2d1äh
2d1ämt
2d1änd
2d1äng
2d1äp
2d1ärz
2d1ä2u
dä3us
2d1b4
dbu2c
2dc
d1ch
dco4r
2d1d2
ddar2m
d3dä
d3dh
d5do
1de
de2ad
de3a2t
3deb4
4d1e2ben
3dec
de1ch
de3e4
2d1eff
deg2
de3gl
dehe2
de3ho
2d1ehr
d1ei
3d2eic
3d2e1im
dein2d
dein2s
de3inse
de2l1a4g
de4l3aug
del1än
del1ec
delei4g
2d1elek
2delem
deler4
2delfm
del4lan
dell3eb
del4lei
del4ler
del2lö2
de2l1ob
de2lop
de3lor
de2lö
del2s5e
del2so
del2s1p
del3t4
dem2ar
dement4
de6mentg
2d1emp
d2en.
de4n3end
4denerg
4d3en4ge.
d2enh
de2ni
den4k3li
den2kn
4den4sem
den4s3en
den6s5tau
den3th
2dentw
2deol
de1on
depi4so
d4er.
de1rad
de2rap
der2bl
2derdb
de2re2b
de4reck
de4r3ei4s
derer3
de3r4erb
de3r4erf
de4r3ero
derer4t
derer6ze
d4erfi
d2erh
4der4höh
d4erhü
3derie
derin4f
4derklä
der3m2
4derneu
de1ro
de2rop
derö4
der3r
4der4sat
der4spa
der6t5en6d
dert4ra
6der6trag
de3ru
de4ruh
de4rum
d2es.
de2s1a
desa4g
de4sam
des3an
des1än
de4seh
des1en1
de4s1et
des1in
3desk
des1o
de2sor
de2s1p
de3spe
des5s2
dessa3c
dest5alt
de4stam
de6stant
de4stei
de4stit
dest5rat
de3stri
de3stro
de2s1u
deten4t
2d1etw
de1un
de1url
de3us
devil4
d1exi
de2xis
2dexp
2d1f4
2d1g2
d2ge.
dge2ta
dge4t1e
2d1h2
d2his
1di
di4ab
di2ad
di4am
di4ath
3dic
di1ce
dich1
dich5ter
di2e
di3e2d
di3end
die4neb
di3eni
di3ens.
di3ern
die4s1c
diet3
die2th
dige4s
dik2a
dil2s3
2d1imb
2d1imp
din2a
2d1ind
2d1inf
2d1inh
2d1in1it
4d3inner
2d1ins
2d1int
di2ob
dion5s
di1p
di4re.
di2ren
di2ris
2d1irl
di2s1a2
di2sp
di3s4per
2d1isr
dist2
di2s1to
di4s3tra
di2ta
di4teng
di4t3erl
di4t3erm
di4t3ers
di2t3r
dit1s
di2tu
di5v
diz2
2d1j
2d1k4
4d1l2
d3le
dle2ra
dli2f
dl3m
dl3s
2d3m2
4d5n2
dni2
dnis1
dni3v
d1ob
d2oba
2dobe
dob4l
d2obr
do1chi
2d1o2f
doll2a
do2mar
do5na
doni1
do2o
2dope
2d1opf
d2opp
d2o3r4a
2dorc
2d1ord
dor2f1a
dor2fä
dor2fl
dor2fr
2d1org
dori1
2dort
dor2ta
dor4ter
d2os.
dos3s
dost1
do4sta
dot6h
do2t1o
do3un
d1ö
dö2d
dö2l3
dölla3
d2ön
3d2ör
dö2s1c
2d3p2
2d1q
d2r4
3d4ra.
2d3rad
2drahm
d3rai
3d4ram
d3rand
2d3rast
d3raub
2d3rauc
2draup
2dräd
d4räh
2d3rät
2d3räu
4d5re.
d4rea.
d4reas
3d4reck
2dref
2dreg
3d4reh
2d3reic
d4reiv
4drem
4d3ren
2d3rep
4d3rer
4dres.
d4resc
2d3rh
d3ri
3d4ri.
3d4ria
2d5ric
d4rid
d4rif
d4rik
d4rin.
d4risc
2driß
3d4rit
4dritu
d3rob
d3roc
2d3rod
d4roi
2d3rose
2d3rost
2d3rot
d3rou
2d3rov
d3rö
drö2s1
d5rub
3d4ruc
2d3rud
2d3ruh
2d3rui
4drund
drunge3
2d5rut
drü1b
2d1s
4ds.
d4s1amt
d2san
ds3assi
d2sau2
ds1än
4dsb
d4schef
d4schin
d2s1e2b
d2s1ef
ds1ehr
d3sei
ds2eig
d4seins
d2s1eng
d2s1ent
d2s1erf
d2serh
d2s1erk
ds1err
d2s1erz
dse2t
d4s1eta
d3s2ha
d3sho
d2sid
d2s1im
d3s2inf
d3s2kan
d3skul
4dsl
d2s1op
dso2r
ds1ori
d2sö
d2s1par
ds1pas
d2spä
ds2pe
ds2po
d3spri
d2spro
ds2pu
dss2
dst4
d4stabe
ds3tauf
d4s3täti
d4stea
ds2til
ds2tip
d2s1tis
d2stod
ds1ums
d2sun
ds2zen
2d1t
dta2d
dtam3m
d3tea
d2th
d4thei
dt3ho
dto2
dt3r
dtran2
dt5s2
1du
du1alv
du1ar
dub3l
du2bli
du2f
2d1ufe
2d1uh
du1i
2d1umb
2dumd
2d1u2m1e
2dumf
2dumg
2d3umk
2duml
d2ump
2dumr
d1ums
d2ums.
2d1umv
2d1un3d
dund2a
2d1unf
2d1ungl
dun3ke
dun2kl
2dunr
dun4st3r
2dunt
2dunw
du1o
5dur2c
2d1url
2dursa
du4schn
du4schr
du4schw
2düb
3düf
3dün
2d1v2
4d1w
dwa2
dwest1
dy2s1
2d3z2
2e1a
e3a2b
eab3l
ea3der
eadli4
ea2dr
ea2g4
ea3ga
ea4ge
ea3gl
eakt2
e3akto
ea2la
e3alei
ealer2
e4aler.
eal5le
eal3lö
eallö3s
e2alti2
e2ame
eam3m
eam1o
eam3t
ea2na
e2ano
e3ar.
ea2ra
e4are.
ea4rene
e4arer
e4ares
ea2sc
eas5s
eat4e2
eater1
e3ath
eat3s2
e3at3t4
e3au2f
e3aug
eau3st
e3ä4
e1b
2eba
e3b2ak
2ebed
ebe2i
2ebel
eb2en
e3ben.
ebens3e
e3ber
ebe4rel
ebert4
2ebet
2ebl
eb2laß
eb3ler
eb4leu
e3blie
eb3lo
eb2lö
2eb2o
ebö2s
2ebr
eb3rei
eb4ru
eb2s
eb6sche
ebse2
ebs1i
ebs1o
ebs1p
ebs3pa
eb4stät
ebs3t2h
eb4s3ti
eb4s3tot
eb3str
ebs1u
2e3bu
ebu2t1
2eca
e1ce
ech1ä
2e1che
ech1ei
e6ch5erzi
ech3l
ech3m
ech3n
e2cho.
ech1o2b
e2ch3r
ech3t4ei
e1chu
ech1uh
ech1w
e1ci
eci6a
eck3se
eck4sta
2eckt
2e1cl
2eco
eco3d
2ect
e1d
e3d2a
ed2dr
ed2e
ede2al
ede3n2e
eden4se
eden4s3p
ede2r
edert2
edi4al
2edip
e3d2o
ed2ö
eds2ä
ed4seh
ed2s1es
ed2s1o
ed2s1p
ed2s3tr
ed2su
edu2s
e3dy3
4ee
ee3a2
eeb2l
ee2ce
ee1ch
ee2cho
eede3
eed3s2
ee1e
e1eff
eef4l
eeg2
e1ei
ee1im
eein4se
eei5se
eel2e
e1e2lek
ee5len
e1emp
e1en
eena2
ee4nag
e2enä
e2enc
e2eno
een3s
e1e2pi
ee2r3as
e1erbt
e1erd
ee3r2e
ee4r3en4g
eere4s1
ee1ro
ee1rö
eer2ös
eert2
e1ertr
ee3r2u
e1erz
ees2
ee3sh
ees3k
ee3ta
ee4tat
ee1u
eeu2f
eewa4r
e1e2x
e1f
2ef.
2efa
e2f1a2d
ef1ana
ef1ar
e2fat
e2fäu
2efe
e3fe.
e2f1e2b
efell4
ef1em
e2fent
ef2er
efeuil4
2eff.
ef2fä2
3effek
1effi
ef2fl
2efi
ef1id
e2f1ins
efi2s
1efku
2efl
e3f4lu
2e3f2o
e3fra
ef3rea
ef3rol
ef3rom
ef4rü
efs2
ef3so
ef3sp
ef2tan
ef2tei
2efu
e2fum
2efü
e1g
eg1d4
e3ge
ege4ler
ege4n3a4
ege4nec
ege2ra
ege4s3to
ege4str
ege1u
e2glo
e2glu
e2gn
eg3nä
eg3ni
eg4sal
eg4s3e4r1
eg3si
eg4sin
egs2pe
eg4sto
egs3tü
eg2th
2e1ha
eh1ach
eh2al
e2hap
eh2aus
2e1hä
e1he
eh4ec
eh1eff
eh2el
ehe5na
ehen2t3
1e2hep
e3her
ehe1ra
e1hi
eh1int
ehis4
eh1lam
eh1lä
ehl3ein
eh4lent
eh5l2er
eh2lin
eh3lo
ehl2se
2ehm
eh3mu
e1ho
e3hol
ehr1a2
ehr1ä
ehr1ec
eh2rei
ehr4erf
ehr6erle
ehre3s
eh3ri
eh1ro2
ehr1ob
ehr1of
eh2s2
eh3sa
eh3se
eh3sh
eh3si
eh3so
eh3sp
eh3sta
2eht
e1hu
e2hunt
e1hü
eh3üb
eh1w
e1hy
2ei3a2
ei2bar
ei2bl
eibu4t
ei4b3ute
ei2cho
eich5te
e2id
ei2d1a
ei3de
eid4ein
ei4d3er4r
2eidn
ei3dra
ei1e
ei3el
4ei3en
eienge4
eie4s
eif2e
1eifr
ei3g2a
4eigeno
eig2er
2eiges
2eigew
ei3gl
1ei2g3n
2eigru
2eigt
2eigu
eik2ar
ei3kau
eik4la
e4il
2eil.
ei2lar
ei2lau
2eilb
eil3d
ei4lein
eile2n1
eil3f4
ei4l3ins
2eiln
1eilzu
ei2m1a4g
eim3all
ei2mor
e1imp
eim2pl
e4i2n1a
ein3a2d
ei4nas
ei4nä
ein3dr
2eindu
ei4neng
ei2neu
2einfo
ein4fo.
ein4fos
ein3g2
ein4hab
e1init
eink4
ein6karn
3einkä
3einkom
ein3n2
1einna
ei2n1o2
1einri
e4insa
3einsat
e3insta
ein6stal
ein4sz
1einu
e4inver
ei3o2
ei1p
eip2f
2eir
ei3re
e1irr
e2is.
ei2sa4
ei6schin
ei4s3erw
eis2pe
ei3spru
eis5sac
ei2str
ei2sum
e4it
ei2tab
ei2t1an
ei2tar
2eitä
ei3te
ei2th
ei2tor
ei2tro
eitt4
eit3um
2eiu
2e1j
e1k
ek2a
1ekd
e3ke.
e3ken
e3kes
e3key
e3k2l
ek3lip
ek4n
ek2o
2ek4r
2ekt
ekt4ant
ekt3erf
ekt3erg
ek4t3er4z
ekt2o
ek2u
e3k2w
e1la
ela4ben
el3abi
el2abt
el3a4der
e3ladu
el1af
ela2h
e2l1ak
el3al
e2l1a2m
e4landa
e2lanm
el1ans
el1anz
2elao
e2l1ap
e2l1a4r
el3ari
el1asi
el1asp
el2ast
2e1lä
3elbis
el2da
eld3erh
elder4p
eld5erst
el3des
eld3s2
e3lea
2elei
e6l5ei6er.
e6l5ei6ern
el1ein
e4leinf
e4leing
e4leinh
e2l1el
1e2lem
e3lem.
el1emp
2e3len.
e4lense
e4l1ent
e3lep
e2l1erd
el1erf
e4ler4fa
e2l1erg
el1erk
el1erl
e4ler4la
e4l3ernä
e4ler2ö
e2l1err
eles2
el1ess
e4l1e2ta
e3leu
2elev
ele2x
1elf.
el3fe
elf4l
1elfm
1elft
elg2a
elgi5er.
elgi5ers
elg4r
e2l1id
e3lie
e2lim
el1ita
2elk
elks2
elk3sc
ella3d
el3lan
el2lap
ella2s
el2lä
el3läd
ell3ein
el3ler
el2leu
el3lie
el2lil
el3l2in
el2log
el2lot
ell3sp
el2lu2m
el2lü
2eln
el5na
2elo
e2lof
e2lol
elon2
e2l1or
elo2ri
el2sum
elt2ak
el3te.
el5ten.
elter4b
3eltern
elter4s
el3tes
elto2
elt3r
elt1s2
elt3sk
2e1lu
el1ur
el3use
e1lü
e2lya
2elz
el2zar
elz2e
el2zwa
e1m
2ema
em1ad
ema2k
e2m3anf
e2m1ans
3emanz
em4d3a2
e3m2en
emen6gel
emen4t3h
e2m1erw
1e2meti
e2m1im
emi5na
em1int
emi3ti
2emm
em2map
emma3u
e2mop
1empf4
em3pfl
em2sa
em3se
em2spr
em3t2
1emul
2emü
e2n1a
4ena.
2en2ac
en3ack
e3nad
e4naf
4enah
e4n3a2k
ena3l2i
enal3p
4enam
en2ame
e4nand
en3ang
e4nanz
en3are
ena4sc
4enat
en3att
e3naue
en1ä
e2när
enä4s
en2ce.
en3d2ac
en2dal
en4d3ess
end4ort
end3rom
end3s2p
end3sz
end2um
2ene.
ene4ben
en1ec
e2neff
en2eid
e3neien
e4nein
e2n1el
ene4le
2enem
2enen
e4n1ent
en4entr
4e3ner.
e2n1erd
e2nerf
1e2nerg
e4nerh
e4nerk
e2n1erl
e4n3ermo
4enern
e2n1err
e2n1ers
e2n1ert
e2n3eru
e2n1erw
e4nerz
2enes
e2n3ess
en3f
enf2a
enf2u
1engad
3engag
enge3ra
en3g2i
en3glo
en3gn
1engp
eng1s
eng3sc
eng3se
2eni
e3ni.
e3nic
e2nid
e3nie
eni3er.
eni5ers.
e2n1i4m
e2n1in
e3nio
eni2ö
e3nit
en3k2ü
e2n1o2b
enob4le
e2nof
en1oh
e3nol
eno2ma
en1on
e2n1op
e2n1o2r
eno2s
enost3
e3not
eno2w
2e1nö
en1ö2d
en3sac
en2sau
en5sche
en2seb
3ensem
ensen1
en2sep
en3ska
en3s2po
enst5alt
en4s3tät
en6s5test
2ensto
ens5trie
e4nt
ent4ag
ent4ark
1entd
en2teb
en4terb
en3tes
1entf
2entfo
1entga
3entgeg
en2thi
3entla
1entn
en4t3rol
3entspr
1entw
4entwet
1entz
en1u
e2nuf
e2num
2enut
e1nü
4enwü
e1ny
enz1ec
en4z3erf
en4z3erg
en4z3erk
e1ñ
2eo
e1o2b1
e1of
eo2fe
e1oh
eo3m
e1on.
e1ond
e1onf
e1onh
e1onl
e1onr
e1ons
e1ope
e1opf
eop4t
e1or
e3or.
e3orb
e3ors
e3orw
eos2
e3os.
eota2
eo3ul
e1ov
e1ö2
e1p
epa2g
e3p2f4
e2pis
1episo
2epl
ep3le
1e2poc
ep2pa
ep2pf
ep2pin
ep4pl
ep2pr
ept2a
ep2tal
2e3pu
epu2s
e1q
er1a
e3ra.
era2be
e3rad.
er3adm
eraf4a
era2g
e1rai
er3aic
e2rak
e1ral
er3all
eran3d
e3rane
er3anf
e2ranh
er3anm
e1rap
er3apf
e2rar
e3rari
e1ras
e2r3a2si
er4ast
era2ß
e2rath
e3rati
e2ratm
e1raub
er3aue
erau2f
er3aug
e1raw
e1raz
e1rä
er1äh
er1äm
e2r1ä4s
erb2e
erb2sp
er1c
er3chl
erda3me
1erdb
er3de
2erdec
erde3in
er4d3en4g
erd3erw
4ere.
er1eb
e3rech
er3echs
er1eck
er1edi
ere4dit
er1eff
er1e2h
2e3rei.
er1eig
e2rein
e4r3eis.
ere2l
er1ele
ere3lev
2e3rem
e2remp
2eren
e3ren.
e3rena
e4rense
e4rentf
e4rentn
e3renz
eren8z7en8d
er1ep
2erer.
e2r3erf
e2r1erh
2erern
e3rero
er1err
er1ers
e2rert
er1erw
2eres
er1ess
er1eß
e4r3e4ti
er1eul
ere4vid
erf2e
er3f4r
4erfür
3ergebn
4ergehä
erg3els
1ergol
4ergrem
e2rh
1erhab
4erhals
er3he
4erhöhe
er3hu
2erhü
2eri
e2riat
e3rib
4e3ric
er1i2de
eri3e4n3
eri5ers.
e3ri3k4
4e3rin.
er1inb
e2r1ini
er1ink
er1ins
er1int
e3rio
er1ita
2erk.
1erklä
2erkli
er3ko
2erkre
erk3t
2erlag
3erlebn
4erln
erm2e
ermen4s
erm3ers
er4nerk
ern1os
e1ro.
er3oa
er1o2b
e2r1o2f
e1rog
e1r1oh
e1rok
e1rol
e1rom
e3ron
er3ony
er1op
e4ro2r
e1ros
e1rou
e1row
er1ox
e1roz
erö2d
2erök
er1ös
er3p4
er3rä
er5rei
erri3er
2errü
ers2a
ersch2
er5schn
er3se
er3s2i
er3sk
er3smo
er3sn
er3sp
er3sto
er3sz
ert2ak
er6terei
er4t3erf
er4ter4h
er4ters
er2t3ho
4erti
ert3ins
erts2e
2ertür
2eru
eruf4s
er1u2m
er1und
er1uns
er3uz
erü4b
3erweck
e1s
e3saa
es3ab
e3sac
esa2d
es2an
es4and
es4ank
es3ant
e3s2as
e3sat
e4s3ato
es3av
e3säc
es2äu
2esb
esbi5er.
e3sc
es2ca
es3cap
es2ce
esch2l
esch2n
e4sco
e4scu
es1ebe
e3seg
es1ehr
e2sein
es3eva
2esf
4esh
es2har
e3sie
e2s1il
es1ini
es3int
e3sit
es2kat
e4s3ke
e4sky
es2log
2esm
eso2r
es2ort
es2ö
2esp
es2pek
e3spi
e3s2por
e3s4pra
es2pu
2esr
es2saa
es2sa2c
es2saf
essali3
es2sau
es2sä4
es3säu
4essem
es6sendu
es4senf
essen6so
ess4e3re
ess3erg
essi4gn
essi4mu
es2si2t
2esso
es2sof
es2s1pa
es2spu
es4ste
es2sub
es4suc
es4summ
es2sü
estab4b
est1ak
e3stan
e4starb
1e2stas
es2tau
es2te
este2c
e4st3eng
e4st3erh
e4st3ess
e5stev
e3sti
e4stip
estmo6de
e2stod
est3ori
2estro
es3trop
es2tu
e3s2tü
es2ty
e2s1um
es1ur
e3sy
eße3r2e
e1t
e3ta.
etab4
etal4la4
etal6li6n
et1am
eta2mi
1etap
etari1
et4at
et1äh
2e3te
e4t1ein
ete3ke
et2en
eten3d2
ete2o
eter4hö
eter4tr
et2h
et3hal
et3hü
e3ti
eti2m
eti2ta
2eto
eto2b
e2t1of
e2torg
2etr
e4traum
et3rec
e4tres
etsch3w
et1s2p
et1su
etta2
et2tab
et2tad
etta3ge
et2ta4s
et2tau
et2tä
et2tei
ette4n1
et4teu
et4th
et2tö4
et2t3r
et4tro
ett3sz
et2t1um
et2tur
et2tü4
etwa4r
2etz
et2zä
et4z3ent
etze4s
et2zw
eu1a2
eu3b4
euen2g
eue6reif
euer4ri
eu2e5sc
2euf
eu2fer
eu2ga
eu4gent
eu3g2er
eug1s2
eu1in
1euk
eu2kä
e1um
e3um.
e3umb
e3uml
e3um2s
eums1p
eum3st
2eun
eun2e
eu4nei
eun4er
e3un2g
eu2nio
eun3ka
eu1o2
eu1p2
e2u3r2e
1euro
eu2rys
eu4sis
eu3sp
eust4
2eut
eut2h
eut6schn
2eux
eu2zo
eu2z1w
e3ü
2e1v
e2vela
e2vent
4ever
eve5r2i
e3vo
ev2s
e1w
2ewa
e3wä
ewä2s
2ewe
e2we.
e3wir
ewi2s
e3wit
ew2s
2ex.
ex3at
1e2xem
ex1er
e1xi
2exie
e2x1in
1exis
ex3l
3exp
2ext.
ex2tin
ex2tu
2exu
2e3xy
ey2n
eys2
e1z
e3z2a
e2z1enn
e3zi
ezi2s
ez2w
é1b
é1c
é1g
é1h
é1l
élu2
é1o
é1p
é1r
é1s
é1t2
é1u2
é1v
é1z2
è1c
è1m
è1n
è1r
ê1p
1fa
3fa.
fab4
f1abe
fa2ben
2f1a2bl
fab5s
fa4cheb
fa2ch1i
fa2cho
fa2ci
f1ader
fa2dr
f4ah
faib4
fa2ke
f2al
fa3l2a
fal2kl
falla2
fal4lei
fal6lenk
fal6l5er6k
fal2li4
fal6scha
fal6schl
fal6schm
fal3te
3fam
f1amt
2fanb
2fanf
fan2gr
2f1ank
2fanl
f1anp
2fanr
fan3s
2fanw
f1an3z
2f1ap
f2ar
far2br
2f3arc
3fari
farre2
far4rec
far4reg
f3art
2f3arz
3fas.
fa3s4a
fa3sh
f3at
fa2to
2f1auf
f3aug
fau2s
f1ausb
3f4av
fa2xa
1fä
fä1c
fäh2r1u
f1älte
2f1ärm
f1ärz
fä2ßer
2f1b2
2f1c
2f3d4
fdie2
1fe
featu4
f2ech
2f1eck
fe2dr
fe2ei
fe1em
fef4l
feh4lei
f4eie
2f1eing
4f1einh
fe1ini
2f1einw
f1ei3s
fek2ta
fe2l1a
fel4da
fel2dr
2f1e2lek
fe2l1er
fe2les
fel3la
fel4lei
fe2l1o
fel4soh
fels2t
fel3t
f2em.
fem4m
2femp
fen3a2
fe2nä
fe2no
fen3s2a
fens2c
fens2t2
fen6stri
f1ent
3fep
f2er.
fe1ra
fer2an
fe4rang
fe4r3anz
fe2rau
fe2r1ä
ferde3
f2ere
fer2er
fer3erz
f1erfa
fe2rid
3ferk
f2erl.
4ferneu
fe1ro
f4erpa
f2ers.
fers2t
f2ert
f1erw
fer8zeuge
fes4t
fe2st1a
fe4st3ei
fe2str
2f1eta
fe2tag
3fete
fet2t3a
feuer3e
feu4ru
3few
f1ex
2fexp
3fez
1fé
2f1f
ffa2b
ffa2ce
f3fal
ff1ans
ff3ar
ff4arb
ff4art
ffa4s
ff1au
ffa2z
ff2e
ffe2e
f2f3ef
ff3ei
ffe1in
ffel3l
ffe2m
f2f3emi
f2fetz
f2fex
f2fil
ffi2xi
ff3lag
ff3li
f3flu
f3flü
ffo2
f2fö
f3f4rä
ff2sa
ff2sp
ffs3tan
4f3g2
fge3s
2f1h2
1fi
3fi.
fi3at
fi1er2f
fi2kin
fi3kl
fik1o2
fi2kob
fi2kr
fi2l1an
fil4auf
fil3d
fi2les
filg4
fi3li
fi4lin
fil2ip
f2ina
fi3ni
2f1int
fi2o
fi3ol
fi2r
fi3ra
fi4re
3fis
fis4a
fisch3a
fisch3o
fisch3w
fi3so
fis2p
fit1o2
fi2tor
fi3tu
3fiz
2f1j
4f1k4
f2l2
2fl.
f3lad
f5lan3d
f3lap
1flä
3f4läc
2f5läd
f3län
2f3läu
2f3leb
2f3lein
f3ler
f3li.
3f4lim
fli4ne
2f5lon
1f4lop
1f4lot
flo2w
f3lö
4f5löf
1f4lug
flu4ger
f4lü
f5lüd
f5lüm
2f1m2
fma2d
2f3n2
fni2s
1fo
fob2l
2f1o2f
foli3
fol2k1
fo2na
fon3au
fon2e
fo2nu
2f1op
fo1ra
4f3org
fo3rin
for4m3a4g
forni7er.
for4sta
for4sti
fort3
for4tei
for2th
for2t1r
fort1s
for3tu
f1o2x
1fö
2fö2f
2f1ök
2f1öl
4f1p2
2f1q
f2r2
f4rac
frach6tr
2f5rad
fra4m
f3rand
f5rap
1f4rän
2fre.
f3rec
f3red
2freg
f3reic
freik2
frein2
f3rep
3f4reu
2f3ric
fri3d
fri2e
2frig
1fris
f4risc
fri6ster
f3roc
1f4ron
fro2na
fro2sc
f3rot
f3ru
f3rü
4f1s
fs2amm
f2san
fs3ar
f2s1as
f2sauf
f2saus
f2saut
f3sc
f4sce
f4schan
f4schef
f2s1e2b
f4sehr
f2s1em
f2s1ent
f2s1er
fse2t
f4s1eta
fsi2d
f3s2kie
f2s1o2
f3span
f2s1pas
f2sph
f3spi
f3s2pl
f3s2por
fs1pr
f2spre
fs2pri
f2spro
fs2pru
fs3s2
f2stas
f4s3täti
f5stel
f2stip
f2s1tis
fst4r
f4s3tres
fs1trü
f3stü
f4s3tüte
f2sty
f2s1un
f3sy
4f1t
f2ta.
f2tab
ft1a2be
ft1af
f2t1al
ft1an
ft1ar
f3tat
f2t1äu
ft1e2h
ft1eig
ft1ein
ft1eis
f2t1ent
f2t1e4ti
f2th
f4thei
ft3ho
f2t1id
ft1op
f2t3ot
f2t3ro
f2trö
f3t4ru
fts1
ft2sa
ftsa4g
ft4sam
fts2c
ft4sche
ft2se4
ft4seh
ft2si
ft4stä
ft4ster
ft4stes
fts2ti
f2tum
ft1url
ftwa4
ft3z2
1fu
3fuc
3fug
3f2uh
f1um
2f1unf
2f1u2ni
fun2kl
fun2ko
fun2k3r
2f1unm
2funt
f2ur
fu4re.
fus2sa
fus4sei
fus6senk
fus2so
fus2s1p
fus4s1t
fu2ß1er
3fut
1fü
2füb
fü2r
2f1v
2f1w
1fy
2f1z
fz2a
fzeiten6
fzei8tend
fz2ö
fzu3
fzu4ga
f3z2w
3ga.
2gabf
ga2b5l
gab4r
2gabz
ga1ch
2gadl
2ga2dr
ga1fl
ga1k
ga2ka
gal2a
2g1a4lau
g4amo
2g1amt
2ganb
gan3d
4gangeb
gan2gr
2ganh
2g3anku
2ganl
g3anla
3g2ano
gans2
2ganw
ga1ny
3gar.
2garb
2garc
3gard
2g1arm
ga3r2o
3g2ars
2g1arti
ga3ru
2g1arz
ga2s
ga3sc
gas3ei
ga4sem
ga3sp
ga4spe
ga4spr
gas5s
gas3tan
ga4st3el
ga3str
ga4stra
gas4trä
ga4stre
gas1tu
gat2a
2g1atm
gat4r
gau1c
2g1auf
2g3aug
g2auk
g1aus
2g1aut
2g1äp
2g1ärz
gäs2
gä4u
2g3b2
gbau5s
gber2
gbi2
2g1c
2gd
g1da
g2d1au
g2d1er
gd1in
g1do
g1dö
gd3r
gd3s2
gdt4
gd1ur
1ge
ge3a2
geb2a
gebe4am
ge3ble
geb4r
ge1c
ged4
ge1e2
ge3ec
ge2es
gef4
ge3g2l
ge3ha
ge4ig
ge1im
ge2in.
gein2s
ge2int
gein2v
ge1ir
ge2is
2g1eise2
gei3sh
gei4sta
2gek.
ge4lanz
gelb1r
gel4b3ra
gelder4
gel6ders
ge3le
2g1e4lek
geler3ö
ge4l3ers
ge4less
gel3l2a
gel3le
ge3lor
gel3sa
gels2p
gels2t
gel3sz
gel3t2a
ge3lü
gelz2
gem2
gem4e
ge3mi
3gen
ge3na
ge4n3ac
ge4nam
ge4nar
gen2as
gen4aug
gen2d1r
gen1eb
ge3nec
gen3eid
gen3ern
gen6erwe
gener4z
gen3n
gen3sz
2gentf
gen3th
4gentw
ge2nun
geo2r
ge1ou
ge3p4
ge1ra
ge2rab
4g3ereig
ge4reng
ge4ren4s
ge4r3ent
ger2er
gerin4f
ger4inn
gerin4t
ger3no
ge1ro
ge1r2ö
ger4sto
ge3r2u
g1erwa
4g3erwer
ges2c
ges3elt
ge2s1er
ge3s2i
ges2p
ges4pi
ges3sä
gess2t
gest2
get2a
ge3tan
2getap
ge3t4u
2g1e1ul
2g1ex
2g1f4
4g1g
gga2t
g3ge
gge2ne
g2g3l
gg4lo
g2g3n
gg4r
2g1h
4gh.
3ghale
gh2e
3g2het
3g2hie
gh1l
3gh2r
g2hu
gh1w
gi3alo
gia2s
gie3g
gi2e1i
gi2el
gien2e1
gift5s
gi2gu
gi2m
gi4mes
2g1ind
gi3ne
g1inf
gin2ga
2g1ins
2giok
2g3isel
gi3t2a
gi4us
2g1j
4g3k2
4gl.
gl2a
4g1lab
g1lac
g2lade
2g1lag
2gland
gla4s3ti
gla4stu
3g2laub
4g1lauf
g1läß
2gläuf
g2l4e
2gle.
3gle3a
2g3leb
g3lec
g3leg
2gleh
3gleic
4g3lein
glei4t5r
g3len
4g3ler
2gles
g3lese
g4lia
2glib
3g2lid
g2lie
2glif
g2lik
2glil
g2lim
4glin
g2lio
2glis
g3lisc
3g2lit
g2liz
3g2loa
3g2lob
4g3loch
glo3g
3g4lok
g2lom
3g2lop
g2lor
3g2lot
2glös
2gls
g1lu2
2g3luf
2glun
4glu3s
g2lut
g1lüg
g2ly
2g1m2
gmül3
2gn.
g2n2a
g4na.
4gnah
3g4nat
3g2nä
gn2e
g3neh
2gnel
gne2tr
2gneu
2gng
g2nie
g2nif
g4nin
2gni2s1
g2no1
g3not
2gnp
2gns
2gnt
2gnu
3g2num.
g2ny
2gnz
go4a
goa3li
2g1o2f
2gog
2g1oh
go1i2
gol2a
2gonis
2g1ope
2g1opf
g2o1ra
2g1ord
2gorg
go2s
go3th
got6t5erg
go1y
2g1p2
2g1q
g2r4
gra2bi
gra2bl
2g3radl
2g3rah
4g3rak
grammen6
gram8m7end
grau3f
gräs1c
2g3räu
2g5re.
g4reb
2g3rec
2g3rede
g4re2e
2g3reic
2greim
2g3rein
g3reit
g3rek
g4rem
2g3renn
gre3no
gren6z5ei
g4rer
g3ret
g3rev
2g3ric
gri2e
g3riese
3grif
2grig
2g3ring
gro2bl
2groc
2groh
gron4
2g3rose
grosse4
gros8seri
g4roß
gro4u
2gröh
g4ruf
2g3rui
2g3rum
grun2g
3g4rup
2grut
2g3rüc
3g4rün
4gs
g2sa
g3saa
gs1ac
gsa2d
gs1af
gs1ag
g4s3a2k
g3sal
gs3all
g4salt
gs3ama
g4s1amb
gs3an
gs3ar
gs1as
g3sat
gs1ä
g3sät
g4sca
g4sce
gsch4
g4schef
g5schü
gs3cr
g2s1e2
gse3e
gs2eh
g3s2eil
g3sel.
g3seln
gsen1
gser5f
gse3ri
g2s1i
gsi2d
g5sil
gs3l
gs1o2
gs1p4
g3s2pek
gs4pie
gs3pl
g5s2por
gsrat4
gs3s2
g3star
gs1tau
g4s1tä
g5stäm
g5stel
g4stemp
gst3ent
g4sterm
gst3err
g4s3test
gst2he
g3sti
gs1tis
g3sto
g4ston
gs1top
g4s1tor
gs1tot
gst4ra
gst5reit
gst4ri
gst5rit
gst3ros
gs1trü
g3stun
gs1tü
gs2tüc
gs1u
g3sub
g5suc
g3sün
g3sy
2g1t
g3te
gti2m
gt4r
gt4se
1gu
gu1an.
gu1ant
gu1as
gu4d3r
gu2e
2gued
guet2
2g1u2f
2g1uh
gu1ins
gu1i4s
3gumm
2g1unf
g2ung.
gunge2
4gungew
2g1ungl
2g3unk
g2uns
2gunt2
3gur
4g1url
gurt3s
gu2s3a
guschi5
gus4sam
gus4ser
gus2sp
gus4st
gu3sti
gu2ß1
gu2t
gut1a
gu4t3erh
gut3h
2güb
gür1
gü3st
2g1v
2g1w
2g3z2
3haa
hab2a
hab2e
2habn
ha2cho
ha2del
ha4din
h1adle
haf3f4l
haft2s
hafts3p
h1ah
h2ahs
ha3ia
h2aj
2haka
ha1kl
2h2al.
halan4c
ha2lau
hal2ba
hal4bei
hal4b3r
2hale
hal4lei
hal6lerf
hal4leu
hal4lok
h1alp
halt5r
h1amt
h2an.
2hanb
h2and
han2da
han2kr
h4ann
2hanr
2hant
hao2s
h1ap
ha2pl
ha2pr
h2a3ra
2harb
h2ard
h1arm.
har3ma
har4me.
har4mes
har2th
h1arti
h2as
2ha3sa
hasi1
ha2ß1
hatt2
hau5f6lie
2h1aufm
h1aukt
hau2sa
hau2sc
hau4spa
hau4s3ti
hau4sto
h2aut.
hau6terk
2hauto
hau2tr
h1äff
h1ärz
hä6s5chen
häu2s1c
hä3usp
2h1b2
hba2r3a
2h1c
2h3d4
hdan2
2hea
he2ad
hea5t
he3be
he4b1ei
he2bl
he3br
he1ch
he3ch2e
h3echt
hed2g
he3di
he2e3l
hee2s
he2fan
he2fä
he2f1ei
hef3erm
2heff
he2fid
he4f3ing
he2f3l
he2fr
he3fri
he2fu
he3gu
h4eib
h1eie
h1eif
h1eig
he2im
heim3p
hei4mu
2hein
heine2
4heio
he1ism
he1i4st
heit4s1
h1eiw
he2l3a
hel1ec
h3e2lek
he3len
hel3ers
he3li
hell3au
hel4mei
he3lo
he4lof
he2lö
3hemd
he3mi
3hemm
4h3emp
h2en.
he4na2
hen3a4g
he2nä
he2n1e2b
hen3end
hen3erg
he2net
heng2
2heni
he2no
hen3sk
hen3s2t2
h1ents
2h3entw
he2nu
hen3z
4he2o
he3on
he3op
he3pa
he3ph
h2er.
her3a2b
he2ral
2herap
he3ras
herau2
herb1r
her4b3ra
he4reck
4hereig
he4r3eis
he2rel
he4rerw
h1er2fo
h3erfü
herg2
her2ho
2herif
herin4f
he6rin6nu
herin4s
herin8ter
h1erke
h3erlau
2herm
he3ro
he4r3o4b
h1erö
hers2t
hert2
her3th
her2z1w
he2tap
heter2
he3th
het2i
he3t4s
h2e2u
heu3g
3heusc
he3x
he1x2a
he1y2
1hè
2h1f4
hfell1
hfel6ler
hfi2s
2h3g2
hget4
2h1h2
hhoh2
4hi.
2hia
hi2ac
hi2ang
h2ias
hi1ce
hich6ter
2hi3d
h2ide
h1i4di
hi2e
hi3ens
hier1i
hie4rin
hif3f4r
hi2kr
hi2l3a4
hil2fr
hi2n
h1indu
hi3nel
hin2en
h1inf
h1inh
hi3n2i
hin3n2
hi3no
hin2t1a
2hio
hi4on
hi3or
2hip1
hip3f
hi2ph
hi2pi
h2i2r
hi3ra
2hi3re
hi3ri
hirn1
hir4ner
hi3ro
hir2s
his2a
hi4se
hi2spa
hi3ti
2hiu
2h1j
2h1k4
4hl
hl2ag
hlam8meng
hla2n
hl1anz
h1las
h1lat
h1laut
h3läche
h3läd
hl1är
h1läs
h1läß
h1läu
hlb4
hl3d4
h3leb
hle3e
h3lein
h2leis
h5len.
hl2eng
hl2enn
h3ler
hle2ra
h2l1erg
h6l3er4nä
hle3run
hl1erw
h4lerz
h3les
h4lesi
h3lex
hlg4
h2lie
h2lif
h2lim
hl1ind
h2lip
h2lis
h3list
h2lit
hl3l
hlle3b
h2lo
h3loc
hl1of
hl1op
h4lor
hlo2re
h3losi
h2lös
hl2ser
hl3sku
hl3slo
hlst4
hls2te
hl2sto
hl3str
hl3t2
h3luf
h3luk
h3lumpe
h1lüf
2h1m
h2mab
h3mad
h3mag
h3man
h3mar
h3mas
h3maß
h3mä
h4mäc
h4mäh
h4mäl
h3me.
hme1e
hme1in
h3meist
h3men
hmen2s
hme2ra
h2mo
h4mon
h3mö
hm3p4
hm2s1p
h2mu
h3mul
h3musc
h3musi
2hn
h2na
h3nam
hn1an
h3nau.
h2nä
hn1äh
hn1är
hn3d4
hn2e
hne3b
hne2e
hn3eig
hn3ein
h2nel
hne4n1
hne4pf
h3ner
hner3ei
h4nersa
hn3ex
hnhof8stras
h2nic
h2nid
h2nie
hn1im
hn1in
h2nip
hn3k4
h2nor
hn3s2k
hns2t
hnsuch4
hnts2
h2nul
hn1unf
ho2bl
ho2c
hoch3
hock3t
2hod
hoe4
ho2ef
ho4fa
hof3fa
ho2f3r
2hoi
3hole
ho2l1ei
hol3g4
ho4lor
3hols
h1o2ly
3holz
hol6zene
hom2e
ho2mec
ho2med
h2on
hond4
hono3
2hoo
2hop
ho1ra
hor3d
2h1org
ho3se
ho4sei
ho3sl
ho4sta
ho2str
2hot.
ho3th
hotli4
2hot1s2
3hov
2ho2w1
h1o2x
ho1y2
hô1
1h2ö
hö2c
3höhe
h4ör
hö4s
hös1c
h3öst
2h3p2
h1q
2hr
hra2b
hr1ac
hr3ad
h1rai
h1rane
h3räu
hr1c
hr3d
h2rec
h3rech
h3red
h3ref
h4rei.
hrei4ba
h3reic
h4r1eig
h3rel
h3ren
h3rep
hr4erbe
hr4erbu
hr2erg
hr2erk
h4rer4la
h3rerle
h6rer6leb
hr6erlei
hr2erm
hr2erz
h3re2s1
hre2t
h2r1eta
h3rev
hrg2
h2ri
h3ric
h4rick
hri4e
h3riesl
h3rin
h4rinh
hr1ins
h4rist
hr3l
hrm2
h2rob
h2rof
h3roh
h3rol
h4rome
h4romi
h4ron
h2ror
h3rou
hrr4
hr2s1ac
hr2s3an
hr2sau
hr3sch
hr2s1en
hr2ser
hr4set
hr2s1in
hrs3k
hr2s1of
hr4stec
hr2su
hr4sw
hr2t5ab
hr2tan
hr2th
hr2tor
hrt3ri
hr2tro
hrt2sa
hrt2se
hrt4ste
h3ruh
hr1ums
h3rü
h4rüb
h4ry
hrz2
4h1s
h4s3acht
h2sa2d
h4samt
h2san
h2sau
h2säh
h3sc
h4schan
h2s1ec
hse4ler
h2s1erl
h3s2ex
h2s1ing
h2s1o2f
h2spac
h2s1par
h2spel
hs2pen
h2sper
h2sph
hs2por
h2sprä
h2spro
hss2
h2staf
hst3alt
hst2an
h4starb
h2stau
h2stäl
h4stea
h5stel
hst2he
hs1tie
h2stin
h2s1tor
h3stö
h3str
hst3ran
h2stu
h3stun
h3stü
h2s1u
h3sub
hs2ung
h3sy
4h1t
ht1a
h2tak
h3t4akt.
ht2al
h2talo
ht3alt
hta2m
h2ta4n
ht3ane
h3tank
h3tann
h2tar
ht2as
h2t3ass
h2tasy
h2t3a2t
h2tau
ht3aug
h2tax
h2t1är
h3te.
ht1ec
h2t1ef
ht1eh
h3teha
h3tehä
hte2he
h2teif
h4teilz
h2t1eim
ht1ein
h2t1eis
h2t1eke
h4t3elit
h2temp
h4tentf
h4t3ents
hter6de.
ht3erfü
ht3ergr
h2t1er2h
ht5erken
h4terkl
h6t5erleu
h4t3er4re
h6t5er6spa
h4t3er4st
ht6erste
h2t1erz
h2t1ese
h2t1ess
h2t1eu
h2t1ex
h2th
h4thei
hthe3u
h2t1im
h2t1in
h4tl
htni2
hto2
h2toly
h2torg
ht3rak
ht3rand
h2t3ras
h2t3rat
ht3rau
h4traub
ht6raume
h3trec
ht3reif
ht3reit
ht4ri
ht5rieg
h2t5rin
h3trit
ht3ro
h2trol
h2tros
ht4rot
ht3rös
h2t3ru
h2t3rü
h4ts
hts3an
ht4s3end
ht4spin
ht3spri
ht4stab
hts2ti
ht4s3tur
ht4s3tür
htt4
htti2
htu2e
h2t1urs
ht3z2
hu2a
hu2b1a
hu2bei
hu2b1en
hu2b3l
hu4b3r
hu2bu
hu2h1a
hu2h1i
huk3t4
hu2l3a
hu2lä
hu2l3ei
hu4leng
hu4lent
hu4ler
hu2let
hu2l1in
hul3l
hu2lo
hu3m2a
h1ums
hu2n
h1una
hu3ni1
h1ups
2h2ur
hurg2
hu3sa
hu2so
hus2si
hus2sp
hus4st
hu2tab
hu3t2h
hu2ti
hut2t
hut4zen
hut4z3er
h2ü
h4übs
h3übu
hühne4
2h1v
hvi2
hvil4
2hw
h2wall
hwe1c
h1weib
h1weih
h2wirr
3hyg
hyl4
3hyp
hy2pe.
2hy2t
2h1z
hz2a
hz2o
hzug4
i1a
2ia.
i4aa
i2ab
iab4l
2iac
i2af
iaf4l
i4a3g2
i2ah
i3ai
i2aj
i2ak
i3ak.
i3akt
2ial
i5al.
ia2l1a4
ia2lä
ial3b
ial3d
i3alei
i3alent
i3a4lerf
i3alerh
ia4l3erm
i3a2let
i3a4lia
ialk2
i3al5l
ia2lor
ial3s
ial3t4
ia2lu
ial3z2
i2am4
i4amo
2ian
ia2nal
i3and2
ian2e
i3ann
i2a3no
i3ant
i3anz
i2ap
ia3pf
ia1q
i3ar.
ia2ra
i2asc
ia3sh
i2asi
i2a1sp
ias5s
iast4
i3at.
i3a2ta
i4ate
i3at4h
1iatr
i3ats
i3au
ia3un
iau2s1
2iav
2iä
i1äm
i1äp
i1är.
i1ärs
i1ät.
i1äta
i1ät3s4
2i1b
ib1art
i2b1auf
ib3be
ib2bli
ib1ei
i2beig
i2beis
ibe4n
iben3a
ibi2k
i3bla
i4blad
i3blä
i3ble
i4bleu
ib2o
i2bö
i4brä
ib3ren
ib2ser
ib4ste
i2bunk
i2bunt
ibus1c
2ic
ic1c
ich1a
ich1ä
i1che
ich1ei
i1chi
i2chin
ich3l
i3chlo
ich3m
i1cho
i2ch3r
ich3ter
ich2tr
i1chu
ich1w
i1ci
icks2
ick3sa
i1cl
i1d
id2ab4
i3d2ac
i3dam
id1au
1i2dee
idein3
i4deis
idel2ä
ide3sa
ide3si
ide3so
1i2dio
idni3
i2dol
1idol.
2i2dr
i3dsc
id2s1p
idt4
1i2dy
ie3a4
ie2bä
ie2bl
ie2bre
ie2bri
ieb4sto
ieb4str
ie1c
ie2cho
ie2dr
ie1e2
ie2f1ak
ie2f1an
ie2fau
ief3f4
ief2i
ie2f3l
ie2fro
ie4g3l
ie3g4n
ie2g3r
ie3g4ra
ieg2s
iegs1c
ieg4s1t
i1ei
i2e2l1a
ie3las
iel3d
i2ele
iel1ec
ie3lerd
ieler8geb
ie4less
i2eli
i1ell
iel3lä
ielo4b
i2els2
iel3sz
iel3ta
2i1en
i3en.
i3ena
iena2b
ie4n3a4g
i3e2nä
ien3d
i2ene
ien1eb
ie3ner
ien4erf
ie4n3erg
i3enf
i3eng
ienge4f
i3enh
i3enj
i3enk
i3enm
i3enn
i3e2no
i3enö
i3enp
i3enr
ien3s2e
iens2k
ien6st5er
ien6stop
iens4tr
ienst5rä
ien3sz
i3env
i3enw
i3enz
ie1o2
iera2
ier3ad
ier3an
ie2r3ap
i2ere
ie3red
ie3r2er
ie4rerf
ie4r3erz
ie3res
i3ereu
ierf4
i4eri
ierin3
ier3k4
ierken4
i1ern
i3ern.
i4erna
i2er5ni
ie2rö
iers2e
ier4s3eh
ier3sta
ier3te
ies2p
ie2spu
ies2sp
ies4s1t
iest6e
ie3su
ie2t1a
ie4t3erh
ie4t3ert
ie2t3ho
ie2t1o
ie2t3ö4
ie2tri
ie2t3ru
iet2se
i1ett
ieu2e
ie1un
ie2w3u
i1ex
2if
if1ar
i2f3arm
if4at
if1au
i2fec
ife2i
if2en
if1erh
if2fa
iffe4s
if6feste
if2fl
if4form
iff2s
if3l
i1f4la
if4lä
i1flü
if3r
if4ra
i1frau
i1fre
if4rei
if4rü
if3sa
if2ta
ift3erk
if2top
if2t3ri
ift1sp
ifts2t
ift3sz
2i1g
iga1i
i2g1ang
ig1art
iga3s
i4gefar
ige4na
ige2ra
ige3ran
ig1erz
i2g1im
i2gl
ig1lä
i4glo
ig4na
i4gnä
i3g4neu
ig4no
i3go
ig4ra
ig3rei
ig3s2a
ig4sal
igsau4g
ig4se
ig1so
ig1sp
ig2spa
ig4sti
ig4s1to
ig2stö
ig4s3tre
2i1h
i2h1am
i2har
i3he
ihe1e
ihe4n
ih3m
ih3n
ih3r
ih2s
ih3sp
i2h1um
ih1w
ii2
ii3a4
i1ie
i3i4g
i1im
i1in
i1i4s
i2is.
ii3t
i1j
2i1k
ik1ak
ika4ka
ik1amt
i2k1ano
ikanten8n
ik1anz
i4kanze
ik1art
ik3att
i2k1au
i2k1är
4ike
i2k1ei
ik2e2l1
i2k1e4r2e
ik1erf
iker6fah
i2k1er2h
i2ker2l
i2k1eta
i3ki.
ik1in
i2kind
i2k3l
i3kla
i3k4lä
i2kn
ik3no
ik2o3p4
ikot3t
i2köl
ik3ra
ik3rä
ik3re
ikro3
ik3so
ik3s2z
ikt2e
ikt3erk
ikt3r
ik2tre
i3kus
i1la
i2l3ab
il1a2d
i2l1ak
i2l3a2m
il1ans
il1asp
il1au
il4aufb
il3aus
i2laut
i1lä1
4ilb
il2c
il2da
il4dac
il4d3en4t
il3d2er
ild1o
il2dor
il2dr
il1ec
ileid4
il1ein
il1el
i4lents
i2l1erf
i2l1erg
i2l1err
il2erz
il2f3l
il2f3re
ilf4s1
ilg2a
il2gl
ili3e4n1
ilig1a2
ili4gab
i2l1ind
i2l1ip
i3lip.
i3lips
2ill.
il3l2a
il4lad
ill4an
il2lä2
il2leg
ille4ge
il3l2er
ill2i
2ills
il2mak
il4mang
il2m3at
il2m1au
il2min
2ilo
i2l1or
ilt2
il3th
il3tr
i1lu2
i2lum
i3lus
ilv4
il2zar
ilz3erk
2im.
i2manw
i2m1arm
im4at
ima2tr
imat5sc
ima4tur
2ime
i2mej
i2m1ele
i2melf
i3men
i2m1erf
i2m1erz
i4mesh
i2meti
i2m1inf
i2m1ins
im4m3ent
im4mit
im4mod
imni2
2imo
im1org
imp2fa
1impo
imp4s
im3pse
1impu
im2str
2imt
imtu2
2imu
in1ac
in3ach.
i4nack
i2n1ad
in2af
ina4lin
in1am
i3nap
in2ars
in2art
ina2s
i2n3au2
inaus1
in1äh
in1äs
in2dal
in2dan
in3dau
indes4t
1index
in3do
2indr
ind4ri
in3drü
1indus
in3d2ü
2ine
i2n1e2be
in1ehe
i2n1eng
in3erbe
i4nerbi
in2erh
iner4lö
i4n3er4tr
i3nes
i4nesk
in1eu
ine3un
ine2x
in3f
1info.
1infos
2inga
ing1af
in2g1a4g
in2gl
ing3sc
ing4sto
1inhab
2inhar
2inhau
4inhe
in2i3d
2inig
ini3kr
in2ir
2inis
ini3se
i3nitz
3inkarn
ink4ste
in3k2ü
inma4le
2inn.
in4n3erm
in2neu
in4ni2v
2innl
in2nor
inn4sta
1innta
2ino
in1od
in3ols
in1or
ino3t
i1nö
in1ö2d
2inp
2inr
ins2am
in3sat
insch2
2inse.
in2seb
2insen
ins3ert
in3skan
in3skr
in4s3tät
ins2te
ins2ti
in3su
1insuf
in4s3um
in3s2z
i4nt
2inta
1integ
int2h
in3t4r
int3s
i2n1u
in2um
in3unz
invil4
i1ny
i1ñ
2i1o
ioa4
io1c
io2d
i2oda
io3du
io3e2
iof4l
i2o3h
io2i3d
io3k4
i3ol.
i3om.
i3oms
ion2
i3on.
ional3a
io2n3au
ion3d
i3on4s1
ions3p
ion3t
i2ony
i2o1p
io4pf
i3ops
i3opt
i2or
i3or.
i3orc
iore4n
i3orp
i3ors
i3ort
io3s
i2ost
ios2u
i3ot.
i3ots
i2ou
i2ov
io2x
i3oz.
i1ö2k
i1ön
i1ös.
2ip.
i1pa
i1pe
ipen3
i3per
iph2
2i1pi
ipi3el
ipi3en
i3p4l
ip2pf
ip2pl
i1pr
2ips
2ipu
2i1q
i1r2a
i3rad
1i2rak
irat2
i1rä
ir1äh
ir2bl
ir1c
ir2e
i3ree
2irek
irg2
ir2gl
irg4s
ir2he
ir2i
2irig
2irk
ir2k3l
irli4n
ir2mak
ir2mau
ir2mä
ir2m1ei
ir2mum
ir4m3unt
2irn
ir2nar
ir2no
i1ro
1iron
i1rö
irpla2
ir2rei
irre4l
ir4reli
irr2h
ir4schl
ir4schm
ir4sch3w
ir3sh
irt4s1t
2iru
iru2s1
i1s
i3saa
i3sac
i4s1amt
is2ap
is3are
i3sat
i2sau
i2s1än
2isb
i2sca
i3s2che
i4schef
i4sch3e4h
i4sch3ei
i2sch1l
isch3le
i2schm
isch3ma
isch3ob
isch3re
isch3ru
i4schwo
isch3wu
i2s3cr
2ise
ise3e
ise3ha
ise3hi
ise3inf
i4seint
ise2n1
ise4n3a
is2end
isen3s
i2serh
i2s1erm
iser2u
i2s1ess
i4s3etat
is2has
isi2a
i2s1id
i4sm
i2s1of
iso2n
isonen4
iso6nend
is1op
3i2sot
2isp
is1pa
i2spar
is1pe
is1pic
is2por
i2spro
is3sa
is4saa
is4s1ac
issa4n
is4sau
is3sä
is4sä4l
is4s3che
is2sei
is3sie
is4sper
is2s1t
is3sta
is4ste
is3sto
is3stu
issu2
is2sub
is4suc
is2sum
i2stab
ist3ac
i4stam
ist2an
i4stea
iste4n
is2ter
ist4ra
is3tras
ist3re
is1trü
i2stur
is1tüm
i2sty
isum3p
i2sü
i1ß
iß1ers
i1ta
it1ab.
i3tag
ital1a
ital5l
it1alt
it1a2m
it1ang
it3a4re
it1art
i3tat
it1au
i3tauc
i2tauf
i2t1ax
4i1tä
i2t1äs
ität2
i1te
i2tei
i4t1eig
i4t1ein
2itel
ite2la
ite4n
itens2
i4tepo
i2tex
i3thr
i1ti
i2t1id
1itii
iti4kan
iti3k2e
i2t1in1
it2inn
i3tis
it3iss
i3tiv
i4tl
itmen2
i1to
i3toc
i2t1of
i1tö
i1tr
i3tra.
it3raf
it3ran
it3ras
it3rau
it3räu
it3re
it3rom
it4ron
i3tru
it3run
it2sa
its1a4g
it2s1e4
its3er1
it4stec
it4s3tem
it4s3tes
it2sti
it4stie
it2s1to
it6stras
it2teb
it4temp
it2tri
i1tu
it1uh
i2t1um
i2tuns
it1urg
itut4
i1tü
2itz
it2zä
it4z3er4g
it2z1w
2i3u2
ium1
ius1t
i1ü
2i1v
i2v1ak
iv1ang
i2veb
iv1elt
ive4n
iv1ene
i2v1ent
iv1erl
i2v1ur
2i1w
iwur2
2i1x
i2xa
ix2em
ixt2
4i1z
iz1ap
iz1au
iz2ei
izei3c
ize2n
i2z1ene
iz4er
i2z1ir
izo2b
i2zö
i2z1w
í1l
jah4rei
jahr4s
ja3l2a
ja3ne
jani1
jani3t2
2jat
je2a
jean2s
je2g
jek4ter
jektor4
jek2tr
je3na
je2p
je2t1a
je2t3h
je2t3r
jet3t
je2t1u2
ji2a
ji2v
joa3
jo2b1
job3r
jo2i
joni1
jo1ra
jord2
jo2sc
jou4l
j2u
ju2bl
jugen2
jugend3
ju2k
jung5s
ju3ni
jur2o
jute1
2j1v
1ka
3ka.
k1a2a
ka3ar
kab2bl
ka2ben
2kabh
2kabla
2kablä
2k1a2bo
ka3b4r
2kabs
2k1abt
ka1c
k2ad
2k3ada
2k3a2dr
ka1f4l
ka1fr
kaf3t2
k2ag
ka1in
ka3ka
kaken4
ka1k4l
2kakt
2kala.
ka2lan
ka3lei
ka3len.
ka4lens
kal3eri
kal2ka
kal2k3l
kal2kr
k1all
kal3lö3
kalo5
kal2tr
ka2lu
k3ama
kamp8ferf
kan2al
ka4n1a4s
ka2nau
kand4
2kanda
kan2e
2k1ang
kank4
2kanl
2k1anna
k1ans
k2ans.
6kantenn
ka3nu3
2kanw
k2anz.
ka2o
2k1apf
3kara
2karb
k2ard
k2arg
kari3es
k2ark
2k1arm
karp3
kar2pf
k2ars
kar3t
k2arta
2k1arti
karu2
k2arw
kasi1
ka2sp
kas3s
ka3tan
ka3t4h
ka2t3r
2katt
kau2f1o
4kaufr
kauf4sp
kauf6s5te
k1aus
kau3t2
2kauto
1kä
k1äh
k1ä2mi
k1än
kär2
kä2s1c
käse3
kä3th
2k3b2
kbe1
kbo4n
kby2
2k3c
2k3d2
kdamp2
2k1ec
k1eff
kefi4
kege2
ke2gl
ke2he.
kehr2s
kehrs3o
kehr4st
2k1eic
2k1eig
k1ein
ke1in2d
2keinh
2k1eise
ke2l1a
ke3l2ag
ke2lä
kel3b4
2k1e2lek
ke2len
ke2l1er
2kelet
kel3la
kell4e
kel3li
kel3s2k
k4elt
2k1emp
k2en.
ken3a
ke4nac
ke2nä
ken3dr
4ken4gag
2kenlä
ke2no
ken4sem
kens2k
ken5s4te
ken3sz
k3en4te.
k3en4ten
ken3th
2k1ents
2kentw
2kentz
2keo2
ke2pl
k2er.
ke1rad
k2erc
ke3reig
4kerfah
k4erfam
k3ergeb
ker6gebn
k3er2hö
ke6rin6nu
kerin6st
kerin4t
ker4ken
k2erko
k2erl
k4erl.
ker4lau
k3er4leb
k6erlebe
k4erlö
ker4neu
k1ero
ker4reg
k2ers.
kerz2
k1erz.
ker4zeu
2k1er2zi
k6es.
ke2sel
ke2t1a
ke2t3h
ket3s
ke1up
keu6schl
2k1e2x
2k3f4
2k1g2
2k1h4
kho3m
ki3a4
ki1ch
2k1i2de
ki3dr
ki2el
kie2l3o
ki1f4l
ki1f4r
ki3k4
2kil2a
ki3lo
k2imi
k2in.
k2ing
2kinh
k2ini
k2inn
ki3n4o
kin3s
2k1inse
2k1int
ki3or
kio4s
3kir
kis2p
kis5s
kist2
kiv2
2kiz
ki3zi
2k3j
2k1k4
kl4
4kl.
4kla.
4kland
k4lar
4k1last
k3laug
k2le
4kle.
kle2br
k3lee
4kleh
k4leid
4k3leit
k3lem.
2k3ler
kle2ra
2k3leu
kle3us
2klic
2klig
k2lim
k2lin
k2lip
k2lir
k2lisc
2klist
klit2s
4kliz
2k3loc
klo2i3
k3lor
2klos.
klost6
k2löt
k1lu
k2lud
kluf2
k2lug
k1lüc
2kly
2k1m
kmi2
k2n2
3knab
k3ne
k4nec
k4nei
2knes
kni4e
kno4bl
2k5nor
k3nu
3knü
1ko
ko2al
2kobj
2k1o2fe
koff4
koh3lu
ko1i2
kol2a
ko3le
kol2k5
3kom
ko4mu
k2on
ko3n2e
kons4
ko3nu
2kop.
ko1pe
kop4fen
2kops
2kopz
ko1r2a
2k1orc
kor6derg
ko3ri
kor4n1a
k2os
ko2s1p
ko3ta
kot1s2
kot4tak
2k1ou
3kow
ko2we
k1o2x
1kö
kö2f
k1öl
2k1p2
2k3q
k2r4
2k3rad
k4ral
k3rats
2kraum
k4raz
k4räc
k4rän
2k3rät
2k3räum
2kre.
2k3rec
2kred.
2k3rede
2k3ref
2kreg
k3reic
kre1i2e4
kreier4
k3reih
2k3rh
2krib
2k3ric
k3ries
2krip
3kris
3k4ron
2kruf
krü1b
2k1s
k4s1amt
k2san
ks4ana
k2sau
k2s1äl
ks2än
ksch4
ks1e2b
k2sent
ks1erl
k2s1ers
k2s1erw
k3shi
k2s1id
k2s1in
k2s1o2
k3son
k4sor
ks1pa
ks2pat
k3s2pe
ks2por
ks2pu
kss2
kst4
k2stal
k4s3tanz
kstat4
k4stea
k2s1tis
k2s1tor
k2strä
k2stum
k2s1u
ks2zen
4k1t
k2t1ad
k3tag
kt1akt
k3tal
kt1am
kt1an
k2t3a2r
kta4re
k2t3au
ktau2s
ktä3s
kte3e
kt1ei
k2temp
k2tent
k4t3erfo
k2t1erh
kte3ru
k2tex
k2th
kt3ho
k2t1id
kt1im
k2t1ing
kt1ins
kti4ter
k2t1of
k3top
k4torga
kt3orie
kt4ran
kt3ras
kt4ro
kt3run
kt3s2
ktt2
k2tuns
kt3z
ku1c
ku2h3
2k1uhr
kul2a
ku3l2e
ku3l2i
2kulp
2k3uml
kum2s
k2u3n2a
kun4s
kunst3
2kunt
2kunw
2k1up.
kur2bl
ku2rei
kuri2e
ku2ro
kur2sp
kur4st
ku4schl
ku2sp
ku2su
ku2ß
1kü
kü1c
kür2s
2k1v
2k1w
2k3z2
kze3l
3la.
3l2ab.
la3ba
2labb
lab2br
4l3aben
2labf
2labg
2labh
2l1a2bl
lab2o
l2abr
lab4ra
lab4ri
2labs
l1abt
3labu
2labw
la1ce
la2ce.
1lad
lad2i
l1adl
2ladm
2l1a4dr
l1adv
2laf
la2fa
laf3t
la2ga
la2gio
la2gn
lago2
la2g1ob
lag3s2e
2la1ho
1lai
lai4s1t
la2kes
la2k1i
l2akk
la1k4l
2l1al
4lalp
l2ami
la3min
lammen8ge
1lammf
l2amp
4l1amt
lamt4s
la4mun
l1anal
la2nau
2lanb
3l2and
lan2d1a2
lan4d3au
lan6d5erw
lan6d5erz
lan2dr
lan4ds
laner2
2lanf
lan2gl
lang3s2
l2anhe
2lanl
4lanli
2l3ann
l1anp
2lans2
4lansä
2lantr
lan2z1w
3lao
2l1apf
l1a2po
lap4pl
la2r1an
la2r1ei
la4rene
3l2ar3g
lar3ini
l2armi
2l1ar3t
l3arti
la2ru
la2sau
4lasd
la5se
3lasg
2lash
2lasi
la2so
2la2sp
las4sa2
3lasser
la2sta
last1o
la2str
las3tur
la2stü
1la2ß3
lat2a
la3t2e
la4tel
2l3ath
la2t3ra
lat2s
2lat2ta
lat4tal
lat4tan
lat4t3in
lat2t3r
1laub.
laub4se
lauf1i
lau4fin
lau2fo
1laug
3laun
l2aus.
2lausl
2lausr
2lauss
2lauto
1law
lawa4
lä1c
2läf
2l1ähn
1länd
lär2m1a
l1ärz
lä2s1c
4lät
2läub
2läuc
2läue
1läuf
1là
4l1b
l3bac
lbb2
l2b1ede
lb3eise
l4beta
l2b1id
l2b1ins
lb2lat
l3blä
lb3le
l2bli
l3blo
l3brec
lb3rit
lb2s
lb3sa
lb3se
lb4sh
lb3si
lb4sk
lb3sp
lb4st1e
lb4sto
lb2u
l2b3uf
lbzei2
2l1c
lch2au
l3che
l4chei
l5chen
l3chi
lch3l
lch3m
lch3n
lch3r
lch3s
lch3ü
lch1w
l3cl
l3co
4l1d
ld3a2b1
l3d2ac
ld3ack
l2d1a2d
lda4g
l2d1ak
ld1al
l3dam
ld1amm
l2d1a2n
ld3ane
l2d1a4r
ld3ari
l3das
ld1au
ld1är
l3de.
l2deh
l2dei
l2dele
l3der.
l3d2erl
l3d2ern
l2d1er2p
lder4tr
lde5sa
l2d1e2se
l2dex
ldi2c
l2d1id
l2d1im
l2dob
ldo2r
ld2os
ld2ö2
ld3r
l2dran
ld4ros
l3d4ru
ld4rü
ld3sa
lds2t
ldt4
ld3th
l2d1um
ldy3
ldys2
1le
3le.
le2a
le3an
le3ar
3le3ba
leben4s
le2bl
2lec
lech5t4e
3led
4ledd
le2er
lef2a
le2g1as
le2gau
le2gä
le2gl
3leg4r
3leh
leh3re
4lehs
4leht
lei4bl
lei2br
l2eic
l2eid
4l1eig
le2im
l2ein.
l2eind
lein4du
l2eine
lei6nerb
4leink
l1einn
l2eint
l2einu
lei6schw
leis6s5er
lei4str
lei4ßer
l2eit
lei2ta
lei8t7er8sc
lekt2a
2lektr
3l2ela
2l1e2lek
l2eli
lel3s
3lemes
le2m1o2
4lemp
l1emu
l2en.
le4nad
le2nä
4lendet
2lendu
4lendun
le4n3end
4lenerg
l1engl
le3ni
l2enk
2l1enni
le2no
len4sem
len3sz
2lentf
l1ents
2l3entw
lent4wä
5lentwet
len2zi
le1os
2lep
3lepa
3lepf
lep4pi
3lepr
l2er.
l2e1ra
le2ra4g
le2rap
le2rau
lerb4
l3erei4g
ler6eign
le4r3ei4m
le4rers
2l1erfo
l2erfr
l2erfü
l3ergeb
3lergeh
l3ergen
3l4ergew
2l1ergi
lerin4s
lerk2
l2erka
l2erko
l4erlei
le1ro
le2rob
2l1erö
3l2erra
l4ers.
lers2k
3lerw
l4erwa
2lerwo
2l1erz
l2erza
ler2zi
les2am
les2e
2l1esel
le3sh
lesi1
le3sk
les2ko
le2spo
les3s
leste3
4lesw
2lesy
le2tat
2le3th
let2to2
le2u
4leud
3leut
2lexe
le2xis
2lexz
2l1f
l3fah
l2f1ec
lfe1e
l4feis
l3f4lä
lf3lo
l3f4lu
lf3ram
lf2s
lf4spe
lf4s1ti
lf2tr
lf4u
lfun2
lfur1
l3fü
2l1g
lg1art
l3gas
lga3t
lg1d4
lgen2a
lge3ra
lgeräu3
l2geti
lg2lö
l3go
lgoa3
lg3re
l3gro
lg2s
lg4s1t
2l3h2
3lhi.
1li
3l4ia
li3ac
li2ad
li3ak
li3ar
lib4
libi3
li1c
3lic.
li3chi
4lick
li3d2a
2l1ido
li4ds
l2ie
liebe4s
li3ene
lie4s1c
lif2fo
3lig
lig4n
li2gre
ligs2
li3ke
li3ko
lik2sp
lik4ter
li3l2a
li3li
li3m2a
2l1imb
3limo
2limp
li3n2a
lin3al
2l1indu
li4ned
li2nef
li2neh
li2nep
li2nes
2l1inf
ling4s3
2l1inh
2l1in1it
2l1inj
lin2k1a
link2s
li2nol
l2ins.
l2insa
l2insc
2linsp
2l1int
li3nu
l1inv
2linz
li2o
li4om
lion5s
li3os.
li2p3a
2li2po
3lipt
3lis.
li3s2a
li4schu
2l1isl
2l1i2so
li2sp
liss2
2liß
li2tal
li3te
li1t2h
lit1s2
lit3sz
li2tur
3liu
liv2e
livi1
2lixi
li2za
lizei3
4l1j
2l1k
lk1alp
l3k2an
l3kar.
lken3t
lk2l
lk3lad
lk3lic
l2k3lö
l3k4lu
l3k2me
lk4ne
lk5ner
lkor2b1
lk4ra
l2k3ru
lk2s1
lk3sä
lk4stä
lk2ü
2l1l
ll1abb
lla2be
l2labt
lla2de
ll1aff
ll1akt
l3l2al
l2l1a2m
ll3ama
lla2n
ll2anw
ll1anz
ll1arm
lla6tern
l2lau
ll3aufg
ll3aufk
ll3aug
ll1aus
l4lausf
l2la2w
l2läd
l2l1äm
l2läu
llb4
llch4
ll3d4
l2le2b
l3lec
ll1ech
l2l1ef
lle2gu
lle2he
l2leib
ll1eim
ll3eise
ll2em
l3len.
lle4n3a
ll3endl
llen3dr
ll3en4du
ll2eng
l4lents
l3ler.
lle2ra
l6lereig
ller4fo
ller6geb
l6lergen
l4lergo
ll3ernt
ll3ertr
ll6erwei
ll2es
l2le2se
l2leuc
l3leur.
l2lex
llf4
llg4
l2lic
l2lieb
l2lieg
l3lik4
lli4la
ll1imp
l2l1ind
l2l1ins
llin6sen
llk4
ll5m
lln2
ll1ob
l2lobe
l2lo2d
l2l1of
llo2gi
ll1opf
l2l1o2r
l3lor.
l3lore
llo2te
l2l1ou
l3löh
ll3sä
ll3sh
ll3s2k
ll2spr
ll4stor
ll3t
llti2m
llt4r
llts2
llu2d
llu2f
llu2me
l2lu2p
ll1ur
llust6
l2lüc
llü2d
ll3z2
4l1m
l3ma.
l2m3a2b
l2marc
lm1art
lmä4s
lm1äst
lm1c
lm2ei
lm3eins
lme4na
l2m1e2p
l2m1erz
lm1ind
lm1ins
lm3m
l2möl
lm3p
lmpf4
lm3s2z
lm3t
4ln
lna4r
ln3are
l3n2e
l3ni
l1nü
1lo
lo4ak
3l2ob.
lo2ber
2lobj
2l1o2bl
l2obr
lob4ri
3lodr
l1o2fe
lo1fl
lof4r
lo2gau
lo3h2e
2l1ohr
loi4r
3lok
lo2k3r
lol2a
l1o2ly
lo2min
l4on
lo2n1o
lo2o
2lopf
lop2pr
2lopt
lo1ra
lo2rak
lo4rä
5lorb
2lorc
l1ord
lo3ren
2l1or3g2
3los.
lo4sa
3lose
lo4ske
lo2spe
loss2e
lo4steu
lo2s3to
lo2s3t4r
lo2ßu
lo2ta
lo3tha
loti4o
2l1ov
lo2ve
2lox
1lö
lö2b3
2löck
2löd
l2ö2f
2l3öfe
4lög
l1öhr
2l1ö4l
4löß
2l1p
l3pa
lpe2n3
lp2f
l2p1ho
lp3t4
l3pu
2l1q
2l3r2
lrat4s
lrut4
lrü1b
4l1s
l3sac
l2sa2d
l3s2al
l4s1amb
l4samt
l2sanf
l2sang
l2sann
l2sanz
l3sare
l2sau2
ls2äm
l4schin
l4schmü
l2s1e2b
l2s1ec
l2s1em
ls1ere
ls1erg
ls1erl
l2s1ers
l2s1erw
l3ses
l3s2ex
l4s3ha
l2s1id
l2s1imp
ls2log
ls3ohne
l4s3ort.
ls2ö
l2spac
ls2pe
l3s2pi
ls2po
ls2pu
l3spul
ls3pun
ls3s2
lst2a
lstab6
ls2taf
l4s3täti
l2s1tis
l2stit
ls1tor
l4stor.
l4store
l4stors
ls2tr
ls1um
l2sun
6l1t
l2tab
ltag4
lt1ak
lt1am
l3tami
lt3and
lt1ang
l4tarm
lt1art
l2t3ato
l2t1au
lt1eh
lt1ein
l2t1eis
lte4lem
l3t2en
lten6gel
lter3a
lter2f
l3t2erg
lter6ken
lter6leb
lter4nä
lt2erö
lte3se
l2t1esk
lte3str
l3tet.
lte2th
l2t1eu
l2th
l3thas
lt3ho
l3thu
ltimo4
l2tob
l2t1of
l2t1o2ri
lto2w
lt1öl
l3tön
lt1ös
lt1öt
lt4rak
ltra3l
lt3räu
l2t3re
lt4rie
lt3roc
lt3ros
l2t3rö
l4ts
lt1spa
lt4stab
lt5ste
ltt2
lt1uh
l2t1um
ltu4ran
ltu2ri
lu1an
4lu4b3
luba2
lubs2
lu2dr
lu2es
1luf
2l1ufe
2luff
luf2t1a
luf2t1e
luf2tr
lu2g1a
lu2g1e2b
lug3erp
lu2gi
lu4g3l
lu2go
lu2g3r
lug3sa
lu2gu
2l1uh
lu1id.
lume2
2lumf
2l1umj
2lumk
2luml
1lumpe
2l1ums
l1umw
1lu2n
2l1una
2l1unf
4l1uni
2lunt
2lunw
4lu2o
lu2pf
2lur
l1urn
l1urt
2luse
lu2sp
lus4sa
lus2sä
lus2s1c
lus4see
lus4seg
lus4sei
lus4sek
lus6senk
lus6sent
lus6serf
lus6serk
lus6sers
lus4si2
lus2so
luss3or
lus2s1p
lus4s1t
lussu2
lus4suc
1lus2t
lu2st1a
lu4stä
lu3str
lust3re
lu2s1u
4lu2ß1
lu2t1a
lu4teg
luter2
lu4t3erg
lut1o2f
lu2top
lu2t3r
lut5schl
3lux
2lüb
2lüd
lüh1l
2l1v
4l3w
2lx
1ly
ly1ar
ly3c
2lymp
3lyn
ly3no
ly1o
lys2
ly3te
ly1u
2l1z
l2z3ac
l3z2an
l2z1ap
lz1ar
l2z1är
l3zen
lz2erk
lz1ind
lz3l
lzo2f
l2zö
lz3t2
l2z1u4fe
lzug4s
lz1w
lz2wec
1ma
maa2
m1ab
m2abe
2mabk
3m2ab4r
2mabs
ma3chan
mach4tr
ma2ci
ma3da
m2ade
2madm
ma2d4r
ma4d2s
ma1f
ma2ge.
ma2geb
ma2gef
ma2geg
ma2gek
ma2gep
ma4ges.
ma2get
ma2gev
ma2gew
2m1agg
magi5er.
magi5ers
2magm
ma3g4n
2m1ago
mai4se
2m1akt
mal1ak
ma4lakt
ma2lan
ma4l3at
ma2lau
ma3le
mal2er
mali1
mal3l
mallö3
2mallt
malu4
ma2l3ut
mam3m
2m1anal
ma2nau
2manb
man4ce.
man3d2
man3ers
ma2net
m2anf
2m1angr
m2anh
2manl
m4ann
man3s
2mansa
2mansä
2mansc
man4sh
2mantw
manu3
2manz
ma2or
2m1apf
m2app
2m3arb
mar3g2
mar2i
4ma3r2o
maro3d
4marr
mar6schm
mar6schr
ma3r2u
m3arz
3mas.
ma1s2pa
2m1aspe
3mas2t
ma2ta2b
ma2tan
mat4c
ma2tel
ma4t3erd
mat3se
mat1sp
mat3url
2m1au2f
3maul
ma3un
2mausg
m4ay
ma1yo
1mä
2m1ähn
mä1i2
4m1änd
3männ
2mäo
m1ärg
mä1t4r
mäu2s1c
2m1b2
mbe2e
mb6l
m3b4r
2mc
m3ch
2m1d
md1a
m2d1ä
m2dei
mds2e
m2d1um
1me
meb4
me2ben
m2e1c
medi3
medie4
medien3
2medy
me1ef
mee2n1
mee4r3ei
mega3
3meh
2m1eif
2m1eig
mei3l2
mein4da
m2eis
me1i2so
me3lam
me2lau
3meld
me2lek
me2ler
melet2
2melf.
mel2se
mel2sp
mel3t4
6mel6tern
2m1e2mi
2m1emp
m2en.
mena2b
me3nal
men3ar
men3au
2mendl
men3ge
m4ens
men4sk
men2so
men3ta
2mentn
ment4sp
4m3entwi
me1o
2meou
2meö
3m2er.
me1ra
mera1f
me2r3ap
me4rens
mer2er
4m3ergän
merin4d
merin4t
m4ersh
merz4en
3mes
me2sal
me2sä
mes2e
4meser
2me3sh
4m1es2sa
mes8senso
mes6ser6g
mes4sig
mes2s1o
mes2s1p
meste2
me2str
4mesu
3me2ß1
m2et
me3t2a
me3th
me3tr
meu1
2m1ex
1mé
2m1f4
mfi4l
2m1g2
2m1h4
1mi
mi2ad
mi3ak
mibi1
mi1ch
mi3da
mie3dr
mi2e1i
mie3l
mi2er
mierer4
mi2et
mie4ti
3mig
mi2kar
mi2ki
mi2ku
mi3l2a
3milb
3milc
milch1
mil4che
2m1imp
min2en
min2eu
min2ga
mi3ni
min2o
mi3nu
3minz
mi2o
mioni1
3mir.
mi3ra
3miri
3mirs
3mirw
mi2sa
mi4scha
mi4schn
mi4sch3w
mise1
mis4st
mi2sta
mi2ß1
3mit1
mi2ta
mi2th
mi2tr
mit3s2
mit5sa
mi3tsu
mit3ta
mi2tu
4mitz
2m1j
2m1k4
m3ka
mk5re.
2m1l2
ml3c
ml3s
2m1m
m2mab
m2m1ak
m2m1al
mm1ang
m2m1ans
mm1anz
mm1art
mma2ß
m2m1au
mmä2
mmd2
m2me2c
m4meh
m2mei
mm1ein
mm3eise
mme4lin
mme4na
m4mentw
m2me2nü
mme2ra
mme4rec
mme2s3a
m2me4te
mm1inb
mm1inf
mm1inh
mm1ins
mm1int
mmi3sc
m4mita
mmo2du
m2mo2l
m2mor
m2m1ö
mm3p2
mmpf4
mms2
mm3te
m2mum
m2mus
2m3n2
m4nesi
1mo
moa3
2mobj
3m2od
mode3s
mo2dr
2mog.
mo2gal
3moh
mo2i3
mo2k1l
2mol.
3mom
mom2e
3m2on
mo2nä
mo3ne
mo4n1er
mon3s
3mo2o
2m1ope
2mopt
mo1ra
mo2rar
2m1orc
mor4d3a
mor2dr
mo2rer
3mos
mo3se
mos3s
moster4
3mot
m1o2x
mo1y
1mö
mö2c
4mök
m1öl
4m1p
mpa3ne
m2pf
mp4f3erg
mpf3erp
mpf3err
mp4f3erz
mp2f3l
mpf1or
mp1hos
mpi3as.
m4p3lem.
m2p3len
m2p3les
mp4lif
m3pon
mpot2
mp3ta
m3pu
2m1q
2m3r2
2m1s
m2san
ms3and
ms1as
m3sat
m3sä
msch2
m4s1ef
ms1erf
ms1erw
ms1ini
mso2r
ms1ori
m2spä
m2sped
ms2por
m2spot
m2spro
ms2pu
ms3s2
m4stag
m2stal
m2sü
m3süc
2m1t
mt1ab
mt1ak
m3tam
mt1ar
mt3are
mt1ein
mt1elt
m2t1erf
m2t1erg
m2t1erl
m2t1ers
m2t1ert
m2t1eta
m2t1eu
m2th
mt3ho
m2t1im
m2t1ins
m2tint
mti2s
mtmen2
m2töl
mt1ös
m2trö
m4ts
mt2sa
mt2s1e
mt3s2ka
mts1p
mt1spa
mtt2
mt1um
mt1urt
mt3z
1mu
mu1a
2m3uh
mu3la
2muls
3mun
mun2d1a
4m3unf
4m3ungeb
mu3ni
m4unk
m2unr
munt2
4munz
mu3ra
mu4r1u2f
3mus.
mu4s1a
mu2s1o
mu2sp
mu2s1to
mu2str
mu2su
muße3
muts3t
mut4str
1mü
2müb
3müh
mü2her
mül2
mül3lu
3mün
3müt
2m1v
mvoll1
2m1w2
mwa2
mwa4r
mwel4t3
mwu1
1my
2m1z
mzug4
1na
3na.
2n1ab
na2bä
na3ber
4nabg
4nabh
na2bl
n2abo
na2br
4n3abs
4nabt
3na2c
nach1
na3chen
nach3s
nach8ters
nacht8raum
4nadd
n2ade
4n1a2dr
n1af
na1f4r
3n2ag
na2gem
3n2ah
na2h1a
n4ahm
n3ahn
3nai
nai2e
n3aig
n3air
2n1ak
na2ka
3nako
n2al.
na2l1a2
na4lal
na2lä
3n2ald
n4ale
na4lent
na2let
nal3la
nalmo2
na2lop
nal2ph
n2als.
nal3t4
na2lu
2naly
3name
na3me.
n2amen
namen4s3
4n1a2mer
na3m4n
3namo
nam2sp
2n1amt
namt4s
2n1an.
4n1a2na
4nanb
n1and2
4n1ang
2nanh
2nani
4nank
2nanl
3nann
na3no
n1anp
2nanr
4n1ans
2nantr
2nanw
nap2si
n1ar
5nar.
na2r1a
2narc
n2ard
4narg
3nari
n2ark
n2arle
2narm
4nart
n3arti
na3r2u
3nas
n2as.
na4schw
4nasp
4n1a2sy
nasyl2
3naß
3nat
n4ata
n3a3t4h
na4the
4n1atm
nats1
nat4sa
nat4sc
4natt
n1au
4nauf
nauf4fr
n3aug
5naui
3n2aul
4nausb
4nausg
n2auso
4nauss
4nausw
navi5er.
navi5ers
1nä
3n2äc
3näe
2n1ähn
3näi
2n1ä2m
2n1än
n1ärz
3näs
nä2sc
n2äss
3näß
2näu
3nä1um
2n3b4
nbais4
nbe2in
nbe3n
nbe3r2e
nbu2s
nby2
2n1c
n3ce4n3
nch3m
2n1d
nd2ag
n2d1ak
n2danl
nd1ann
n2d1anz
ndat2
n2d1au
nd1c
nde4al.
n2dei
nde4län
n4dentl
n4d3ents
nder6laß
nder6läs
nde4rob
nde2s
ndes1e
nde4spe
ndi2a3
n2dob
ndo2be
nd1op
nd1or
ndo2ri
n2dö
n2d3rat
n2d3re
n2drob
nd3rol
n2drö
n2d3run
nd2sor
nd2spr
nd3th
ndt4r
n2duns
n2dü
ndy3
1ne
3ne.
ne2ap
nea4s
ne3at
ne2bl
2n1ebn
2nec
3neca
3ned
2nee3
ne2e2i4
ne3ein
n1ef
neg4
2ne2he.
2nehen2
3nehm
4n1ehr
2n1ei
4neier
4neif
3neigt
4n3eing
4n3eink
ne2ke
nek3t4
ne2l
3nela
nel3b
2n1ele
4nelek
4nelem
ne3len
ne3li
3nelk
n2ell
nel4la4
nel4lif
3ne3lo
3ne3lu
n2em.
2n1emb
nem4e
n1e2mi
2n3emp
2n1ems
3nen
n2en.
n2en3a2
ne2nä
n2enb
n2enc
4n1endb
4n1endd
4n1endf
n1endg
4n1endh
4n1endk
4n1endp
4n1endt
4n1endw
ne2n1e2b
nen3ei
nenen1
ne4nene
n2enf
4nengb
nen4ge.
nen4gen
4nengs
4nengt
n2enh
ne2ni
n2enj
nen3k
ne2no
n2ens
nens4e
nen3sk
5n2en3t2a
n1entb
4n1entl
4nentn
5nentr
n1ents
4n3entw
4nentz
ne4n3u
n2env
n2enw
n2enz
ne2ob
ne1os
2nepf
2n1epo
ne2pos
n2er.
ne1ra
ne2rab
ne2r3af
ne3r4al
ne2r3am
ne2ran
ne2rap
ne2rau
nerb2
4nerbe.
4nerben
n1erbi
nere2
ne2reb
n1erf
4n5erfo
nerfor4
2nerfü
3nergr
n1erh
4n3erhö
3neri
n2erj
n1erk
n2erli
2n1erlö
ner4mit
n2ern.
n1ernä
ner4neu
4n1ernt
ne1rös
n2erp
3n2ers.
n3ersa
n2ert.
ne2rup
n2erv
2n1erz
n2es
n4es.
nes2c
ne2sei
ne2sev
nesi1
ne3ska
nes1o
ne2sor
ne2s1pa
4n3essi
ne2tad
ne2t1ak
ne2t1an
ne2tap
n1etat
ne2tau
ne2th
net3ha
nett4sc
n1e2tu
net2zi
ne2u
neu1c
neuer4f
neuer4k
neuer4s
neuer4w
neu3g
2n1eup
neur2
n2ew
2n1ex
3nez
1né
2n1f
nf1ak
nfalt2
n3far
n3fi
nfi4le.
nf4l
nf5lin
nf2o
nf4r
nf2tan
nft2o
nf2t3r
nft2s
nft4ste
n2f1u
4n1g
ng2abs
n2g1ac
ng1ad
n2g1ak
n2g1a2m
n2g1and
ng2anf
ng1anz
n2g1äl
ng3d4
n3gef
n2g1ein
ng2en
ngen2a
ngens2
n3ger
nge4ram
n4g3erse
ng6es
nges2t
nge4zän
ng3g4
ng3hu
n2g1i2d
n2glic
n2glo
n3g2loc
ng3m
n2gn
ng3ne
ng1or
n3gra
ng3rat
ng3roc
ng2s
ngsa4g
ngs1ah
ngs3au
ng4s3e4h
ngs3pa
ng3ts
n2gum
2n1h2
n3han
n3har
n3hau
n3hä
n3he
nhe2r
n3hu
1ni
3nia
nib4l
nibu2
nicht5er
nich8ters
n1id
3n2id.
ni2de
ni3dr
n4ie
nie3b
ni1el
nie3l2a
nie4n
ni3ene
ni1ero
nig2a
2n3i2gel
2niget
nig3r
ni2gre
nig2sp
3nik
ni2kal
ni2kar
ni3ker
ni4k3ing
ni3kl
ni2kr
3n2il
nim2o
4n1imp
nin1
3n2in.
n2in2a
4n3ind
2ninf
3n2ing4
4n1inh
ni2nor
2n1ins
n2ins.
4ninse
4n1int
2n1inv
ni2ob
ni3ok
ni3ol
n2ip
ni3ra
3n2is
ni4schw
ni2s1e
ni2s1p
nis5s2
ni2stu
ni3stun
ni2s1u
2nit
ni1th
ni2ti
nit4r
nit4tec
nit4tie
nitt4sa
ni3tu
3nix
n1j
2n1k
n2k3ad
n2k1ak
n3k2al
n4k3alg
nk2am
n2kans
n2k3au4s
n2käh
n2k1äp
nke4lei
n3k2er
n4k3erfa
nk4erg
nk1inh
n2k1ins
nk3len
nk3les
n3klin
nk2lo
nk4na
n2k1ort
nk2öf
n2köl
n2k3ro
nk2sal
nks2ei
nk3s2z
nk2tak
nk2tan
nkt1it
nk4top
nk2tru
n2küb
2n3l2
2n3m4
nmen2s
nmes8sens
nmül3
4n1n
nna2be
n2nada
n4n1all
n2n1an
n5nat
n2nau
nn3d
nn4ens
n4nents
nner4fü
nn2erh
nn2erk
nne2rö4
n4n3er4wa
nner2z
nne2s1e
n2ness
nn2ex
nn3f
nng4
n3ni
n2nof
nn1o2r
nn3se
nn3s2p
nn4s3pe
nnst4
nn2th
n2n1uf
n2n1unf
nn1ur
1no
3no.
no2bla
n2o3ble
3noblo
2n1obs
no1c
noch4r
2no2d
no3dr
n1of
2n3o2fe
n3ole
no2leu
n2on.
3n2opa
3nor.
nor2a
no2rad
n2o1rak
no3ral
2norc
nor4da
nor2d5r
3norh
3norm
3nors
n1ort
3n2os.
no3se
no3sh
no2sp
n2oste
nost1r
2nostv
nos2u
no3tab
no2tä
no4t1ei
no2tel
no3t3h
no4tha
no2t3in
no2top
no2tr
3nov
3now
2n1o2x
3noz
2nöd
2nö2f
2n1ök
4n1ö4l
1n2öt
2n3p4
npa2g
npf4
npsy3
2n1q
4n3r2
nräu3s
nre3sz
nrö2s1
6n1s
n2sa2d
n2sall
n2sang
n2sant
n3s2arg
n2saus
n2s1än
n3sät
n2s1äus
ns2ca
n4schl.
n3schu
nsch7werd
ns1eb
nse2ha2
nseh5ere
n3senk
nsen4sp
ns1ent
ns1erf
ns1erg
n2serh
n2s1erk
n2s1erö
ns1ers
n2s1erw
n2s1erz
n3sex
nsfi4l
n2simp
n2s1ini
nsinn4s
nsi2te
nsi2tr
ns2kal
ns2kel
n2s1op
n4s3ort.
nsp4
n2spat
n5s2pen
n4speri
n2sph
ns2pi
n2spo
ns3pon
n2sprä
n4s3prie
n4spro
ns3s2
ns2t1ak
n2stas
n4stat.
n4s3tate
ns2tau
n5s2te.
n4st3eif
n5stel
ns4tem.
ns4ten.
n4stent
ns2ter
ns3term
ns4tes.
n5steu
ns2tob
n6stoffi
nst5opfe
ns2tor
n4strac
n6strieb
nst4ru
ns2tum
nst2ü
nstü1b
n2sty
ns2um
n2s1un
ns2ung
ns2unr
n4s3zi
2n1t
nt3abs
n3t2a3c
n3t2al
nt1ang
n4tanza
nt2arb
nt1ark
nt4at
n2tauf
nt1äm
n2t1äu
n3te.
nte3au
nte2b
nt1ebe
nte1e
nte3g6
nt1eh
nt1ein
nte5lei
n3t2en
nt4ene
nten6te.
n3ter
ntera4
nte4ras
nt4erh
nt4ern
nt4ers
nt4ert
n2t1ess
n3tet
nte3v
nt2her
n2t3ho
n3t4hu
nti3k4l
n2tinf
n2t1inh
ntini1
n3tit
nt4lem
ntmen2
ntmo2
n3to
nton2s1
nt3rec
n3t4ree
nt3reif
n3trep
nt4rig
n3trop
n2t3rü
n4t1s
nts2o
nts2p
nt4s3par
nts2ti
nt4s1to
nttü3
3n4tu.
ntum2
ntu2ra
ntu4re.
ntu4res
nt3z
1nu
3nu1a
nu4ale
nu3ar
nubi1
2nuc
3nue
nu2es
nuf2
nu2fe
4n1uh
3nui
nu3k4
n2um.
2n3umb
2numf
2numg
3numm
2numr
2n1ums
2n3umz
nu2n
2nuna
nunf2
3n2ung
4n3ungl
2n1uni
2nunt
3nuo
2nup
2nur
3nu2s
nu3sc
nu3se
nus1i
nu3sl
nus1p
nus4su
nu4s1t
nu2ß
3nut
nu2ta
nu2t3r
3nuu
3nux
3nuz
2nü4b
nür1c
1nüt
2n1v2
n3ver
nvol7ler
4n1w
nwei4st
2nx
1ny.
1nyh
2nymu
n1yo
1nyr
1nys
1nyw
2n1z
n2z1a4g
n2zan
n2z1au
nz1än
n2z1är
nze4l3a
nzel3l
n4zense
n4zentw
n4zentz
nz3erwe
nzi2ga
n2zinh
nz1ini
nz3le
n2zor
nz2öl
nzug2s
n2zurk
nz1wa
n2z1wä
n4zwir
n2zwö
n2z1wu
ño1
2o3a2
o4abi
o4ac
oa3che
oa3chi
o4ad
oa3de
oa4g
o4a3i
oa3ke
oak1l
o4a3la
o4a3mi
o2a3s
3oase
oa4si
o4at
oa3te
o5au
o1ä
o1b
ob2al
obal2t1
2oban
o3bar
2o3b2ä
2obb
ob2e
2o3be.
2obea
ob3ein
obel2i
2o3b4en
oben3d4
oben3se
ober3in4
obe4ris
2obew
2o3b2i
obi2t
ob3ite
1obj
ob1l
ob3lei
1o2b3li
2o3blo
2o3bo
o2b3re
obs2
ob3sh
ob3sk
ob2sta
ob3sz
2o3bu
2o3bü
2oby2
2oc
oc1c
o1ce
och1a
ocha2b
o1che
oche4b
o2ch1ec
och1ei
ocher4k
och3l
och3m
och1o
och3ö2
och3r
ocht4
och3te
o1chu
ochu2f
och1w
o3ci
ock2er
ock3sz
o1cl
o3co
o1ç
o1d
o3d2a
od2dr
ode2c
o3d2e1i
odein3
ode2n1
odene2
odesi1
ode3sp
o3dex
2o3dia
odi4er
o3dir
o3div
o2don
odo2s
2odr
o2dre
odt4
2odu
o3dy
2o1e
oe4b
o2ec
oe2d
oe2h
oe2l
oe2n1
o4es
o2et
o3et.
o3ets
oe2x
o1ë
2ofa
of1ac
of1au
o2f1ei
of2en
o3fer
of2fa
of2f1in
of2fir
of2fix
1offiz
of2f3l
of2fo
of2f3r
offs2
off3sh
of2fu
of2fü
2ofi
of3l
of1la
of4lä
of4lö
2ofo
2o1f1r
of3ra
of3rä
of4rü
ofs1a
of4sam
of2spe
of2spr
of2s1u
2oft
of2tei
of3th
2o1g
o2g1ab
oga3d
og1ala
og1ang
o2g1ei
oge2l1i
o3gh
ogi2er
o3gis
og2lo
og4n
ogo4i3
og2s
og3sc
og3s2p
o1ha
o1hä
o1he
o2h1eis
o2h1er2t
o2h1er2z
o1hi
ohl1a
oh3lec
ohl1ei
oh3len
oh3lep
oh4lerg
oh4l3erh
oh4lerw
oh3lo
ohls2e
oh2lu
oh4n1ac
oh3nee
3ohng
oh2ni
1ohnm
oh2n1o
o1ho
oho2la
oh1o2p
o2h3ö
ohr3a
oh4rin
oh1ro
o1hu
oh1w
2o1hy
2oi
o1i2d
o3ie
o1im
oimmu4
o1in
oi2ra
oi2re
o2isc
o3isch.
oi3se
o1ism
oiss2
oi4st
2o1j
2o1k
oka2la
okale4
o3kat
3o2kel
oki2o
ok1lä
ok2li
ok4n
4okr
ok2s1p
okt4
2ol
o1la
o2lab
o2l1ak
ol2ar
ol1auf
o1lä
ol4dam
ol4dr
ol1eie
ol1eis
oler2
ol1ex
o1lé
ol2fa
ol2fl
olf1r
ol2fra
olf3sp
olf3st
ol2gl
ol2gr
ol2i
oli3k4
oli3tu
ol2kl
olk3r
ol2kre
ol2la2d
ol2lak
oll3ans
ol2las
ollä2
ol4l1ec
ol4lei
oll3ein
ol2l1el
oll5ends
ol4lerk
oll3erw
ol4li4st
ol2lo2c
ol2log
ol2lö2
oll3sp
ol2lu
ol3lus
o3lo
ol2of
olo1p2
ol1ort
ols2t
ol2str
o1lu
3oly
1olym
ol2z1a
ol4z3ern
ol2zin
ol2zw
2om
o2mab
oma4ner
om2anw
om1art
o2m1au
o2meb
om1ebe
ome3c
o2m1ei
o3meis
o2mel
o2mene
o2mep
omer2
o2meru
om1erz
om2es
omiet1
omil3l
o2m1ind
om1ing
om1ins
o2m1int
om3ma
om3me
om3mu
om1org
om3pf
omp4l
oms2
omtu3
o4munt
omy1
2ona
ona2b
o2nae
o3nal
ona4lin
on1ap
o2narb
on4at
on2au
2onä
on1äh
onbe3
2onc
onderer5
2one
one4i
one2n1
on1erb
o2n1erd
on1erg
on1erö
o3nett
on3f2
on3g2l
ong4r
ong3s
4o3ni
on2i3d
o4nikr
o4n1im
on3ing
on3k2
3onke
onli4n
onlo2c
on3n2an
on3n2e
ono1
o3nod
o2noke
on1orc
ono3s
ons1a
onsa4g
on2seb
onse2l
on4sh
onsi2d
ons3l
ons1p
onst2h
on3t2a
on4t3end
ont3erw
on2t3ri
2onuk
on3v
1ony
on3z
o1ñ
oo2k3l
o1op
o1or
oo4sk
oos5s
oo2su
oo2tr
2o1ö2
o1pa
opab4
o2p3ad
op3akt
o3pan
o1pec
o1pei
ope4n
1oper
o1pes
2opf.
op2f3a
op3fah
op4ferd
opf5erde
opf1l
opf3la
op1flü
op3for
4oph2
o3phe
o1pi
opi5a2
opi3er.
opi5ers.
opin2
op3lag
o2p3le
op3li
2o3po
op4pl
2o1pr
1opsi
op3sz
1op3t4
o1q
2or.
or1a
or3a2b
o1rad
2o1ral
o2r3alm
or4alt
3or2am
or2and
o2ranh
or3arb
o1ras
or3att
orau2s
o3rä
or1änd
or1ät
or2bar
orb2l
or1c
2orca
or2ce
2orda
or2d1am
or4dar
or4dau
or4d3eng
or2deu
or4d3ing
or2d1ir
or2dit
1ordn
or2do
2ordr
2ords
or2dum
2ordw
2ore
ore2a
ore2b
o2r1eck
o2r1ef
ore2h
or1eig
o2rein
or1er
o2rerf
or1eth
o2r1eu
2orf
orf3s2
or3g4a
2orget
or3g2h
2orgia
orgi1e
or2gl
or3gle
or2gn
2orh
2o3ric
4orie.
o4rient
o3rier
4oril
4orin1
or1ins
ork2a
or2k3ar
ork4r
2orm
or4mans
or4ment
2orn
or2nac
or2n3ar
or2n3ä
or5ne.
or3n2o
2o1ro
or1o2b
oro3n2a
2o1rö
2orp
2orq
2orr
orr4a
or3re
or3rh
2ors2
or3s4a
or3sh
or3si
or3sz
or2t1ak
or2t1an
or2tau
or2tär
or2tef
or4t3ent
ort2er
or4t3ere
ort3erf
ort3erk
ort5ersc
or2t3ev
or2the
or2tin
ort3ins
or4t3off
or2tor
or2tö
or4trau
or4t3räu
ort3ric
or2t1um
o3ru
or2uf
o4r3un
o2r3ü
o2rya
o1s
2o3s2a
os3ad
os4an
o4sca
osch3ar
o4schä
o3sche
osch3le
os2co
2ose
ose3e
o2s1ei
ose2n
os2ex
2osh
o3s2hi
2osi
o3sk
o4ska
o4ski
2os2kl
2os2ko
os2lo
2oso
2osp
os1pec
o3s2po
os2sa
oss7achse.
oss3ack
oss3and
os2sä
os2se4g
os4sei
os3sem
oss3en4k
os3sent
oss3enz
os2so
oss1or
os2sö
os2s3p
os4s1t
os2sul
os2t
o2st1a2b
o3stal.
o4st1am
ost3ang
osta2s
ost1au
o4sterd
oster3e
ost5er6we
ost3h
o2stin
o4s3ton.
ost3ran
o2st3rä
ost3re
os3tri
ost3rot
ost3uf
2osu4
os1um
2o3sy
o3s2ze
o2ß1el
o2ß1en2k
o2ß1enz
o2ß1ere
o2ß1erf
oß3t
2o1t
ota2go
o3tark
o2t1au
ot3aug
o3tax
ot1ä
o2teb
o3tei
o4t1eib
ote1i4n
ote3ine
ote2l1a
ote4lei
ot2em3
otemp2
otens2
o2t1erw
4ot2h
ot4he
ot5hel
o4t3hi
ot3ho
o2thr
o2til
o2t1i2m
ot2in
o4tl
otli2
ot4ol
ot1opf
ot2or
oto2ra
o3tra
o2t3re
ot3rin
ot2sa
ots1p
ot2spa
ots2pe
ott1a
ot2tan
ot2tau
ot2teb
ot4terh
ot4terk
ot2th
ot2t3r
ot3t4ra
o2u
oub4
ou2ce
ou1f4l
oug2
ou2ge
ou3gl
o3uh
ou4le.
o3um
o3unds
oung5
oun4ge.
oungs2
2our
ouri2e
our4ne.
ou3s2i
ous2t
outu4
2ouv
2o1ü
o1v
2ovi
oviso3
2ovo
2o1w
o3wec
owe2r1
o3wi
o1x
2ox.
ox2a
ox2e
ox3l
o2xu
1oxy
o1yo
2o1z
o3z2a
oz2e
ozen4ta
o3zi
ozon1
órd2
ö1b
öbe2la
öbe4li
öb2l
ö2ble
ö2b3r
ö1ch
öch1l
ö2chr
öchs2t
öch4str
ö1d
ödi3
1ödu
ö1e
1öf
öf2fa
öf2fl
öf3l
ögen4s1
ög3l
ög3r
ög2s
ö1he
öh3l2e
öh3ri
öh2s
ö1hu
ö3ig.
ö3isch.
ö1ke
ö2ko
ök3r
ök2s
3öl.
öl1a2
öl1ei
öl1em
öl2f1ei
ölf3s
öl1im
öl1in
öl2k3l
öl2la2
öl2nar
öl1o2
öls2
öl3sa
öl3sz
ö2l1u
öl2ung
ölz2w
ö1m
öm2s
ön2e
ö3ni
önizi1
önn2e
öo1
öot2
öoti1
ö1pe
öpf3l
ör3a2
ör2b3l
ör1c
ör2dr
ö2r3ec
ö2r1ei
ö2r1e2l
ör2erg
ör2erk
örer2l
ö3r2erz
ör2f3l
ör2gl
ö2r1im
ör2kl
örn2e
ör1o
örs2e
ör3s2k
ört2e
öru4
ö2r1une
ö1s
ö2sa
ö2scha
ö4sch3ei
ö2schl
ö2sch3m
ö2schw
2öse
ö2s1ei
ö2sp
ös2s1c
ös4st
ös2t
ö2sta
ö1ß
ö1t
ö2t3a
öte4n3
öt2h
öt2sc
öt2tr
ö1v
ö1w
ö1z
öze3
özes4
p2a
1pa.
1paa
1pac
pa3da
pa2dr
pa1f4r
pag4
pa3gh
pa1ho
1pak
pa1k4l
pak2to
3pala
pala3t
1palä
pa3li
pal2ma
pal2mä
pal2m1o
2palt
pa2nar
pa4nat
pan3d
pan4ds
pa2neu
pank4
2panl
2pann
1pa2no
pan3sl
pant2
panz4
1pap
papi2
papieren8
papie8r7end
1para
pa2r3af
par3akt
1parc
pa5reg
2par2er
2parg
pargel6d
1park.
par4kam
par4kau
par2kr
1paro
2parp
1partn
1party
par3z2
pa1s2p
pas4sek
pa2ßu
pat1a
pat4c
pate2
1pati
1pat4r
1pau
p3auf
pa3uni
1pä
3päc
3päd
3pär
3päs
pä4t1e2h
pä4t3ent
pät3h
pä2to
pät3s
2p1b
pbe1
2p3c
2p1d2
pda2
p2e
1pe.
pe2a
pea4r
pech1
1ped
pe2en
pef4
pei1
2peic
pe1im
1peit
pekt4s
1pel
pe2l1a4
pe4lein
pe2let
pe4leu
pe2lex
pe3li4n
pe4l3ink
pel3k
pel3la
pel3lä
pel3l4e
pel3li
pel3t
1pem
1pen
pena4
pe3n2al
pe2nä
pen3da
pe4nen
pe2n1o
pens2
3pensi
pe2nu
penz2
1pep
pe1ra
per2an
1perio
1perle
per4na
1pero
per2ra2
perr3an
per4rä2
per4ric
per6rieg
1pers
2perse
2persi
3perso
1perü
perwa4
pe3sa
pes3s2
pes2t
3pet
1pé
4pf.
p2fab
p2fad
p2faf
pf3ai
p2f1ak
pf1ans
p2fa4r
pf3are
p2f1au
4p3fe.
p2fei
pf1eim
pf1ein
p3fen.
p2fent
p3fer.
pf2erw
p3f2es
pff4
pffa3
p2f1ins
pf4lan
p2f3lä
pf4leg
pf3lei
pf3lo
p2for
pf3r
pf1ra
3pf4ro
pfs2
pf3sl
pf3sz
pf3t
2pfü
2p1g
pgra2
1ph
4ph.
2phä
2phb
2phd
2p1hei
phen3d2
phen3s
2ph1ers
2phf
2phg
phi2ka
2phk
ph2l
2phm
2phn
p3hop
pho2s
2phö
ph4r
2phs
pht2
2ph3the
phu4s
2p1hü
2phz
pi2a1
pia3k
piap2
pia3s
pi3chl
p4id
piegelei8
pi2el
piela2
pie4lei
1pier
1pig
3pik
1pil
pi3le
pil4zer
2pind
pin2e
pingen4
ping3s
3pinse
pi2o
pi3oi
pi3onu
3pip
pi2pe
pi3ri
3pirin
3pis
4piso
pis2t
pi3t2a
pit2s
pi2z1in
p1j
2p1k2
pku2
pkur1
1p2l4
4pl.
3pla
p3lad
plan3g
3plä
2ple.
ple1c
ple2e
p4leg
ple5n2
2p3ler
p3lic
p3lif
2plig
p4lo
2p3lu
2p1m2
pma1
2p1n
1p2o
po3b4
po1c
3pod
2poh
po2i
po3id
3poin
3pok
3p4ol
po2lau
po3li
pol3lo
po4lor
2pond
po1o2b
po2p3ak
po2p3ar
po2pl
po3pt
po1rau
porf4
por4tre
por4tri
po3s2e
po2sta
post3ag
po4stä
po4st3ei
post3ra
po3ta
3pote
po2t1u
po2w
po3x
pö2bl
pö2c
2p1p
p2p3a2b
pp3anl
ppa2p
ppe1e
ppeli5ne
ppe2n1
ppf4
pp1fr
p2p1h
p3p2ho
p2p1ia
pp3lä
p2p3le
pp3oh
ppp2
p2p3ra
pp3ren
p2pri
pp3sa
ppt2
pp3ta
p3puc
p2pul
p2punk
p3pur
p2r2
1prak
1prax
p4rä
1präd
1präg
3präm
3präs
2pre.
2prec
3pred
pre2e1
2preg
1prei
3preis
prei4s3c
2preiz
2p3rer
3p4res
1preß
pri4e
2prig
3prinz
pri2t1
priter4
1p4ro1
3prob
2proc
3prod
3prog
3proj
2pross
2proß
3prot
1prüf
2prüh
2prün
2p1s
4ps.
ps4an
p3se
p3s2h
ps1id
p2sö
ps2po
ps2te
pst3re
p2stu
3p2sy
ps2ze
2p1t
pt1a
pt2ab
pt3alb
pt3at
p3te
p4t3ec
p4t1ei
pte4l
p4tele
p4t1ent
p4t1ep
pt3erei
p4t1erw
p4t1erz
p2th
pt1in1
p4tos
pto2w
ptpo4
p2t3r
pt1s2
ptt2
pt1um
p3tung
pt1urs
p2tü4
3p2ty
pt3z
1pu
pu1a
pub4
2puc
pu2dr
2p1uh
2puk
pul2sp
3pulv
2pund
pun2s
2punt
2pur
pu3ri
3put
put2s
1püf
pül3l
2p1v
2p1w
pwa4r
3py1
py3t
2p1z
qu4
quel4la
que4te.
1queu
qui3s
1ra.
2r1aa
ra2ab
3ra3ar
3raau
r1ab
ra2bar
rab2bl
2rabd
r2a3b2er
2rabf
2rabg
1r4abi
ra2br
2rabs
2rabt
ra2bü
2r3abw
1raby
ra1ce
2r1acet
ra4cheb
ra4chin
racht3r
rach6trä
ra2chu
r2ack
r2ad
r4ad.
ra2dam
2radap
3radf
r3a2d3r
rad3t4
1ra2e
ra3er
r2af
raf3ar
ra2fer
ra3ge
ra3gle
ra2gn
3r2ahm
2raho
4raht
2raic
rail4l
2r3air
3ra1k4l
ra2kre
ra2kro
2rakti
3rakü
r2al
r4al.
ra2la2
ral3ab
rala4g
r3alar
ral3b
3r4ald
ra3le
2ralg
r4ali
rali5er.
rali5ers
ralk2
ral3la
ral5l2e
2rallg
2r3alm.
r3alp.
2ralpe
r4als
r3alt
2ralta
r4al3t2h
ra2lu
3raly
r2ame
ra2mer
1r2ami
ram4man
ram6m5ers
ram4mit
ram4mu
2r1amt
ramt4s
r2an.
ra5nat
2ranb
r2anbe
4ranc
r4anda
r4ande
ran4dep
ran4d3er
4r3anei
r4aner
2ranf
1rangi
rani1e
ran2kr
2ranl
2r1anm
r2anmu
2r1anp
2ranr
r2ans.
r2ansp
ran4spa
ran2th
2rantr
2r3anw
r2ap
2rapf
ra2pri
r1ar
r2ara
2rarb
3rarei
rar3f4
ra4r1in
r2ark
2r3arz
r2as
r4as.
ras4a
ra4schl
2rasph
ras2t
2raß
1rat
ra2t1a
ra3ta.
ra3te
rat2o
rat4r
2r3atta
4ratz
4rau.
3raub.
4raud
4raue
rau3e2n
2rauf
2raug
3raum
rau4m3ag
rau4man
rau2mi
3raup
4raur
2rausb
2rausg
rau2sp
raus5se
raus3tr
4raut
raut5s
1raü
r2ax
raxe3
raxi4s1
räch4s
3r2äd
4räf
rä1fr
4räg
2räh
2räm
3rän.
3räni
3räns
2r1är
r2är.
rä3ra
rä4sc
rä2st
3rätse
rä2u
4räue
4räun
räu2s
räu5sche
4räut
4r1b
r2b1ab
r2b1a2de
r2bak
rbal3a
rba3re
rb1art
rb1auf
rbb2
rb1ech
rbeid2
r4belä
r4belis
r3ben.
rb1ent
rbe3r2e
rber4gl
rb2la
rbla2d
r2blan
r8blasser
r4b3last
r3blä
r2ble.
rb3ler
r2bleu
rb2lin
rb2lö
rb2o
rb4ri
rb2sa
rb2sei
rb3ska
rb2s1o
rb2sta
rb4stä
rb2stu
rb2su
rb2u
rbu2sc
2rc
r1ce
r1che.
r1chen
r1chi
rch3l
rch3m
rch3r
rchs2
rch3sp
rchst4
rch3t2a
rch6terg
rch6terw
rch1w
r1ci
r1cl
r1ç
2r1d
r3da
r4dab
rd2ac
r4daf
r4d1ak
r4d1al
rdani1
rd1ant
rd1anz
r4dap
r2dei
rd2ei.
r4deis
r2d1elb
r3den
rden3d2
rde3re
rder4er
rderin6s
r4d3ernt
rde3sp
rdga4
rdgas3
rdi3a2
rdia4l
r2d1inn
rd1it
rdo2be
r3don
rd1os
rdo4st
r2dö
rd3rat
rd4ri
rdt4
rd3ta
rd3th
rdwa4
1re
3re.
re3aler
re2am
re3at.
re3ats
2reä
re2b1a
re2b1l
reb1r
reb3ra
re2bü
r2ech
rech3ar
4rechs
2reck.
2recki
3red.
4redd
2redi
re1el
re1er
3refe
2reff
3refl
3refo
3reg
5reg.
rege4l3ä
2reh
re2hac
re4h3ent
re2h1i
rehl4
reh3n
re2h1o
r2ei.
r2eie
2reig
rei3l2a
rei3l2i
3reim
reim2p
r1ein
4reinb
rei3nec
4reing
r3eink
4reinr
rein8s7tre
re1in2v
reister6
reis5tro
re2ke
re3la
2r1elb
rel2e
relea4
re3lei
2re2lek
2r1elf
re3lo
2r1elt
relu2
r4em.
r2emi
4rempf
4remu
r4en.
r2ena
rena2b
re3nal
re2nä
3rendi
ren3dr
re4n3end
ren2gl
2rengp
re2ni
ren4nar
ren3sau
2r1entg
2r1entl
2r1ents
2rentw
4rentz
r2enz
ren2zw
re3or
3repe
re4pis
3repo
4repp
3r4er.
2r1erb
rer2bi
r4erbil
r2erbr
2r1erd
r2erer
r1erf
r2erfe
r2erfl
r1erg
r4ergen
re3ri
r1erk
4r3erken
r2erki
2rerkl
2r1erl
5rerlag
2r1erm
rer2n
2r1ernä
4r3erns
4r3ernt
r2e1ro
re2rob
r1erö
3r2ers.
2r1ersa
r2erse
2rersp
r1ert
r2erte
2rertr
2r1erz
rer5ze
r2erzy
3r4es.
re2sa
res3an
re4schw
3rese
3reso
2ress
res4sam
ress2e
res6seit
res6s5erw
3rest
res3tem
re2stu
3resu
2re2ß1
re2thy
re2u
reu3g2
2reul
re3uni
2r1eur
2reü
2r3evid
r1ew
rewa4r
re2wi
4r3e2x1
3rez
4rezi
1ré
2r1f
rfall4s
r2fent
rf2es
rfi4le.
r2flan
rf3lic
rf3lin
rf4lö
r3flü
r3for
rf4ru
rf4rü
rf2sa
rf2s1ä
rf2s1id
rf2spr
rf2ta
rf3t4r
rf2u
4r1g
rg2ab
r2g1a2d
r2g1ah
r2g1ak
rg2an
rgas2t
rga4str
rge4an
rge2bl
rg2el
rge4l3er
rgen4z3w
rge4ral
rge4tap
r2geto
rgi4sel
r3gla
r2glan
rgleich8s7
r2gleu
r2glig
rg2lö
rg2lu
r2gna
r2gno
r2g1ob
rgö2
r2g1öd
r2g3ral
r2greg
r2gres
r2gret
rg3rin
rg3saf
r1h4
2rh.
2rha
r2ha.
r3hals
2rhä
3r4he.
2r3her
r2hoe
r3hof
rho2i3
2rhol
2rhö
2rhs
1ri
ri3am
ri3at
rib2bl
ri1ce
ri1cha
ri2dan
ri2dau
rid2g
2ridol
2ridy
r2ie
rieb4s3t
rie2fr
ri1el
ri3els
riene4
ri3eni
rie2nu
ri1er.
ri4ere
ri3e4sti
ri1eu
ri2f1a
ri2f1ei
ri2f1er
ri2f1o
ri2fr
rif4ter
3rig
ri4gene
5rigj
rig1l
4rigr
rik1l
ri4kla
r2imb
ri2me.
4rimp
rim2s
r2i3na
2r1ind
rin4dex
rin4diz
4rindu
ri3n2e
rine1i
2r1inf
rin2fo
rin2ga
ring3l
rin2gr
2r1inh
4rinit
2rink
rin2kl
3rinn
6r5innenm
4r3inner
4rinnta
r1innu
2rins2
3r4ins.
rin2so
rin2sp
r4inspi
2rint
rin4teg
rin4t5r
2r1inv
4r1ir
r2is
ris4a
ri4scho
ri4schw
3risik
rismu2
ri3so
ri2s1p
3riss
ris2sa
ris4san
rist5ers
ristes4
ri6stess
ri2ß1
r2it
r3i2tal
ri3t2i
ri3t4r
rit4tei
rit2tr
5ritu
rix1
ri3xi
1rí
2r1j
2r1k
rk2am
rk4ap
rkauf4s
r2käh
r3kla
rk4las
rk4lau
r2klis
rk2lo
rk2lu
rk4n
r2k5nu
rk3räu
r2k3rea
r3kri
rk2s1e
rk2sp
rkstati6
rk4stec
rk2ta
rk4t3eng
rk4t3erf
rkt3ers
rk6tersc
rk4t3erw
rk4t3erz
rk2tin
rk2t1o2
rk2t3r
rk3tra
rk2um
rku2n
rk1uni
rku4s1t
4r1l
rl2ab
r5lag
r5lan
r2l1ar
r2l1a4sc
r2l3aug
rl2e
rle4a
r3lec
rle4i
rle2st
r3let
r3l2i
r3l2o
rlös5s
rl2s1p
rl2sto
rl3t
r3lu
rlu4str
rlz2
4r1m
r2mab
r3m2ag
rma2la
r2m1ald
r2m1ank
rm1ans
rm1anz
rm1a2p
r2maph
rm3d2
r2m1ef
r2meo
r2m1erp
rm2es
r2mide
r2m1im
rm3m
rmmo3
r2m1o2ri
rm3sa
rms2t
rm3sta
rmt2a
rm2u
rm3ums
4rn
rna2b
rna4n
rn2and
rn3ani
r2n1anz
rna4r
rn2arb
rn3are
rn3ari
r2nau
rn3d4r
r3ne
rn3e4ben
r4nef
rn2ei
rn3eif
r4n3eis
rne2n
r4n1ene
r4nerf
r4n1erg
rn4erhi
r4n1ert
rner4ve
r5nes
rn2et
rne3uf
r4nex
rn3f
rng2
r3ni
r4n1in
r3nod
r2n1op
r2n1or
rn1ö
rn3sa
rn3s2ä
rn3s2p
rn3s2z
rn3t2e
rn1ur
r1nü
r1ny
ro2bei
2robj
1robo
2robs
ro1ch
3rock.
4rockn
r2o3de
ro3e2
4rog.
4rogs
roh1l
3r2ohr
3roi
ro3le
rol4lan
rol3l4en
rolli4n
rol6lini
2roly
4rom.
ro2mad
ro2mer
4romm
4romt
r2on
ro4nerb
3ronn
rons2
ron4tan
4ro1ny
2ro2pf
ro3ph
r1or
r2ora
ro2r3al
ro2rat
ro2rei
ro2r1o
ror3th
ro3se
ro3sh
ro3s2i
ro3smo
ros2s1c
ro3sta
ro2st1r
ro2ßu
ro2tag
ro2tä
ro2tei
ro2tho
ro2tri
rot1s
rots2o
ro3t2u
ro3unt
3rout
rö2b3l
rö2du
2rö2f
3röh
r1ök
1röl
rölla4
3römi
4röp
r1ör
r2ös.
3rötu
2r1p2
r3p4a
r3p4e
rpe2re
rpe4r3in
rpf4
r2pli
rpo4str
rps1t
rp3t
r3pu
2r1q
2r1r
rr2ab
rr2ar
rrat2s
rr1äm
rrb2
rr1c
rr2e
rre4ale
r5rega
rre2le
rre2pa
rrer4s
r3res
rre2ve
r2rew
rr2he
r3r4hen
rrik2
rr2n3a
r3r2o
r4r3ob
rro3m
rr2th
r3ru
r3r2ü
rrü1b
4r1s
rs3ab
r2sa2d
r4samp
r4s1amt
rs2an
r2s3ang
rs3anp
rs3ar
r3sche
r6scherl
rs1ebe
r2sein
rse2n1
rs2end
rse4ne
rs1ere
rs1erö
rs1ers
rs1erz
rse2t
rs1eta
r3sho
rs2kal
rs2kan
rs2kie
rs2kis
rs2kl
r4sko
r4skr
r4sku
rs3l
rs4no
rson4e
r2s1op
r4s3ort.
rs2p4
r2s3ph
r5spi
rs3s2
r5stad
r4stant
rs2tau
r6st5eing
rster2
r6sterbt
r4st3erw
rs2th
r5stim
rst3ing
r2stip
r2s1tot
rs2tr
rst3ran
r6strang
rs2tu
r2sumf
r3swi
4r1t
rt4abl
r2t1alm
rtals1
rt1am
rt1ang
rt1ann
rt1ant
r2t1ar
rt3a4re
r2t3att
rt1är
r3te.
rte1e2
rtei3la
rt1ein
r2telf
rtel6lei
r4tempf
rte2n1
r3ten.
rte4na
rtens2
rt3erei
r4terfa
r4terfo
rt1erh
r4t3er4la
rter6mit
r4t3ernä
rter4re
rt1ers
r3tes2
rte3sk
r2thi
rt2hum
r2t1id
r2t1ima
rt4is
rto1p
rt1or
rto2ri
r2t3rak
rt3rec
rt3ros
r4ts
rt4s1eh
rt1s2pe
rt3t4
r2t1urt
rt3z
rtz2a
1ru
ru1a
ru3a2r3
rube4
ru3ches
rude2a
ru2dr
3ruf
ru2fa
ruf2s1
ruf4st
ruf4ter
2r1uhr
ru1ins
ru1is
2rum
4rumf
ru2mi
4ruml
r2ums.
4rumz
2r1una
2rund
run2d1a
r2unde
rund3er
run6derf
run6der6l
run6ders
run6derw
2r1unf
2rungl
2r1u2ni
4r3unio
run2kr
2r1unl
2r1unm
4runn
4r3unt
2runw
ru3pr
4r3ur
ru2ra
ru2r1e
5ruro
ru2si
rus2s1p
rus6s3t
3rut
ru4tei
rut3h
ru2t1o2
ru2t3r
4ruz
ru2zw
1rü
2rüb
rü1ben
rü1ch
rück5sta
4rümm
rün3z
2r1v
rve4n1e
rve5s
rv2s
2r1w
r5wei
rwun3s
4r1x
1ry
ry2c
rys2t
rysti1
2r1z
rz2an
r2zar
r2zas
r3ze.
rz1eck
r5zene
rz1eng
r4z3ents
r2z1erf
r2z1erg
r2z1erk
r2z1erw
rz1id
r3z2of
rz2ö
rz3te
rz2th
rz2t3ro
rzug2u
r3zü
r3zwä
r3z2wec
1sa
3sa.
s2aa
2s1ab
sa2be
3sabet
sa2bl
sa3ble
sa2br
4sabs
sa2cho2
sach3t
s1ad
2s3ada
s3adm
2s3a2dr
sa2fe
2s3aff
3safi
sa1f4r
sa4gent
sag4n
s1a2gr
3sai
sa3i2k1
sail2
2s1ak
sa2ka
3saki
4s3akt
3sal.
4s1alar
sa4l3erb
sa2l1id
s1all
sal5lo3
3salo
sal2se
2s1alt
3s2alz
3sam
s2ame
s3ameri
4s1amma
4s1amn
s1am3p4
sam2to
s1an
s2an.
2s3a2na
2s3anb
s2an2c
s2and
s4and.
san4dar
san4dri
3sang.
sang4s
2s3anh
3s4ani
2s3anl
2sanp
2s3ans
san4sk
4santr
2s3anw
s3anz
2s1ap
s2aph
sa2po
3sapr
2s1ar
3s4ar.
3s2ara
4s3arb
3s2ard
3sari
s3arr
3s2ars
4sarti
s1a2sp
4s3a2sy
sat2a
2s3ath
2s3atl
4s1atm
sa2tr
sa3ts
sat4z3en
s1a4u
3sau.
3sauc
3saue
sau8erste
2s3aufb
sau2gr
3saum
sauri1
2s3ausb
sa2vo
3say
s1äh
s3ähn
2s1ält
2s1äm
2s1änd
2s1är
sä2s
1s2ät
1säu
3säug
2säuß
4s3b4
sba4n
sbe3r2e
1sc
4sc.
2scam
s2cap
4scar
2s1ce
6sch.
sch2ab
3schaf
2schak
sch2al
4schanc
4schang
5schanz
4schao
s2chau
3s2chä
2schb
2schc
2schd
sch2e
3sche.
6schef.
6schefs
sch3ei.
4schemp
3sches
4schess
4schex
4schf
4schg
2schh
schi4e
3sching
4schiru
3schis
2schk
sch4lag
4schle.
6schlein
4schmas
2schmö
4schmüh
2schn.
4schobj
2schox
3schö
4schöl
2schp
2schq
4schre.
4schrin
sch3rom
4schron
4schrou
6schs2
sch3sk
4sch3t
scht2a
scht4r
s2chu
4schunt
3schü
2schv
4schwaa
4schwet
sch4wil
2schz
2scj
6s1cl
2sco
3s2cop
3sco4r
s2cr
2scs
2scu
4s3d2
sda3me
sdien4e
sd4r
1se
3se.
se3at.
2s1e2ben
seb4r
2s1echo
s1echt
2s1eck
se2dik
3see
se1ec
se2e1i4
see3ig
seein2
se1er.
se1erk
se1erö
2s1eff
sef4l
se2gal
se2gl
seg4r
3seh
seh1a
se2ha4g
se2han
se3he
se4h1ei
se4hel
se4herk
se2hin
seh1l
seh3re
seh3s
seh3t
se2hüb
2s1ei.
2s1eie
2s1eig
3seih
sei3le
s1ein
5s2ein.
2seinb
sein4du
sei3n2e
sein4fo
2seing
2seinh
4seink
2seinl
2seinn
2seinr
s4eins.
4seinsa
4seinsp
4seinst
2seinw
2s1eis
3s2eit
3sek
4s1e2ke
s2el.
se2l1a
se3lad
sela4g
se3lam
sel1ec
2selem
se4lerl
sel3ers
2self.
s1elix
sel3le
se2l3ö
s2els
sel3sz
sel3tr
s4e3ma
2s1emp
s2en.
se4nag
se2nä
2s1endl
5seni
se2no
s2ens
s2ent.
sen3ta
2sentf
4s3entg
s2enti
2s1ents
2sentw
2sentz
se4n3u
seo2r
4s1e2pos
s2er.
ser3a2d
se2r3al
s3ereig
se4r3eim
se4r3enk
ser2er
2s1erfo
s2erfr
s3erfü
4ser4fül
s1ergä
s4ergr
s1erh
2serhö
3seri
serk4
4s3erken
s1erkl
s2ern.
s1ernä
4s3ernt
se1rot
2s3eröf
s2ers.
2sersa
4serseh
sers2t
s4ert.
seru2
se4r1uf
se3rum
se3rund
3s4erv
se2sel
se3sk
se3su
3set
4se4tap
se2tat
4s1e2th
se1u2n
2s1ex
se2xe
4sexp
sex3t2
6s3f4
sfal6l5er
sflo4
4s3g2
sges2
2s1h
4sh.
sh2a
3s2ha.
sha2k
4s3han
sh2e
3shi.
3shid
4shil
shi4r
sh3n
4shof
3shop
sho4re
3show
sh4r
4shs
1si
si3ach.
si2ad
si3am.
sia4s
2siat
sib4
si1c
2s1ideo
s2ido
s2ie
siege4s
sieh1
sie4hes
si3ene
si1err
si1f4
3sig
si2g1a
sig4n
si3gnu
si2g3r
si2k1ab
si2kak
si2k1ä
sik3erl
si2ki
si4k1l
si2kr
sik3s2
sik3t4
si2ku
sil2br
2s1imm
si3n4a
2s1ind
2s1inf
sing1a
sin3gl
sing4le
sin4gr
sing3sa
2s1inh
sin1i1
2s1inq
2s1ins
s2ins.
2s1int
2s1inv
3sio
3siru
3sis
si2sa
si4schu
si2s1e
si2s1o
si2s1p
sis3s2
si2stu
s2it
si2tau
3site
sit3r
si2tra
si3tum
siv1a
sive3
si2vr
1sí
4s1j
2s1k2
4sk.
1skala
4skam
4skanz
4skas
ska4te.
4skateg
ska4tes
4skä
4skb
s2kep
3s2ki.
s2kif
s2kig
3s2kik
4skir
3skiz
sk4l
4s3klas
3s2klav
4sk4n
4skom
4skor
4skow
4skö
4sks
4sk3t
3skulp
2s1l2
3slal
4slan
sla2ve
s2law
sl3b
s5le
s3li
3s4lip
s3lo.
slo3be
s3loe
2s1m2
s3ma
s3mu
2s3n2
4s5na
snab4
sni3er.
sni3ers
4s5not
4snö
3so.
so4a
2s1o2b
so3et
3soft
3sog
s1o2he
6sohng
2s1ohr
1sol
so3la
so2l1ei
sol2la4
sol4ler
2so2ly
3som
1s2on
son3au
sone2
son3end
son3sä
son2s1o
so3o
2s1opf
3sor.
s1orc
2s1ord
so2rei
so3ren
2s1orga
5s2orge
2s1o2rie
so2ro
3sors
so4ru
3sos
4s1ost
3soß
1sou
so3unt
3sov
4s1o2ve
3sow
2s1ox
5soz
sö2f
2s1ök
s1ö2l
s1ö4s
sp2
2sp.
2spaa
2spak
2spala
spani7er.
2spano
2spap
2s3para
1spare
2sparo
5s6parten
3sparu
3s2paß
2spau
s2paz
s2pä
2spär
2spe.
4spensi
spe3p2
s2pera
2spero
s2perr
2spers
4spet
1s2pez
2s3pf
2spha
s3phe
1spi
3s2pi4e
4s3pier4
spi2k
4spil
3spio
4spip
4spis
3s2pit
3s2piz
2spl
4spla
4splä
3s2pli
s3p4lu
s3pn
2spod
2spog
s2poi
2spok
4spol
1spon
1spor
2s3pos
s2pott
4spr.
s2prac
s2pran
2sprax
2spräm
4spräs
1s4prec
2spred
s2pren
2spres
s2prit
2sprob
2sprop
5spross
1spru
2sprüf
1sprün
2s3ps
2spt
1spuk
2spup
3spur
4sput
1spü
4spy
2s1q
2s3r4
srat2s
srat4sc
sret3
srö2s
srös1c
srücker6
4s1s
ssa3bo
ss2ad
s3sag
ss1aj
s3sal
s4s1alb
s4s3amt
s4s3ang
s4sans
ss2ant
s4sanz
s3sas
ss3att
ss2ä
ssch2
ss1ec
s2s1ega
sse3inf
sse3in4t
s3sen.
s3ser.
sse6r5att
ss1erö
ss3erse
s3s2es
sse3ta
s3skala
ss3l
ss1off
ssoi4
s2s1op
ss1ori
s2söl
s3spe
ss2pen
ss2po
s2spro
ssquet4
ss3s2
sst2a
s5stad
ss2tar
ss1te
s4ste.
s5stel
s4sten
s4stes
s4stet
s5steu
ss2th
ss2tip
ss1tis
ss2top
s3strec
ss2tur
s3s2tü
ss1ums
1st
6st.
s4ta.
3staa
2stabb
2stabh
s2tabi
2stabt
2stabz
st2ac
3s2tad
4stada
4stadr
3staff
2stag
3stah
2stak
2stal.
2stale
3sta3li
2stalk
st1alm
st1alp
3stam
st1a2mi
4stamt
sta4na
3stand
4stanf
4stanl
4stann
2stanw
4stanza
s2tar.
s2tars
3start
st1asi
3stat
2stat.
5statu
s4tau.
2stauf
2staum
5staur
2staus
2stax
3stä
4stäg
4stält
4stämt
s2tär
5stätt
4stäus
4stb
2st3c
2std
3ste
s2tean
4stechn
4stee
ste2gr
ste4i
4st1eid
5s2teig
4s3teil
steil4z
stei4na
s2t2el
s3telem
5stell
stel4l3ä
ste4mar
4stempf
ste4na
4st3ends
4stentf
4stentw
4stepi
st5erbie
ste4rec
ste6rers
st3erfü
st2erg
st5ergeb
s2tern
6sterras
s2ters
stes3ta
ste4stä
4stests
s2teu
4steuf
4st3ev
4stex
4stf
2stg
2sth
st3ho
5s2tic
3stie
4stief.
3stim
2stinb
2stinf
2st1ins
s4tio
sti2r
st3i2so
2stj
2stk
4stl
4stm
2stn
2stob
3stoc
sto3d
s2tode
s2tof
stoffen6
stof8fens
2st3om
2stope
2stopo
2stord
2storg
s2tory
3stos
4stou
2stöch
2stöl
2stön
5s2tör
2stöt
2stp
2stq
3s2traf
2strag
3strah
4strai
3s2tral
4strans
3s2tras
3straß
4straum
s2träf
2s3träg
s2trän
4sträne
2stre.
4strech
4stred
4stref
4streg
s3treib
3st4reif
4streis
st3renn
2strep
2stret
2strev
2stri.
3s4tria
2strib
4strig
stri2k
4strisi
2stroc
3s2trof
3s2trok
st3roll
stro4ma
2ströp
4ströt
3struk
2st3run
2strup
4st3s2
sts4k
2st3t4
st2u
5s2tub
4stuc
3stud
2stue
3stuf
5stuh
2stuk
2stumr
stum2s
2stumz
stu2n
2stun.
2stunf
2st3uni
2stuns
2stunt
3stuö
stu3re
st3url
2s3turn
2st3urt
4stüch
s4tück
2stür.
2stüre
2stürg
2stürs
2stv
2stw
2sty.
2stys
4st3z
1su.
su1an
1su2b3
su4ba2
4subi
3su1c
su2cha
such4st
2s1u2f
4s1uh
su1is
su1it.
sul2a
sul2i
sult2
su2mar
su2mau
3s2ume
su2m1el
su6m5ents
s3umfa
s3umfe
3summ
sum1o2
su2mor
s2ump
s3umsa
s3umst
su2n
sunder4
sun6d5erh
su4ne
s1unf
s3ungl
2s1uni
4sunt
3s2up
sup3p4
su2ra
2s1url
s1urt
sus1e
su2sp
sus3s
2sü2b
sü2d1
süden2
sü3den.
1sün
1süs
1süß
2s1v
2s1w
s3we
sweh2
4swie
4swil
1s2y
syl1
sym3
sy2n3
sy4na
sy4nä
sy5s
2s1z2
4s3za
4szä
4s3zei
s2zena
5s2zene
4s3zent
s2zes
s2zeß
s3zet
s2zis
sz3ta
4s3zu
4s3zw
2ß3a2
ß1ä
2ß1b2
2ß1c
2ß1d4
ßdie3
1ße
2ß1ec
2ß1e2g
2ß1ei
ße2l1a
ße2le
ße2ni
ße2no
2ßentz
ße2nu
ß2ers.
2ßerse
ßer3t
ße2s
ße2t
ß1ex
2ß1f
2ß3g2
ßge2bl
2ß1h2
1ßi
ßi2g1a
2ß1in
ß1j
2ß1k4
2ß1l2
2ß1m
2ß1n2
ß1o2
ß1ö
2ß1p2
2ß1q
ßquet2
2ß3r2
2ß3s2
ßsch2
ßst2
2ß1t
ß2th
ßts2
1ßu2
ß1uf
2ß1uh
2ß1um
ß1uni
ß1ü
2ß1v
2ß1w
2ß1z2
2tab.
ta2b1an
2t1abb
1tabel
2taben
ta4bend
2tabf
2tabg
2tabh
2tabk
1t6able
2t3abn
ta2br
4tabs
2t3abt
ta2bü
2tabw
2tabz
2t1ac
3tacu
t1ada
tadi3
2t1a2dr
ta3d2s
1taf2e
2taff
t1afg
t1af4r
1t2ag
3tag.
ta2ga
ta2g1ei
4t3a4gent
ta3gl
t3ago
tag2s
tag4st
tah2li
tahl3sk
ta3i2k
tai2l
ta1ins
tai4r
ta1ir.
1tak
t3a2ka
ta2kro
tak2ta
3taktb
3takts
3t2aktu
2takz
1t2al.
ta2la
ta3lag
ta3lak
tal3au
t1alb.
t1albk
1talbu
tal3d
1t4ale
tal2en
ta4lens
tal2ga
tal4leg
tal4lei
tal4let
tal6leut
tallin6s
tallo4s
tallö4
tal4lus
ta2l1op
tal2se
2talt
2tam
ta2mer
tam2ma2
tam4mi
tam4mut
t1ampl
t1amt
t1a2na
2tanb
t2and
tand4ar
ta3ne
4tanf
2tang
t2ank
t3ankl
2tanl
t1anm
2tanme
4t1anna
t1ans
t2ans.
4t3ansi
2t3ansp
2tanwa
2tanwä
t2anz.
t1anza
4tanzei
tan6zerh
t1anzu
tan2z1w
ta3or
ta2pe.
ta2pes
2tapf
ta2pl
2tappa
t2appe
2tarb
ta4ren4s
ta4r3ere
3t4ari
2tark
2t1arm
2tart
tar2ta
t1arti
tar2to
ta2ru
2t1arz
ta3sa
1tasc
t1asp
1tas2t
ta3str
1tat.
ta2ta2b
ta2tan
ta2tau
tat1ei
ta2tem
ta2t1er
ta2th
tat3he
t3atl
t4atm
ta2tom
1tats
ta2t1um
4taud
t1auf
4taufg
tau3f4li
4taufn
2taufw
1taug
t1auk
3taum
1taus
2taus.
t1ausb
tau6schr
tau6schw
t2ause
t3ausg
t1ausk
2tausl
2t3auss
4t1ausw
1tax
ta3xi
taxi3s
3täa
tä1c
2täd
3täe
1täg
2tägy
2täh
2t1ält
2täm
t1ämt
t1ängs
1tänz
t1äp
t2är.
tä2ru
tä2s2
t2ät
2tätt
2täug
1täus
2täuß
2täx
1tà
4t3b2
tbauer4
tbe3r2e
tblock5e
tblocken8
2t1c
t3cha
t3che
tch2i
tch3l
t2ch1u
tch1w
t3cl
t3cr
2t3d4
tdun2
1te2a4
te3al
teamma5
te3an
3t4ebb
4t1e2ben
1t2ech
te1cha
3techn
te2chu
2teck
teck2e
te2de
1tee
te1em
te2en3
te1erw
te2es
2teff
2t1egg
teg3re
2teh
2teign
teik4
1teil
2tein
tein3ec
t3einge
t3einla
4teinn
t1eis.
t1eisb
tei3st
te2kel
tek3t2
tela2
te2l3ab
te2l1ac
te2l1au
telb4
tel3d4
te3le
tel1eb
tele4be
te4l1ec
3telef
3teleg
te4l1eh
te4lein
2telem
te4lerd
te4leu
4t3elf.
te2l1in
te2lit
tel3lau
tel3lä
tel3l2e
tel6lein
tel6li6st
te4lost
te2l1ö
tel3s2k
tel3ta
tel3th
tel3t4r
te3mä
te2m1ei
te2min
2temo
te2m1o2r
3temper
1tempo
te4m1u
t6en.
tena2b
te4n3a2d
te4n3a4g
te4nas
te4n3au
te2nä
ten3äh
t4enb
ten3da
4t3endf
t6endi
2t1endl
t6endo
4t3endp
ten3d4r
te2n1e2b
te2nef
ten3ei
te3n4ei.
4tenerg
te2net
4t1eng.
ten4gag
t3engla
t4enh
te2ni
te4n3in
t4enj
t2enk
t2enl
t4enm
ten3n
t2eno
t2ens
tens2e
4tensem
t4enta
t1entb
2tentd
t4ente
4tentn
ten4t3ri
4t3entw
4tentz
te2nu
t2enz
ten6zerh
ten3zw
t1e2pi
t6er.
ter3ac
te1raf
ter3am
te3ran.
te3rand
ter3as
4terbs
4terbt
4t3erde.
te2re2b
te4r3eif
te2rel
ter3end
te4reng
te4rerk
terer4z
4t3erfol
t4erfr
4terfül
terg2
ter3ga
6ter6grei
t4ergru
2t1ergu
4tergü
t4eri
te3ria
te2rid
ter3k
4terklä
2t3erlö
1term
ter4mer
ter4n3ar
4t3erneu
t4ero
t1erö
3terras
ter4re.
1terro
t4ers.
ter3sc
ter4ser
terst4
t4erst.
t4ersti
t4erstu
tert4a
tert2o
teru2
te4r1uf
ter3za
2t1erzb
t2erzu
te2s
tes1ac
te3sä
t1esel
tes1er
te3si
te3so
te3sp
te4spr
3tesse.
tes3si
t2es2t
tes3tät
te4st3ei
tester4
te6sterg
te6sterk
testes4
1tests
t2et.
te2tat
4tetl
3teuf
te1un
teu2r3a2
te2vi
1tex
te1xa
t1e2xe
2t1e2xi
4texp
3text
2t1exz
2t1f4
tfi2l
2t1g2
tger2
t1h
4th.
2th2a
3t4ha.
t2hag
t3hai
t2hak
3thal.
4t3hau
2t3hä
4thc
1th2e
t2he.
3thea
2theb
t2hec
2t3hei
t4hein
t2hek
t2hem
t4hene
t4heni
3theo
2therr
t2hes
3these
t2heu
1thi.
thi3er
t2hik
2t3hil
2t3him
thi3nu
t3hir
2thk
4th3l
4th3m
2th3n
t2ho
t4ho.
2t3hoc
t3hof
2t3hoh
t4hol.
t4holo
t3hor
2t3hot
thou4
2thov
2t3hö
2thp
1th2r2
2ths
2thub
4thun
2thü
2thv
t2hy
ti2ad
ti3a2m
tib4
ti1ce
ti3chr
tiden2
ti4dend
t2ie
1tief.
tie2fr
ti1el
ti2el.
tiel3a
ti3e4n1
tie4rec
ti2ern
1tierr
2tieß
ti1et
ti1eu
1tif.
tif3f
ti1fr
t4ig
ti4gerz
tihi4
ti2kam
ti2kar
ti2kin
ti2kra
ti2krä
tiks2
ti2kü
ti2lar
ti2lau
ti2lei
ti2lel
1tilg
tille4b
ti2l3ö
tilt4
ti2lu
ti2ma2g
t2imi
tim2ma2
4t1imp
t2in.
ti3na
t1inb
4t1ind
ti3n2e
t1inf
tin2g1a
ting3l
ting3s
t1in1it
2t1inj
tin2k1l
t2ins.
4t1inse
t1int
ti3nu
4t1inv
3tio
1tip
3tip.
ti4que.
ti1rh
t2is
ti4scha
tisch3w
ti2sei
ti2sp
3ti3te
tium2
ti2van
tive3
ti2vel
ti4vene
tiver2
ti4verl
ti2v1o
ti2v3r
ti2za
2t1j
2t3k4
2t3l
tl4e
3tlem
tle2r3a
4t5li
tli3ni
2t1m2
tmal2
tmen4t3
tmo4des
t3mu
2t3n2
t5na
tnes4
to4as
to5a4t
1tob
2tobj
tob2l
t1obs
to1ch
t3ochs
3tocht
2tock
1tod
3tod.
tode2
to2d1er
tode4s1
to2d1u
toi4r
to3la
tom1e2
2tomg
1ton
to2nau
to2neh
3too
to2pak
to2pat
1topo
2topt
to1ra
to2rau
to4rän
2torc
t1ord
to2r1el
t1org
t3orga
tor3int
to2rö
1tort
t1ort.
to2ru
t2orw
to3sc
to3se
to3sh
to4sk
tos4seu
tost4
1toten
to2tho
tots2
3t4ou
touil4
to3un
tö2c
1töch
2töf
2t1ök
1tö4l
1tön
t1ö4st
1töt
2t3p2
tpf4
2t1q
t2r4
2tr.
1trac
tra3cha
t3rad.
tra4dem
tra4far
1trag
2trahm
3t4rai
tra4lin
1tram
2t3rams
3t4ran.
2trand
1trank
t1rann
1trans
t3rase
t3rasi
2traß
1traum
2traup
1trä
2träh
3träne
2träs
2träß
2träus
2träuß
4t5re.
tre4ale
tre2br
2trec
t3rech
t4reck
2t3red
1tref
2trefe
3t4reff
2trefo
2treg
t4rei.
1t4reib
2treif
t3reig
2t3reih
t3rein
2t3reis
2treit
t3reiz
2t3rek
2t3rel
t4rem
t4ren.
1trend
t3rent
1trep
2trepe
2trepo
t4repr
t4rer
t4res.
1t4ret
tre2t3r
t5rett
t4reu
2t3rev
2trez
3t4ré
2t3rh
1trib
3trieb.
3triebs
6trieg
tri2er
1trigg
1trin
t3rind
2tring
tri3ni
3trio
t4rip
t3riß
t4rit
1triu
tri2x
trizi1
1troc
4trock.
t4roi
tro2ke
tro2mi
2t3roo
t4rop
tro1pe
3tropf
2troß
t3röc
2tröh
2tröm
1tröp
2tröss
1tröt
2truf
1trug
2truk
trum2
trums1
2t3rund
1t4runk
3t4rup
t3ruß
tru2th
trü1be
trü1bu
2t3rüc
trücker6
t4rüg
3trümm
try1
2ts
t3saa
t3s2ac
t2sa2d
t2s1ah
ts1al
t4s1amt4
t2san
ts3ar
ts1as
t3sat
t2sau
t1sä
t2säh
t2s1än
t4schar
t3sche
t4schef
t3schl
tsch4li
t4schro
ts2cor
t2s1e2b
t3seil
t4seind
ts1em
tse2n1
t2s1eng
t3sens
t2s1ent
t3seq
t2s1er
t6s5essen
t3sic
t2s1i2d
tsing4
ts1ini
t2s1ir
t3sit
t3skala
ts3kr
ts1o
tso2r
t1spal
t1span
ts1par
ts4pare
t1spas
ts2ped
t1spek
ts2pi
ts3ple
ts2pon
ts2por
ts3s2
tst4
t2staf
ts2tat
ts2tau
ts3täti
t4stea
t4s1tep
t4sterm
t4s3terr
ts1tie
t2s1tis
t2stit
t2ston
t4s3trad
t2strä
t2s1tri
ts2tro
t4strop
t2s1trü
ts1u
1tsub
t1sü
4t1t
tt1ab
tt2ac
tta6gess
tt1ak
t4tals
tt3ank
t2tanz
tt1art
t2tän
tt1ebe
tt1eif
tt1ein
tt1eis
tte2la
tte4leb
t4te4leg
tte4len
ttel3l
ttel1o
t3ter
tte4rec
tt2erg
tte4sa
tte4s1ä
tt2häu
t2t3ho
t3to.
t3tos
t3tro
tt3rü
tt2sen
tts1p
tt4s3tem
tt4ster
tt4sti
ttu2
t2tuc
tt2un
t2tu4s
ttü2
tu1alm
tu3an
tub2
tuba3b
1tuc
tu2chi
1tue
tu3en
tu2ere
2tuf
tuf2e
tu3fen
t3u2fer
tuf4fel
2tuh
tu2is
t3u2kr
tul2a
1tum
t2um.
t2ume
2t3umf
2t3umg
2t1umh
2t3umk
2tump
2t3umr
tum2si
tum2so
2t3umt
2t1umw
t3umz
1tun.
2t1una
2t1und
t4une
2t3unf
t3unga
tung6s
2tunif
2t1u2nio
1tunn
1tuns
2t3unt
t1up.
tu2r1a4g
tu2rä
tur1c
tu2re.
tu2rei
tu2r1er
tu2res
tu2r1e2t
turin1
1turn
tu2ro
tur3s
tu4ru
tu2sa
tu4schl
tu2so
tu3ta
2tüb
1tüch
tück2s
1tüf
1tür.
tür1c
1türe
1türg
1türs
1tüten
2tütz
2t3v
4t3w
twa2
twi4e
1ty
3ty.
3typ
ty2pa
3tys
4t1z
t2za4
tz1ag
tz1al
tz1ar
tz1au
tz1ä
t3ze.
t2z1ec
t2z1eie
t2z1eis
tze4n1
tz2ene
tz3ents
tz1erl
tz2ers
t3zes1
tzes3t
tz1ind
t2zor
tz2ö
tz2th
tz2tin
tz1wä
tz1wi
tz1wu
2ua
u1a2b
u3a2c
uad4
u1ah
u1al.
ua2lau
u1alb
u3alet
u1alf
ual3l
ualle2
u3a2lo
u1alr
u1als
u1al3t
ua2lu
u1alz
u3am
u1ans
u3ar.
uara2b
u1ars
ua3sa
ua2th
uat2i
u3au
uau2s
u1ay
u1äm
u1än
uäs4
u1äu
2u1b
u8becken.
ub3ein
u3b4i
ubi3os.
ub2l
ub3lic
u2b3lu
u2bop
ub3rä
u2b3rit
ub2san
ub2s1o
ub2spa
u2büb
2uc
uc1c
u1ce4
uces3
uch1a
u1cha.
uch1ä
u1che
u2ch1ec
uch1ei
u1chi
uch1il
uch1in
uch3l
uch3m
uch3n
u2ch3r
uch2so
uch4spr
uchst4
uch4tor
uch2t3r
u1chu
u2chum
uch3ü
uch1w
u1ci
uck2er
uck3erl
u1cl
2u1d
u3d2a
uder2e
udert4
udi3en
uditi4
u2don
ud3ra
u3dru
2u1e
u2ed
ue2en
u2eg
u4ela
ue2le
ueli4
uel2la
ue2mi
uen1
ue2nä
ue2ner
uenge4
uen2gl
u3e2ni
ue2no
uen2sa
ue2nu
uen2zu
u2ep
ue2r3a
ue2r1ä
uer6baut
uere2
ue2rec
ue3reig
u3eremp
u3erent
ue4rerg
uer3g2
u3erh
u3erinf
u3erin4t
uer4nan
uer2ne
uer4ner
uer3o
uer2ö
u3err
uer3sc
uer3t2
u3erum
u3erunf
u3erunt
u3erur
ue4s
ue5se
ue5sp
ues3s
ue2ta
ue4tek
u3fac
u3fah
uf1ak
u3fal
uf3ar
uf1au
u2f1äs
u2f1ä2ß
u2f1ei
u2f1em
u3fen.
u2fent
u2f1erh
u4ferle
uf2ern
u2f1eß
2uff
uffel2
uff4l
uf2fro
uf3l
u2fob
ufo2r
uf1ori
uf3r
uf3sä
uf2spo
uf4ster
uf2t1eb
uf3ten
uft3erd
uft3s2
u2fum
2u1g
u4gabte
ug1af
ug1ak
ugang4
u2g1ap
uga4s
ug1au
ug3d2
u2g1ei
u2g1erf
u2g1erl
ug4es
ug3hu
u2g1l
ug3lad
u4g3lo
u3g2lö
u4glu
u2g3n
ugo3
ug1or
u2gö
u4g3reis
ug3ro
u2grol
ug4ros
ug3rüs
ug3sau
ug3sc
ug3se
ug4ser
ug3si
ug1spa
ug5stä
u2gü
u1h
uh2au
uh1la
uh1lä
uh2li
uhme4
uhr1a
uh2rer
uh3ri
uh4rin
uhrt4
uh2ru
uh4rü
uh1un
uh1w
2ui
ui2c
u1ie
ui1em
u3ig
u4ige
uil4les
u1im
u1in.
uin3n
u1is.
u3isch.
u3ischs
uisi4n
ui2st
u1j
uk2a
u3käu
u1ke
u1ki
u1k2l
ukle1i
u1k4n
u3ko
uk2ö
u1k4r
uk2ta
uk2t1in
uk2t3r
u1ku
uku2s
uk2ü
u1l
ul1ab3
ul1am
ul1äm
ulb4
ul2dr
uld2se
2ule
u2l1el
ule4n
ul1erf
ul1er2h
ul1erw
ule2sa
ule4s3t
ule2t
ul1eta
u2lex
ulf4
ulg4
uli2k
ul1ins
ul3ka
ul2kn
ulla2g
ul2lä
ul3len
ul2les
ulli2n
ul2lö2
ulo2i
ul1or
ul2p1h
ul2sa
ul4sam
uls2t
2ulta
ul2tri
ult3s
u2lü
ul2vr
ulz2w
u2m3a2k
um1all
um1anz
u2m1art
u2maus
u2maut
u2m1äh
1um3d2
um2en
ument4s
umer2a
um1erf
um1erg
um1erl
um1erw
1umf
1umg
um1inh
u2m1ins
um1ir
1umk
1uml
2umm
umm2a
um4mess
u2möl
umpf4li
um2pho
um2p3le
1umr
3umsat
um2sau
um2ser
um2sim
um2s1pe
um4stem
um2s1u
um3t2
um2un
u2m1ur
1umz
un1
2un.
4una.
1unab
un4al
u3n2am
u2n3an
4un2as
un3at
unau2s
1unda
un4dab
1undd
un3de.
un4dei
und3erf
un2dex
1undf
2undg
un2did
1undn
un2dor
un2d3r
4unds.
und3sp
un2d1um
undü4
1undv
1undz
u3ne
une2b
une2d
une2h
un2ei.
un3ein
un3eis
unen2t
u4n3erz
unes4
1unget
1ungew
1unglü
un3gn
un2gr
ung3ri
ung4s1
un2id
un3ide
1u2nif
unik4
un2im
uni2r
2unis
un3isl
u3n2it
3u2niv
2unk
un2k1a2
un2kei
un2kne
unks2
unk4tit
unk2t3r
3unku
unlö2
un2n3a2d
un3n2e
uno4r
un2os
1unr
uns2
2uns.
unsch5el
un3se
1un3si
un3sk
un3sp
unst1r
1unt
un3ta
unte4ri
2unth
2unto
un3tr
unt3s
2untu
u2nu
u3nuc
u1nü
unvol2
unvoll3
1unw
2unz
2uo
u1o2b
u3of
u1op
u1or
u3or.
u3or3c
u3ors
u1os.
uote2
u1pa
u1pe2
uper1
up2fa
upf2e
upf1i
u1pfl
u3pi
up4lu
up2pl
u1pr
upt3a2
upt3erf
upt3erg
upt1o
u1q
2ur.
u1ra
u2rab
u3raba
ura2be
ural2t
ural4ta
u2r1a2m
ur3ame
u2r1ana
uran4fa
uran4fo
u2r1ang
uran4ge
ur2anh
u2r1an5s
u2rar
ur3a4ren
u2r3att
u2r1au
2u1rä
ur1än
ur3b2a
urch1
ur3d2i
ur1eff
u2rele
ure4n
u4r1ep
ur1erh
ur1erw
2urf
urf3t
ur2gri
urgros4
uri2c
u2r1im
ur1ini
ur3ins
ur1int
urk3se
ur4matt
4u1ro
u3rol
u1rö
ur3p
2urr
ur3re
ur2san
ur2sau
ur2ser
urst4r
ur4sw
urs2ze
urt2
u3ru
ury3
ur2z1a
ur2zä
ur2zec
ur2zi
ur2z1o
ur2z1w
2us
u3saa
u2s1af
us4ann
u1sä
u6schent
u5schmu
usch5wer
u2s1ec
u2s1ei
u3seid
u3sep
use1ra
u2serp
u2s1ese
usi3er.
usi5ers.
us1is.
us3kl
u1so
us3oc
u3soh
u3sol
u2s1op
us1ou
u1sö
u1sp
u2spac
us3part
u2s1pas
u2spat
u3spek
us1pic
u2spo
us2por
u2spu
us2sa2c
ussa2k
us2sat
uss3aue
ussä4l
us2säu
usse4g
us2sei
usse2k
us2se2q
uss5erfa
usser6kl
uss5er6su
us2sez
ussi2c
us3sie
us2si4l
us2si2r
us2sof
us2soh
us4sum
us2sü
u2stab
ust3abe
u3stal
us2tat
us2ten
us2ter
us2th
ust2in
u3stis
u2s1tor
u2strä
u4strit
u3s4trop
u2s1tur
u2sty
u1su
us2ur
2uß
u2ß1u
2u1t
u3ta.
ut1alt
ut3a2m
u2t1ap
u2t1ar
u2t1är
u3te
u4t1ed
ut1e4ge
ut1ei.
ut1eie
ute2n1
u2tent
uter4er
u4t3ersa
ut2es
ut2et
u4tev
u4t1ex
utfi4
ut2he
u2thi
u2t3ho
u2thu
utli4n
u3to.
uto4ber
uto3c
u3tom
ut1opf
u2tops
ut4or
ut3rea
ut3rü
ut3s2a
ut2s1ä
ut4schl
ut4schm
ut4schö
ut3si
ut1s2p
ut2s3pa
utt4an
ut3te
ut3t4l
utt1s2
utu4re
utu5ru
utz3eng
ut2z1in
ut2zo
ut2z1w
2u1u2
u1ü2
u1v4
u2ve.
uve3rä
u1w
2u1x
ux2e
ux2o
ux3t
u1ya
2u1z
uz3ot
uz1we
uz3z4
1üb
üb1ä
2übc
2übd
übe2
übe4n3
über3
ü4bet
üb3l
üb3r
2üc
ü1che
üch3l
üch4s1c
üch5t4e
ück1er
ück3eri
ück4spe
ü4d3a2
üden2g
ü3d2ens
üd1o4
üdö4
üd3r
üd3s2
üdsa1
üd3t4
üdwe2
ü4f1a
ü2f1ei
üfer2
ü2f1erg
üf2fl
ü2f1i
üf3l
üf2to
ü1g
üge6lei6s
ü2g3l
ü2gn
üg3s
üh1a
ü1he
ü2h1ei
ü2h1eng
üh1erf
ü2h1er2k
ü2h1er2z
üh1i
ühl1ac
üh1lam
üh3l2e
üh3mo
üh3ne
üh1o
üh3r2e
ühr3ei.
üh1ro
ühr3ta
ühs2
üh3stu
üh3t
üh4th
üht4r
ü1hu
üh1w
ü1k2
2ül
ül1a
ül2c
ü3l4e
ülla4
üll1au
ül2lei
ül3ler
ül4leu
ül2lo
ü1lu
ü2ment
4ün
ü2n1a
ün2da
ün2dr
ünen3
ün2f1a
ün2f1ei
ün2fli
ün2fr
ün2g3l
ünt2
ün2za
ün2zw
ü1pe
üpf3l
ü1pi
üp2pl
ür1a
ü2r1ei
ür2fl
ür2fr
ür4g3en4g
ü1r2o3
ür4ster
ürt2h
ür2zö
ür2zw
üs2a
ü2schl
üse3h
üse3l
ü1sp
üs4sa
üs2s1c
üss2e
üs4st
ü2sta
ü2str
ü1su
ü1ß
2üt
ü1ta
ü2t1al
ü1te
ü1ti
üt3r
üt4s1
üt2tr
ü1tu
ü1v
ü1z
2v1ab
va1c
val2s
2vang
2varb
vas2
v4at
va2t3a4
va2tei
va2t3h
vatik2
va4t1in
vati8ons.
va2t3r
vat3s4
va2t1u
vat3z
2v1au
vä1
2v1b
2v1d
1ve2
ve3ar
ve3b
ve3c
ve3d
ve3g
ve3h
ve4i
2v1ein
veit4
veits1
ve3la
ve4l1au
ve3le
ve3li
vel3l
ve3lo
ve3ma
2ve3mu
ve3nal
ven2c
ve3ne
venen4d
ve3ni
ve3nö
ve3nü
ve3o
ver1
ver3a
ve3rad
ve3rand
ve3ras
ver3b2
ver5d2
vere2
verf4
verg4
ve3ri
ve4rin
ver3k
ver3sta
vert2
ver5te
ver3u
ve3s
2vesc
2vese
ve4sh
ve4s1p
ves4t
ve3ta
vete1
ve3to
ve3tr
2veü
ve3v
ve3x2
2v1f4
2v1g
2v1h
vi3ar
vi4a3t
vi2c
vi3de
vie2h3a
vi2el
vi3en
vie4rec
vie2w1
vig2
2vii
vi2l1a
vi4l1e2h
vi2l1in
vil3l
2v1i2m
vima2
vi4na
vin2s
2v1int
vi3sa
vise4
vi3s2o
vi2sp
vis2u
2v1k
2v1l2
2v1m
2v1n
2v1ob
vo3ga
vo2gu
3vol
vol2la
voll7auf.
vollen4
vol6l5end
voller4
vol6lerw
vol2li
2v1op
vo2r1
vor3a
vor3e
vor3g
vo3ri
vo5rig
vormen4
vorö4
3voy
2v1p
v2r
2v3ra
v3re
v4ree
2v3ro
2v1s
vs2e
v3s2z
2v1t
vu2et
2vumf
2v1v
2v1w
2v1z
w2a
1waa
wab2bl
wa3che
wach6stu
wach4t4r
waffe2
waffel3
1wag
wa5ge
wa2g3n
wa3go
1wah
wahl5ent
wah4ler
wah2li
wai2b
1wal
2walb
wal4da
wa2les
wal4li4n
2walm
wal2ta
wal2to
walt4st
wa3na
w3anf
wang4s
1wann
wan6z5en6d
wa2p
1war2e
ware1i
wart4e
1was
wa3sa
wa4scha
wa3sche
wa3schi
wa3sh
wass4e
1wäh
1wäl
wäm3
2wäng
1wäs
wäs2c
2w1b2
wbu2
2w1c
2w1d
we2a
we2ba
4webeb
we2bl
web3s
we2e4
weed3
we2fl
1weg
we2g1a
we2g3l
we4gn
we2g3r
weg1s
weg3sa
weg3se
1weh
we4i
wei4bl
2weie
weifel6d
weik4
1weil
wei3sc
weis6se6k
weis4s3p
wei3str
wei4tr
weit1s
wel6schl
wel6schr
wel2t1
welt3a4
wel6t5en6d
wem2ma2
wen3a4
wen2gl
we3ni
wen4k3ri
we2r3a
wer2bl
1werbu
werd2
5werdens
1werdu
werer2
wer2fl
wer4gel
we4r3io
1werk.
wer2ka
1werke
wer2kl
wer2ku
we2rö
wer4sta
wer2t1a
wer4t3ei
wer6t5erm
wer2to
1wese
wesen4s3
we2sp
wes2t
we2st1a
we4st3ei
we4steu
we4sti
we2st1o2
we2stö
we2st3r
we4stu
1wet
wet2s
wett3s
2w1ey
2w1g
2w3h
1wid
wi2e
wie3l2
wien2e
wie2st
wik2
1wil
wim2ma
wim4mu
win4d3ec
win2dr
win2e
2wing
win8n7er8sc
win4num
1wi4r
wi3s2e
wi2sp
1wiss
wi3st
wi3th
1witzl
2w1k
2w1l
2w1m
2wn
wn3s
1wo1c
wo2cha
woche4
1woh
woh4lei
1wolf
wolf4s1
wol4la
wol2lä
wol4ler
wor3a
wo2r3i
wor2t3r
wo4r3u
wot2
1wöc
wört2h
2w1p
w2r
w3ro
2w1s
w3s2k
2w1t
wti2
w2u
1wuc
wuch4sc
wuls2
wun2da
wun4g3r
wun2s
4wur.
wur2fa
1wurst
wus4
1wu4t1
1wüh
wüs4
2w1w
2w1z
x1a
1xa.
2xa2b
1x2ad
1xae
xa1fl
1x2ag
xa2m
xand4
x2anz
1x2as
2x1b
2xc
x1ce
x1ch
x1cl
4x1d
1xe
x1e4g
2xek
xe2l
x1em
3x2em.
xemp4
x2en
xen3s2
x2er.
x2ere
xers2
3xes
2x3eu
2x1f
2x1g
2x1h
xib4
xi1c
xich2
2xid
xide2
xi2d1em
x1i2do
xie3l
xi3g
xil1
xil2a
xi2lo
xi2lu
xin3s2
x2is
xi2s1e
xi2s1o2
xis5s
xi2su
x1i2tu
x1j
2x1k2
4x2l2
x3lä
x3le
2x1m
2x1n
x1or
4x1p
xpor6ter
x1q
2x1r
2x3s2
4x1t
x2t1a
x3ta.
x3t2as
xt1ä
x2tän
x2t1e2d
x2t1ei
x2tent
x2t1er2f
x2t3ev
xtfi4
x2t1il2l
xtra3b4
x2t3ran
xt1s2
xt1u
x3t2ur
1xu
xu1a
x1u2n
xu2s
2xv
2x1w
2xy
3xy.
3xys
x1z
2y1ab
1yac
y1al.
y1a2m
yan2g
y1ank
y1ät
y1b
y1c2
y2chi
y3chis
ych3n
y1d4
y1e
y2ef
yen4n
y2ere
yes2
y2es.
ye4st
ye2th
y1f2
y1g
ygi2
ygie5
yg2l
y1h
yhr2
y1i4
y1j
y1k2
yke3n
yk3s2
y1l
y2l3a2m
yl4ante
yl5b
yl3c
y4le.
yli4n
yllo2
yllo4s
yllö2
yloni1
y2l1u
yma2t
ymp2
ym2pha
ympi1
y2n1o
yno4d
ynt2
y1of
yom2
yon4i
y1ont
y1os
y1ou
y1p
ypa2
yp3an
ype2
y2pf
y3ph
y2p1in
ypo3
y4p3s
y1r
y3r2e
y3ri
yri2a
yri1e
y3r4o
yrr2
y1s
ys2an
ys2c
yse1
y3s2h
y4s3l
ysme3
ys2pa
yst2
y2s1u2
y3s2z
y1t2
y2te.
y2tes
y3to
yu2r
yure3
y1v
y1w
y1y
y1z2
za2
2z3ab
zab3l
za3cha
za3chä
2z1ad
2z1af
za3ge
za3gr
3z2ah
zah4ner
2z3ak
za3li
2z1all
2z1am
z1an
za3ne
2z3anf
3zani
3z2ank
zan4kl
2z3anl
za3no
zanti1
za3ra
2zarb
2zarc
za3re
2z1arm
za3ro
z1arti
zar2tr
2z1arz
z1as
zast4
2z3at3
3zaub
z1au2f
z3aug
3zaun
2z1äc
3z2äh
2z1äm
2zängs
2z1äp
z1ärg
z1ärm
4z1b4
zbü1b
zbübe3
2z3c
2z3d2
zdan2
zdä1
2z1e2ben
2zecho
ze1e
2z1eff
zehe4
zehen1
zeh2l
zeik4
zei3la
zeile4
2z1ein
zeis2
zei3sk
zei3st4
zei2t1a
zeit5end
zei4t3er
zei2tr
zeit3ri
ze2l1a2
zelau2
ze2len
ze2l1er
ze2l1in
zel3l2a
zel4leh
zel4li4n
zels2
zel3sz
zel3t2h
zel3tr
zelu2
2z1emp
5zen.
ze4n3ac
ze2nä
zen3n
ze2no
zens2e
zen4sem
zent3s
ze2nu
zen4z3er
z2er.
ze2r3a
ze2re2b
2z1ergä
4z3ergeb
z3erhal
2zerhö
zerin4t
zerk2
z2erl.
2zerlö
z2ern
zer4neb
zer4n3ei
2z1erq
zers2
2z1ersa
4z3erste
4z3erstr
3zert
zert1a4
zer4t3ag
zert4an
zer6tere
zer6terl
zer4tin
zer6trau
4zerwei
2z1erz
3z2erza
ze2s
zes2c
ze3sku
zesse2
zes4sei
zessen4
zes6s5end
zes4ser
zes4si4c
zes4sim
zes2sp
ze3stau
ze2ß1
ze2tr
2zetts
2z1ex
2z1f4
2z1g2
zger2a
2z1h
z2hen
zhir3
3zi.
zi3alo
zi3ar
zi2dei
zid3r
zie4lei
zi1erh
zi1es.
3zig
zil2e
zil3l
2z1imp
zim2t3
zin2e
zin3ei
zin4er
2z1inf
z1inh
zin1it
zin2sa
zin4ser
4zinsuf
z1int
z1inv
zi2o3
zi3op
zirk2
zirk4s1
zis4t
zi3s2z
zit2h
zi2t1o2
ziv2
2z1j
2z1k4
2z1l2
2z1m2
2z3n2
2z1ob
2z1of
zo2gl
2z1oh
3zol
zolla2
zol3le
zol2li2
zol3lu
zon4ter
zo2o
2z1ope
z1or
zo2ri
zor4ne
zo3se
2z1osz
2zö2f
2z1ök
z1öl
2zön
2z3p4
2z1q
2z3r2
4z1s2
z3sa
z3sh
z3sk
z3str
z3sz
2z1t
z2t1au
z4tehe
zte3str
z3t2her
zt3ho
zt1ins
zt3rec
zt3s2
zu3a
zu3b4
3zu4c
zud4
zudi4
zu2el
zu3f4
zu2g1ar
zu4gent
zu3gl
zug4ste
zug1un
2z1uhr
zuh2u
zu1i
zu3k
2z1um.
zumen2
2zumf
2zumg
2zuml
2zumr
2z1ums
zun2e
2zunt
zup2fi
zu3r2a
z1urk
2z1url
2z1urs
2z1urt
zu3s2
zu3t2a
zuz2
2züb
zür1c
2z1v
zw2
z1wac
2zwag
2zwah
zwan2d1
z2wang
z1war
2zwas
4zwäl
2zweg
2zweh
z2weig
2z1wel
2z1wen
2z1wer
z2werg
2z1wes
2zwet
2zwir
z2wit
2z1wo
z1wör
z1wur
2z1wü
2z1z
z3z4a
zze3s
z3z2o
zz2ö
}

\endinput

%%% Local Variables:
%%% mode: tex
%%% coding: utf-8
%%% End:

